
/* Allow Only Digits  */
angularApp.directive('numberInput', function () {
    return {
        require: 'ngModel',
        link: function (scope, element, attr, ngModelCtrl) {
            function fromUser(text) {
            	   if (text) {
                       var transformedInput = text.replace(/[^0-9]/g, '');

                       if (transformedInput !== text) {
                           ngModelCtrl.$setViewValue(transformedInput);
                           ngModelCtrl.$render();
                       }
                       return transformedInput;
                   }  
                return undefined;
            }            
            ngModelCtrl.$parsers.push(fromUser);
        }
    };
});

/* Allow Only chatBot char  */
angularApp.directive('chatBotChar', function () {
    return {
        require: 'ngModel',
        link: function (scope, element, attr, ngModelCtrl) {
            function fromUser(text) {
            	   if (text) {
                       var transformedInput = text.replace(/[^a-zA-z\?!@#$%&*-,. ]/g, '');

                       if (transformedInput !== text) {
                           ngModelCtrl.$setViewValue(transformedInput);
                           ngModelCtrl.$render();
                       }
		
                       return transformedInput;
                   }  
                return undefined;
            }   

            ngModelCtrl.$parsers.push(fromUser);
        }
    };
});

/* Allow Only numbers 2 decimal places  */
angularApp.directive('amountInput', function($filter,$browser,utilityService) {
    return {
      require: '?ngModel',
      link: function(scope, element, attrs, ngModelCtrl) {
        if(!ngModelCtrl) {
          return; 
        }
        var listener = function() {
            var value = element.val().replace(/,/g, '')
            element.val($filter('INR')(value, false))
        }
        ngModelCtrl.$parsers.push(function(val) {
          if (angular.isUndefined(val)) {
              var val = '';
          }
          
          var clean = utilityService.isUndefined(attrs.noDecimal)?val.replace(/[^0-9\.]/g, ''):val.replace(/[^0-9]/g, '');
          if(attrs.ngModel == "chequeDepositsVm.cheque.chequeAmount" && clean.indexOf('.')==-1 && clean.length>14){
             clean = clean.slice(0,14);
          }else{   
          var negativeCheck = clean.split('-');
			var decimalCheck = clean.split('.');
          if(!angular.isUndefined(negativeCheck[1])) {
              negativeCheck[1] = negativeCheck[1].slice(0, negativeCheck[1].length);
              clean =negativeCheck[0] + '-' + negativeCheck[1];
              if(negativeCheck[0].length > 0) {
              	clean =negativeCheck[0];
              }              
          }            
          if(!angular.isUndefined(decimalCheck[1])) {
              decimalCheck[1] = decimalCheck[1].slice(0,2);
              clean =decimalCheck[0] + '.' + decimalCheck[1];
          }
          }

          if (val !== clean) {
            ngModelCtrl.$setViewValue(clean);
            ngModelCtrl.$render();
            ngModelCtrl.$render = function() {
                element.val($filter('INR')(ngModelCtrl.$viewValue, false))
            }
          }
          return clean;
        });

        element.bind('keypress', function(event) {
          if(event.keyCode === 32) {
            event.preventDefault();
          }
        });
        element.bind('change', listener);
        element.bind('keydown', function(event) {
            $browser.defer(listener) // Have to do this or changes don't get picked up properly
        });
        element.bind('focus', function(event) {
            $browser.defer(listener) // Have to do this or changes don't get picked up properly
        });
      }
    };
  });
  
  
  
  
/* Restrict input user to Maximum Length  */
angularApp.directive("maxLen", [function() {
  return {
    require: 'ngModel',
    link: function (scope, element, attrs, ngModelCtrl) {
      var maxlength = Number(attrs.maxLen);
      function fromUser(text) {
          if (text.length > maxlength) {
            var transformedInput = text.substring(0, maxlength);
            ngModelCtrl.$setViewValue(transformedInput);
            ngModelCtrl.$render();
            return transformedInput;
          } 
          return text;
      }
      ngModelCtrl.$parsers.push(fromUser);
    }
  }; 
}]);

/* Restrict input user to Maximum Length if max length is dynamic   */
angularApp.directive("dynamicMaxLen", [function() {
  return {
    require: 'ngModel',
    link: function (scope, element, attrs, ngModelCtrl) {
		var attrsTemp=attrs;
		var maxlength = Number(attrs.dynamicMaxLen);
      function fromUser(text) {
		  maxlength = Number(attrsTemp.dynamicMaxLen);
          if (text.length > maxlength) {
            var transformedInput = text.substring(0, maxlength);
            ngModelCtrl.$setViewValue(transformedInput);
            ngModelCtrl.$render();
            return transformedInput;
          } else if (text) {
            var transformedInput =  text.replace(/[^A-Za-z0-9 .,|@&_-]/g, '');
            ngModelCtrl.$setViewValue(transformedInput);
            ngModelCtrl.$render();
            return transformedInput;
          }

          
          return text;
      }
      ngModelCtrl.$parsers.push(fromUser);
    }
  }; 
}]);

/* Restrict user input to Maximum Amount  */
angularApp.directive("maxAmount", [function() {
    return {
        restrict: "A",
        scope: { data: '=maxAmount' },
        link: function(scope, elem, attrs) {        
           
  angular.element(elem).on("keypress", function(e) {
              var inputValue=parseInt(this.value.replace(/,/g,''))
                if (inputValue >= scope.data) e.preventDefault();
            });
     
        }
    }
}]);

