(function() {
	'use strict';

	angularApp.value('validStatusCodeService', {
		"codes" : ["0000","0001"]
	});
	angularApp.service('commonAPIService', commonAPIService);

	commonAPIService.$inject = [ '$cordovaBarcodeScanner','utilityService', 'validStatusCodeService','aoService', 'AdapterUtils'];
	
	function commonAPIService($cordovaBarcodeScanner, utilityService, validStatusCodeService, aoService, AdapterUtils) {
		var APIService = this;
		var alphabets = /^([ \.]?[a-zA-Z]+)+$/;
        var numbers = /^[0-9]*$/;
        var addressRegex = /^[A-z().,-/0-9 #']*$/;

		APIService.invokeAdapter = function(adapterURL, requestType, params,
				callback) {
			requestType = angular.lowercase(requestType);
			if (requestType == 'get') {
				AdapterUtils.getData(adapterURL, true).then(
					function (response) {
						if (response.status == 200) {
							// valid status : we can check different common
							// status codes in this place
							callback(response);
						} else {
							// invalid status from server
						}
					},
					function (error) {
						utilityService.showErrorMessage(error);
						// execute failure case
					}
				);
			} else if (requestType == 'post'){					
				AdapterUtils.postData(adapterURL, params, true).then(
					function (response) {
						if (response.status == 200) {
							// valid status : we can check different common
							// status codes in this place
							callback(response);
						} else {
							// invalid status from server
						}
					},
					function (error) {
						utilityService.showErrorMessage(error);
						// execute failure case
					}
				);
			}
		};

		APIService.QRcodescanner = function (callback) {
			$cordovaBarcodeScanner.scan().then(function (barcodeData) {
				var barcodeDetail = {}
				if (!utilityService.isUndefined(barcodeData.text)) {
					var xmlText = barcodeData.text;
					var formattedXml = xmlText.replace("/?xml", "?xml");
					formattedXml = formattedXml.replace("xml?", "?xml");
					var x2js = new X2JS();
					var jsonObj = x2js.xml_str2json(formattedXml);
					if (utilityService.isUndefined(jsonObj)) {
						var title = '';
						var template = "{{'AADHAAR_POPUP'| translate}}";
						var onTap = '';
						var buttontext = "<b>  </b>";
						utilityService.showAlertModal(title, template, onTap, $scope, $state, buttontext);
					}
					else {
						var jsonStr = JSON.stringify(jsonObj);
						
						var securedScannedData = {
							_co: aoService.checkHtmlTags(jsonObj.PrintLetterBarcodeData._uid),
							_dist: aoService.checkHtmlTags(jsonObj.PrintLetterBarcodeData._dist),
							_dob: aoService.checkHtmlTags(jsonObj.PrintLetterBarcodeData._dob),
							_gender: aoService.checkHtmlTags(jsonObj.PrintLetterBarcodeData._gender),
							_house: aoService.checkHtmlTags(jsonObj.PrintLetterBarcodeData._house),
							_name: aoService.checkHtmlTags(jsonObj.PrintLetterBarcodeData._name),
							_pc: aoService.checkHtmlTags(jsonObj.PrintLetterBarcodeData._pc),
							_po: aoService.checkHtmlTags(jsonObj.PrintLetterBarcodeData._po),
							_state: aoService.checkHtmlTags(jsonObj.PrintLetterBarcodeData._state),
							_street: aoService.checkHtmlTags(jsonObj.PrintLetterBarcodeData._street),
							_subdist: aoService.checkHtmlTags(jsonObj.PrintLetterBarcodeData._subdist),
							_uid: aoService.checkHtmlTags(jsonObj.PrintLetterBarcodeData._uid),
							_vtc: aoService.checkHtmlTags(jsonObj.PrintLetterBarcodeData._vtc),
							_yob: aoService.checkHtmlTags(jsonObj.PrintLetterBarcodeData._yob),
							_loc: aoService.checkHtmlTags(jsonObj.PrintLetterBarcodeData._loc),
							_lm: aoService.checkHtmlTags(jsonObj.PrintLetterBarcodeData._lm)
						}
						barcodeDetail.uid = aoService.checkSecuredData(numbers, securedScannedData._uid);
						barcodeDetail.name = aoService.checkSecuredData(alphabets, securedScannedData._name);
						barcodeDetail.gender = aoService.checkSecuredData(alphabets, securedScannedData._gender);
						barcodeDetail.yob = aoService.checkSecuredData(numbers, securedScannedData._yob);
						barcodeDetail.house = aoService.checkSecuredData(addressRegex, securedScannedData._house);
						barcodeDetail.street = aoService.checkSecuredData(addressRegex, securedScannedData._street);
						barcodeDetail.lm = aoService.checkSecuredData(addressRegex, securedScannedData._lm);
						barcodeDetail.loc = aoService.checkSecuredData(addressRegex, securedScannedData._loc);
						barcodeDetail.vtc = aoService.checkSecuredData(addressRegex, securedScannedData._vtc);
						barcodeDetail.po = aoService.checkSecuredData(addressRegex, securedScannedData._po);
						barcodeDetail.dist = aoService.checkSecuredData(addressRegex, securedScannedData._dist);
						barcodeDetail.subdist = aoService.checkSecuredData(addressRegex, securedScannedData._subdist);
						barcodeDetail.state = aoService.checkSecuredData(addressRegex, securedScannedData._state);
						barcodeDetail.pc = aoService.checkSecuredData(numbers, securedScannedData._pc);
						barcodeDetail.dob = securedScannedData._dob;
					}
				}
				callback(barcodeDetail);
			}, function (error) {
				callback(error);
			});
		}
		return APIService;
	}
})();
