angularApp.service('validationService', function(utilityService) {
	var isValidEmail = function(email) {
		// Logic to validate Email
	}
	
	/**
	 * Validates Mobile number
	 * @param {Number} mobile
	 * @return {boolean} isValidMobile
	 */
	var isValidMobile = function(mobile) {
		if (utilityService.isUndefined(mobile))
			return false
		var regexp = new RegExp("^[6789][0-9]{9}$");
		return regexp.test(mobile);
	}
	
	/**
	 * Validates SBI Account Number
	 * @param {Number} mobile
	 * @return {boolean} isValidMobile
	 */
	var isValidSBIAccountNumber = function(sbiAccNO) {
		if (utilityService.isUndefined(sbiAccNO))
			return false
		// Validation changed for VPA implementation
		var regexp = new RegExp("^[a-zA-Z0-9]{11}$");
		return regexp.test(sbiAccNO);
	}
	
	/**
	 * Validates whether the given input contains alphabets only
	 * @param {String} name
	 * @return {boolean} isValidName
	 */
	var isValidName = function(name) {
		if (utilityService.isUndefined(name))
			return false
		var regexp = new RegExp("^[a-z A-Z]{1,100}$");
		return regexp.test(name);
	}   
	
	/**
	 * Validates whether the given input contains alphabets and Numeric only
	 * @param {String} name
	 * @return {boolean} isValidNickName
	 */
	var isValidNickName = function(nickName) {
		if (utilityService.isUndefined(nickName))
			return false
		var regexp = new RegExp("[a-zA-Z0-9]$");
		return regexp.test(nickName);
	} 
	/**
	 * Validates Max Length
	 * @param {Number} maxlength
	 * @return {boolean} isValidMaxLength
	 */
	var isValidMaxLength = function(maxlength) {
		if (utilityService.isUndefined(maxlength))
			return false
		var regexp = new RegExp("[0-9]$");
		return regexp.test(maxlength);
	}
	
	/**
	 * Validates IFSC Code
	 * @param {String} ifsc
	 * @return {boolean} isValidIFSC
	 */
	var isValidIFSC = function(ifsc) {
		if (utilityService.isUndefined(ifsc))
			return false
		var regexp = new RegExp("[A-Z|a-z]{4}[0][0-9a-zA-Z]{6}$");
		return regexp.test(ifsc);
	}
	var isValidOTP = function(otp) {
		if (utilityService.isUndefined(otp))
			return false;
		var regexp = new RegExp("^[0-9]{6}$");
		return regexp.test(otp);
	};

	/**
	 * Validates MMID
	 * @param {Number} mmid
	 * @return {boolean} isValidMMID
	 */
	var isValidMMID = function(mmid) {
		if (utilityService.isUndefined(mmid))
			return false
		var regexp = new RegExp("^[0-9]{7}$");
		return regexp.test(mmid);
	}
	
	/**
	 * Validates VPA
	 * @param {String} vpa
	 * @return {boolean} isValidVPA
	 */
	var isValidVPA = function(vpa) {
		if (utilityService.isUndefined(vpa))
			return false
		var regexp = new RegExp("^[a-zA-Z0-9]+([\.-]?\[a-zA-Z0-9]+)*@[a-zA-Z]+[a-zA-Z]+$");
		if(vpa.indexOf("@sbi") == -1){
			return false;
		}
		return regexp.test(vpa);
	}
	
	/**
	 * Validates Amount , checks if transAmount is less than or equal to availableBalance, also checks if transAmount is less than or equal to maxLimit (if given)
	 * returns 1 if transAmount, availableBalance ,maxLimit are undefined
	 * returns 2 if transAmount > availableBalance 
	 * returns 3 if transAmount > maxLimit
	 * returns 0 if success
	 * @param {Number} availableBalance
	 * @param {Number} transAmount
	 * @param {Number} maxLimit
	 * @return {Number} isValidAmount
	 */
	var isValidAmount = function(availableBalance, transAmount, maxLimit) {
		if (utilityService.isUndefined(availableBalance) || utilityService.isUndefined(transAmount))
			return 1
		if (transAmount<=0)
			return 1
		var avlBal;
		var tranAmt;
		var maxL;
		if (typeof transAmount === "number")
			tranAmt = transAmount;
		else
			tranAmt = parseFloat(transAmount.replace(",", ""));
		if (typeof availableBalance === "number")
			avlBal = availableBalance;
		else
			avlBal = parseFloat(availableBalance.replace(",", ""));
		if (!utilityService.isUndefined(maxLimit))
			if (typeof maxLimit === "number")
				maxL = maxLimit;
			else
				maxL = parseFloat(maxLimit.replace(",", ""));
		if (avlBal >= tranAmt) {
			if (utilityService.isUndefined(maxL))
				return 0 
			if (maxL >= tranAmt)
				return 0
			else
				return 3
		} else {
			return 4
		}
	}
	
	return {
		isValidEmail : isValidEmail,
		isValidMobile : isValidMobile,
		isValidName : isValidName,
		isValidSBIAccountNumber : isValidSBIAccountNumber,
		isValidVPA : isValidVPA,
		isValidIFSC : isValidIFSC,
		isValidOTP : isValidOTP,
		isValidMMID : isValidMMID,
		isValidNickName : isValidNickName,
		isValidMaxLength : isValidMaxLength,
		isValidAmount : isValidAmount
	};
});
