'use strict';
/**
*   @ngdoc service
*   @name angularApp.service : velocityCheck Service
*   @restrict A
*   @description
*	Velocity Check : One customer should not be allowed to send SMS more than 5 times in day
*/
angularApp.service('velocityCheckService',
    function (loggedInUserService, $q, registerWithSimService, constantConfig) {
        var velocityCheckService = this;
        velocityCheckService.isAllowed = true;
        var vCount = 1;
        var appendData;
        var fileName = constantConfig.SB.fileName;
        var velocityMaxCount = registerWithSimService.velocityMaxCount;
        var velocityErrorMessage = registerWithSimService.velocityErrorMessage;
        var reqParams;
        var technicalError = constantConfig.SB.technicalError;

        velocityCheckService.getVelocityData = function () {
            var q = $q.defer();
            loggedInUserService.manageLocalData('', fileName, false, 'read').then(function (response) {
                if (response || response.length > 0) {
                    var preDT = response.currentDateTime ? new Date(response.currentDateTime) : new Date();
                    var isSameDate = velocityCheckService.checkSameDate(preDT);
                    var isVelocityCount = response.vCount ? parseInt(response.vCount) : '';
                    
                    if (isSameDate && isVelocityCount >= velocityMaxCount) {
                        q.reject(velocityErrorMessage);
                    } else {
                        //counter increment or set 1 based on different date
                        if (!isSameDate && isVelocityCount) {
                            reqParams = velocityCheckService.commonCodeForAppendingData(vCount, response, preDT);
                        } else {
                            reqParams = velocityCheckService.commonCodeForAppendingData("", response, preDT);
                        }
                        velocityCheckService.velocityDataSave(reqParams).then(function (res) {
                            q.resolve(response);
                        });
                    }

                } else {
                    //This is first time where counter set to 1
                    var newDate = new Date();
                    reqParams = velocityCheckService.commonCodeForAppendingData(vCount, response, newDate);
                    velocityCheckService.velocityDataSave(reqParams).then(function (res) {
                        q.resolve(response);
                    });
                }
            },function(){
                q.reject(technicalError);
            });
            return q.promise;
        }

        velocityCheckService.commonCodeForAppendingData = function (cnt, response, preDT) {
            var count;
            if (cnt)
                count = cnt;
            else
                count = response.vCount ? parseInt(response.vCount) + 1 : vCount;

            appendData = '"vCount": "' + count + '","currentDateTime":"' + new Date() + '","previousSavedDateTime":"' + preDT + '"';
            return appendData;
        }

        velocityCheckService.velocityDataSave = function (ad) {
            var q1 = $q.defer();
            loggedInUserService.manageLocalData(ad, fileName, false, 'write').then(function (res) {
                q1.resolve(res);
            }, function () {
                q1.resolve();
            });

            return q1.promise;
        };

        velocityCheckService.checkSameDate = function (preDT) {
            var cdt = new Date();
            var diff = cdt.getDate() === preDT.getDate() ? true : false;
            return diff;
        }

        return velocityCheckService;
    });
