angularApp.service('AdapterUtils',
	function ($q, $state, utilityService, ConnectivityMonitorUtils, constantConfig, encryptionService, loggedInUserService, $rootScope, $ionicPopup) {

		var AdapterUtils = this;
		AdapterUtils.secretData = "";
		AdapterUtils.isAppTimedOut = false;
		AdapterUtils.isSessionExpired = false;

		/**
		 *  WLResourceRequest for session logout call
		 */
		AdapterUtils.sessionLogout = function () {
			var q = $q.defer();
			var payLoad = {};
			AdapterUtils.postData("adapters/PreHomeLoginAdapter/portal/logout", payLoad, false).then(
			  function (response) {
				q.resolve(response.data);
			  },
			  function (error) {
				q.reject(error);
			  }
			);
			return q.promise;
		};

		/**
		 *  WLResourceRequest for get call
		 */
		AdapterUtils.getData = function (url, isLoader) {
			var q = $q.defer();
			var payLoad = {};
			var isEncryptEnabled = true;
			AdapterUtils.callAdapterResource(url, payLoad, isLoader, WLResourceRequest.POST, isEncryptEnabled).then(
				function (response) {
					q.resolve(response);
				},
				function (error) {
					q.reject(error);
				}
			);
			return q.promise;
		}

		/**
		 *  WLResourceRequest for put call
		 */
		AdapterUtils.putData = function (url, payLoad, isLoader) {
			var q = $q.defer();
			var isEncryptEnabled = true;
			AdapterUtils.callAdapterResource(url, payLoad, isLoader, WLResourceRequest.PUT, isEncryptEnabled).then(
				function (response) {
					q.resolve(response);
				},
				function (error) {
					q.reject(error);
				}
			);
			return q.promise;
		}
		
		/**
		 *  WLResourceRequest for post call
		 */
		AdapterUtils.postData = function (url, payLoad, isLoader) {
			var q = $q.defer();
			var isEncryptEnabled = true;
			AdapterUtils.callAdapterResource(url, payLoad, isLoader, WLResourceRequest.POST, isEncryptEnabled).then(
				function (response) {
					q.resolve(response);
				},
				function (error) {
					q.reject(error);
				}
			);
			return q.promise;
		}

		/**
		 *  WLResourceRequest for post with explicit timeout call
		 */
		AdapterUtils.postDataWithTimeOut = function (url, payLoad, isLoader, timeOutInMilliSeconds) {
			var q = $q.defer();
			var isEncryptEnabled = true;
			AdapterUtils.callAdapterResource(url, payLoad, isLoader, WLResourceRequest.POST, isEncryptEnabled, timeOutInMilliSeconds).then(
				function (response) {
					q.resolve(response);
				},
				function (error) {
					q.reject(error);
				}
			);
			return q.promise;
		}

		/**
		 *  WLResourceRequest for post with explicit timeout call
		 */
		AdapterUtils.postDataWithOutEncryption = function (url, payLoad, isLoader) {
			var q = $q.defer();
			var isEncryptEnabled = false;
			AdapterUtils.callAdapterResource(url, payLoad, isLoader, WLResourceRequest.POST, isEncryptEnabled).then(
				function (response) {
					q.resolve(response);
				},
				function (error) {
					q.reject(error);
				}
			);
			return q.promise;
		}

		/**
		 *  Actual adapter resources are called using the below method
		 */
		AdapterUtils.callAdapterResource = function (url, payLoad, isLoader, requestType, isEncryptEnabled, timeOutInMilliSeconds) {
			var q = $q.defer();
			if (!utilityService.lastTimeStamp) {
				utilityService.lastTimeStamp = new Date();
			} else {
				var diff = Math.ceil(((new Date()) - utilityService.lastTimeStamp) / 60000);
				if (diff > constantConfig.SBITIMEOUT) {
					if(!AdapterUtils.isAppTimedOut) {
						AdapterUtils.isAppTimedOut = true;
						setTimeout(function () {
							reloadApp(constantConfig.adapter.CHALLENGE_HANDLING_CANCELED);
							return;
						}, 300);
						
						
					}
				}
				utilityService.lastTimeStamp = new Date();
			}

			//Check spinner to be displayed or not
			if (isLoader) {
				utilityService.showSpinner();
			}

			//Check network connectivity 
			if (ConnectivityMonitorUtils.isOffline()) {
				q.reject({ "responseMessage": "Unable to connect to Internet. Please check your connectivity." });
				return q.promise;
			}

			var options = {
				timeout: (timeOutInMilliSeconds ? Number(timeOutInMilliSeconds) : 60000)
			};

			if(utilityService.accessRestricted) {
				options.scope =  utilityService.accessRestricted;
			}

			var resourceRequest = new WLResourceRequest(url, requestType, options);
			
			if (typeof payLoad == "object") {
				payLoad.xLotusToken = loggedInUserService.tokenLotus;
			} else {
				payLoad = {};
				payLoad.xLotusToken = loggedInUserService.tokenLotus;
			}

			if(isEncryptEnabled){
				payLoad = AdapterUtils.secretData == "" ? JSON.stringify(payLoad) : AdapterUtils.secretData + encryptionService.getAES256EncryptedData(JSON.stringify(payLoad));
			} else {
				payLoad = JSON.stringify(payLoad);
			}
			
			resourceRequest.send(payLoad).then(function (response) {
				if (isLoader) {
					utilityService.hideSpinner();
				}
				try {
					if(isEncryptEnabled){
						response.responseText = AdapterUtils.secretData == "" ? JSON.parse(response.responseText.replace(/{{/g,"")) : JSON.parse(encryptionService.getAES256DecryptedData(response.responseText).replace(/{{/g,""));
					} else {
						response.responseText = JSON.parse(response.responseText.replace(/{{/g,"")) ;
					}
				} catch (err) {
					response.responseText = JSON.parse(response.responseText);
					if(!AdapterUtils.isSessionExpired){
						if (response.responseText.responseCode == '0400') {
							AdapterUtils.isSessionExpired = true;
							//reloadApp(response.responseText.responseMessage);
							reloadApp(constantConfig.adapter.CHALLENGE_HANDLING_CANCELED);
							return;
						}
					}
				}
				if (response && response.responseText && response.responseText.responseCode == '0000') {
					q.resolve(response.responseText);
				} else {
					q.reject(response.responseText);
				}
			}, function (error) {
				if (isLoader) {
					utilityService.hideSpinner();
				}
				if(error.errorCode == "INVALID_REQUEST" || error.errorCode == "invalid_client"){
                    reloadApp(constantConfig.adapter.INVALID_REQUEST);
                    return;
                }
				q.reject({ "responseMessage": utilityService.getServerExceptionMessage(error) });
			});
			return q.promise;
		}

		function reloadApp(message) {
			/*Condition not to show popup if session is expired and reloads automatically as suggested */
			if(message == constantConfig.adapter.CHALLENGE_HANDLING_CANCELED || message == constantConfig.adapter.SESSION_INACTIVITY){
				loggedInUserService.logoutUser();
			} else if(message == constantConfig.adapter.INVALID_REQUEST){
                loggedInUserService.setMFPUrl(false);
            } else {
				var reloadPopup = $ionicPopup.show({
					title: null,
					cssClass: 'my-custom-popup',
					template: '<div class="button_fund fontSize-subHeading roboto-light font-dark-grey">' + message + '</div>',
					scope: '',
					buttons: [{
						text: 'OK',
						type: 'button-assertive',
						onTap: function () {
							reloadPopup.close();
							loggedInUserService.logoutUser();
						}
					}],
				});
			}
		}

		document.addEventListener("resume", onResume, false);

		function onResume() {
			if (!utilityService.lastTimeStamp) { 
				utilityService.lastTimeStamp = new Date(); 
			} else {
				var diff = Math.ceil(((new Date()) - utilityService.lastTimeStamp) / 60000);
				if (diff > constantConfig.SBITIMEOUT) {
					if(!AdapterUtils.isAppTimedOut) {
						AdapterUtils.isAppTimedOut = true;
						reloadApp(constantConfig.adapter.CHALLENGE_HANDLING_CANCELED);
						return;
					}
				}
			}
		}

		return AdapterUtils;
	});