/**
*   @ngdoc config
*   @name angularApp.config : appConfig
*   @description
*	configuration file for app module
*/

'use strict';

// definition of routes
angularApp.config(['$stateProvider',
	'$urlRouterProvider',
	'$controllerProvider',
	'$translateProvider',
	'$ionicConfigProvider',

	function ($stateProvider,
		$urlRouterProvider,
		$controllerProvider,
		$translateProvider,
		$ionicConfigProvider) {

		$translateProvider.useStaticFilesLoader({ files: [{ prefix: 'i18n/', suffix: '.json' }, { prefix: 'i18n/mf/', suffix: '.json' },{ prefix: 'i18n/nfs/', suffix: '.json' }, { prefix: 'i18n/feedback/', suffix: '.json' }, { prefix: 'i18n/settings/', suffix: '.json' }, { prefix: 'i18n/mydreams/', suffix: '.json' }, { prefix: 'i18n/cards/', suffix: '.json' }, { prefix: 'i18n/sec/', suffix: '.json' },{ prefix: 'i18n/version/', suffix: '.json' },{ prefix: 'i18n/irctc/', suffix: '.json' },{ prefix: 'i18n/agl/', suffix: '.json' }, { prefix: 'i18n/mobility/', suffix: '.json' },{ prefix: 'i18n/rxtc/', suffix: '.json' },{ prefix: 'i18n/goldloan/', suffix: '.json' }, { prefix: 'i18n/support/', suffix: '.json' },{ prefix: 'i18n/carloan/', suffix: '.json' },{ prefix: 'i18n/homeloan/', suffix: '.json' },{ prefix: 'i18n/rd/', suffix: '.json' }, { prefix: 'i18n/xpresscredit/', suffix: '.json' },{ prefix: 'i18n/yonocash/', suffix: '.json' }, { prefix: 'i18n/etax/', suffix: '.json' }, { prefix: 'i18n/bharatQR/', suffix: '.json' }, { prefix: 'i18n/accountOpening/', suffix: '.json' }, { prefix: 'i18n/ncmc/', suffix: '.json' },{ prefix: 'i18n/fdmaturity/', suffix: '.json' },{ prefix: 'i18n/service/', suffix: '.json' },{ prefix: 'i18n/yonowearable/', suffix: '.json' }, { prefix: 'i18n/quickpay/', suffix: '.json' },{ prefix: 'i18n/nps/', suffix: '.json' },{ prefix: 'i18n/pacl/', suffix: '.json' },{ prefix: 'i18n/patwl/', suffix: '.json' },{ prefix: 'i18n/fundsTransfer/', suffix: '.json' }, { prefix: 'i18n/fasTag/', suffix: '.json' }, { prefix: 'i18n/ppfExtension/', suffix: '.json' }, { prefix: 'i18n/governmentSchemes/', suffix: '.json' },{ prefix: 'i18n/rinnraksha/', suffix: '.json' }, { prefix: 'i18n/csat/', suffix: '.json' }, { prefix: 'i18n/updateKYC/', suffix: '.json' }] });
		// Set sanitization strategy
		$translateProvider.useSanitizeValueStrategy('sanitizeParameters');
		//Set the default Language
		$translateProvider.preferredLanguage('en');
		$translateProvider.fallbackLanguage("en");
		ionic.Platform.isAndroid() ? $ionicConfigProvider.views.transition('android') : $ionicConfigProvider.views.transition('none');
		$ionicConfigProvider.views.swipeBackEnabled(false);
		//set header text to center
		$ionicConfigProvider.navBar.alignTitle('center');
		$ionicConfigProvider.views.forwardCache(true);

		//set jsScrolling to true
		$ionicConfigProvider.scrolling.jsScrolling(true);
		// any unknown URLS go to 404
		//$urlRouterProvider.otherwise('/404');
		// no route goes to index
		//$urlRouterProvider.when('', '/menu/mPinLogin');
		// use a state provider for routing

		/*State defination with respective names, urls, controllers and templates */
		$stateProvider
			//Menu start
			.state('menu', {
				url: '/menu',
				data: {
					pageId: 'HM_MENU'
				},
				abstract: true,
				cache: false,
				templateUrl: 'pages/menu/menu.html',
				controller: 'menuController',
				controllerAs: 'menuVm',
			})
			//Menu ends

			//Account Aggregators start
			.state('menu.manageAggregators', {
				url: '/manageAggregators',
				cache: false,
				data: {
					pageId: 'ACC_AGGREGATORS'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/accountAggregator/manageAggregators.html',
						controller: 'manageAggregatorsController',
						controllerAs: 'manageAggregatorsVm',
					}
				}
			})
			.state('menu.availableAggregators', {
				url: '/availableAggregators',
				cache: false,
				data: {
					pageId: 'ACC_AGGREGATORS'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/accountAggregator/availableAggregators.html',
						controller: 'availableAggregatorsController',
						controllerAs: 'availableAggregatorsVm',
					}
				}
			})
			.state('menu.otherBankTransactions', {
				url: '/otherBankTransactions',
				cache: false,
				data: {
					pageId: 'ACC_AGGREGATORS_TRANS'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/accountAggregator/otherBankTransactions.html',
						controller: 'otherBankTransactionsController',
						controllerAs: 'otherBankTransactionsVm',
					}
				}
			})
			//Account Aggregators end

			.state('menu.calculateFDRD', {
				url: '/calculateFDRD',
				cache: false,
				data: {
					pageId: 'CALCULATE_FDRD'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/calculateFdRd/calculateFdRd.html',
						controller: 'calculateFdRdController',
						controllerAs: 'calcFdRdVm'
					}
				}
			})
			//Fixed Deposit start
			.state('menu.fixedDeposit', {
				url: '/fixedDeposit',
				cache: false,
				data: {
					pageId: 'FD_HOM'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fixedDeposit/fixedDeposit/fixedDeposit.html',
						controller: 'fixedDepositController',
						controllerAs: 'fixedDepositVm',
					}
				}
			})
			.state('menu.fixedDuration', {
				url: '/fixedDuration',
				cache: false,
				data: {
					pageId: 'FD_DUR'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fixedDeposit/fixedDuration/fixedDuration.html',
						controller: 'fixedDurationController',
						controllerAs: 'fixedDurationVm',
					}
				}
			})
			.state('menu.nominee', {
				url: '/nominee',
				cache: false,
				data: {
					pageId: 'FD_NOM'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fixedDeposit/nominee/nominee.html',
						controller: 'nomineeController',
						controllerAs: 'nomineeVm',
					}
				}
			})
			.state('menu.interestrate', {
				url: '/interestrate',
				cache: false,
				data: {
					pageId: 'FD_INSTR'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fixedDeposit/interestrate/interestrate.html',
						controller: 'interestrateController',
						controllerAs: 'interestrateVm',
					}
				}
			})
			.state('menu.reviewFD', {
				url: '/reviewFD',
				cache: false,
				data: {
					pageId: 'FD_RVW'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fixedDeposit/reviewFD/reviewFD.html',
						controller: 'reviewFDController',
						controllerAs: 'reviewFDVm',
					}
				}
			})
			.state('menu.interestPayout', {
				url: '/interestPayout',
				cache: false,
				data: {
					pageId: 'FD_IPO'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fixedDeposit/interestPayout/interestPayout.html',
						controller: 'interestPayoutController',
						controllerAs: 'interestPayoutVm',
					}
				}
			})
			.state('menu.atMaturity', {
				url: '/atMaturity',
				cache: false,
				data: {
					pageId: 'FD_AMTY'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fixedDeposit/atMaturity/atMaturity.html',
						controller: 'atMaturityController',
						controllerAs: 'atMaturityVm',
					}
				}
			})
			.state('menu.fixedDepositDetails', {
				url: '/fixedDepositDetails',
				cache: false,
				data: {
					pageId: 'FD_DETL'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fixedDeposit/fixedDepositDetails/fixedDepositDetails.html',
						controller: 'fixedDepositDetailsController',
						controllerAs: 'fixedDepositDetailsVm',
					}
				}
			})
			.state('menu.fixedDepositClosure', {
				url: '/fixedDepositClosure',
				cache: false,
				data: {
					pageId: 'FD_CLS'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fixedDeposit/fixedDepositDetails/fixedDepositClosure.html',
						controller: 'fixedDepositDetailsController',
						controllerAs: 'fixedDepositDetailsVm',
					}
				}
			})
			.state('menu.overdraft', {
				url: '/overdraft',
				cache: false,
				data: {
					pageId: 'FD_OVRDFT'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fixedDeposit/overdraft/overdraft.html',
						controller: 'overdraftController',
						controllerAs: 'overdraftVm',
					}
				}
			})
			//Fixed Deposit ends

			//Account Overview start
			.state('menu.accountOverviewMyBalance', {
				url: '/accountOverviewMyBalance',
				data: {
					pageId: 'AOV_HOM'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/myBalance/myBalance.html',
						controller: 'myBalanceController',
						controllerAs: 'Vm',
					}
				}
			})
			.state('menu.spendAnalysis', {
				url: '/spendAnalysis',
				cache: false,
				data: {
					pageId: 'SA_ATI'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/spendAnalysis/spendAnalysis.html',
						controller: 'spendAnalysisController',
						controllerAs: 'spendAnalysisVm',
					}
				}
			})
			.state('menu.myBarrowings', {
				url: '/myBarrowings',
				cache: false,
				data: {
					pageId: 'AOV_MYBRW'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/myBarrowings/myBarrowings.html',
						controller: 'myBarrowingsController',
						controllerAs: 'myBarrowingsVm',
					}
				}
			})
			.state('menu.autoLoan', {
				url: '/autoLoan',
				cache: false,
				data: {
					pageId: 'AOV_AULON'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/autoLoan/autoLoan.html',
						controller: 'autoLoanController',
						controllerAs: 'autoLoanvm',
					}
				}
			})
			.state('menu.odDetails', {
				url: '/odDetails',
				cache: false,
				data: {
					pageId: 'AOV_ODDTL'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/odDetails/odDetails.html',
						controller: 'odDetailsController',
						controllerAs: 'odDetailsvm',
					}
				}
			})
			.state('menu.recurringDeposits', {
				url: '/recurringDeposits',
				cache: false,
				data: {
					pageId: 'AOV_RECRNGDEPST'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/recurringDeposits/recurringDeposits.html',
						controller: 'recurringDepositsController',
						controllerAs: 'recurringDepositsVm',
					}
				}
			})
			.state('menu.otherDeposits', {
				url: '/otherDeposits',
				cache: false,
				data: {
					pageId: 'AOV_OTHERDEPST'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/otherDeposits/otherDeposits.html',
						controller: 'otherDepositsController',
						controllerAs: 'otherDepositsVm',
					}
				}
			})
			.state('menu.myInvestments', {
				url: '/myInvestments',
				cache: false,
				data: {
					pageId: 'AOV_MYINVT'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/myInvestments/myInvestments.html',
						controller: 'myInvestmentsController',
						controllerAs: 'myInvestmentsvm',
					}
				}
			})
			.state('menu.myInsurance', {
				url: '/myInsurance',
				cache: false,
				data: {
					pageId: 'AOV_MYINSU'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/myInsurance/myInsurance.html',
						controller: 'myInsuranceController',
						controllerAs: 'myInsuranceVm',
					}
				}
			})
			.state('menu.transaction', {
				url: '/transaction',
				cache: false,
				data: {
					pageId: 'AOV_TRNS'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/transaction/transaction.html',
						controller: 'transactionController',
						controllerAs: 'transactionVm',
					}
				}
			})
			.state('menu.myCards', {
				url: '/myCards',
				cache: false,
				data: {
					pageId: 'AOV_MYCRDS'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/myCards/myCards.html',
						controller: 'myCardsController',
						controllerAs: 'myCardsVm',
					}
				}
			})
			.state('menu.overdraftAcc', {
				url: '/overdraftAcc',
				data: {
					pageId: 'AOV_ODACCT'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/overdraftAcc/overdraftAcc.html',
						controller: 'overdraftAccController',
						controllerAs: 'overdraftAccVm',
					}
				}
			})
			//Account Overview End
			//My Dreams Revamp Start
			.state('menu.editSelectedDream', {
				url: '/editSelectedDream',
				data: {
					pageId: 'CLOSEDDREAMDTL'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/myDreams/editSelectedDream.html',
						controller: 'editSelectedDreamController',
						controllerAs: 'editSelectedDreamVm'
					}
				}
			})

			.state('menu.closedDreamDetails', {
				url: '/closedlinkDream',
				data: {
					pageId: 'CLOSEDDREAMDTL'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/myDreams/closedDreamDetails.html',
						controller: 'closedDreamDetailsController',
						controllerAs: 'closedDreamDetailsVm'
					}
				}
			})
			.state('menu.linkDream', {
				url: '/linkDream',
				data: {
					pageId: 'LINKDREAM'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/myDreams/linkDream.html',
						controller: 'linkDreamController',
						controllerAs: 'linkDreamVm'
					}
				}
			})
			.state('menu.createNewDream', {
				url: '/createNewDream',
				data: {
					pageId: 'CREATENEWDREAM'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/myDreams/createNewDream.html',
						controller: 'createNewDreamController',
						controllerAs: 'createNewDreamVm'
					}
				}
			})
			.state('menu.createNewDreamSuccess', {
				url: '/createNewDreamSuccess',
				data: {
					pageId: 'CREATENEWDREAMSUCCESS'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/myDreams/createNewDreamSuccess.html',
						controller: 'createNewDreamSuccessController',
						controllerAs: 'createNewDreamSuccessVm'
					}
				}
			})
			.state('menu.closeDreamSuccess', {
				url: '/closeDreamSuccess',
				data: {
					pageId: 'CLOSEDREAMSUCCESS'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/myDreams/closeDreamSuccess.html',
						controller: 'closeDreamSuccessController',
						controllerAs: 'closeDreamSuccessVm'
					}
				}
			})
			.state('menu.selectedDream', {
				url: '/selectedDream',
				data: {
					pageId: 'CLOSEDREAMSUCCESS'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/myDreams/selectedDream.html',
						controller: 'selectedDreamController',
						controllerAs: 'selectedDreamVm'
					}
				}
			})
						.state('menu.closeDreamOTP', {
				url: '/closeDreamOTP',
				data: {
					pageId: 'CLOSEDREAMOTP'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/myDreams/closeDreamOTP.html',
						controller: 'closeDreamOTPController',
						controllerAs: 'closeDreamOTPVm'
					}
				}, params: { depositObject: null }
			})
			.state('menu.closeDepositOTP', {
				url: '/closeDepositOTP',
				data: {
					pageId: 'CLOSEDEPOSITOTP'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/closeDepositOTP/closeDepositOTP.html',
						controller: 'closeDepositOTPController',
						controllerAs: 'closeDepositOTPVm'
					}
				}, params: { depositObject: null }
			})
			.state('menu.delinkSuccess', {
				url: '/delinkSuccess',
				data: {
					pageId: 'DLINKDREAMSUCCESS'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/myDreams/delinkSuccess.html',
						controller: 'delinkSuccessController',
						controllerAs: 'delinkSuccessVm'
					}
				}
			})
			.state('menu.viewDream', {
				url: '/viewDream',
				data: {
					pageId: 'VIEWDREAM'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/myDreams/viewDream.html',
						controller: 'viewDreamController',
						controllerAs: 'viewDreamVm'
					}
				}
			})
			.state('menu.linkDreamReview', {
				url: '/linkDreamReview',
				data: {
					pageId: 'LINKDREAMREVIEW'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/myDreams/linkDreamReview.html',
						controller: 'linkDreamReviewController',
						controllerAs: 'linkDreamReviewVm'
					}
				}
			})

				.state('menu.closeDreamReview', {
				url: '/closeDreamReview',
				data: {
					pageId: 'LINKDREAMREVIEW'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/myDreams/closeDreamReview.html',
						controller: 'closeDreamReviewController',
						controllerAs: 'closeDreamReviewVm'
					}
				}
			})
			//My Dream Revamp End
			//My Dreams starts
			.state('menu.myDreams', {
				url: '/myDreams',
				data: {
					pageId: 'MD_MYDM'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/myDeposits/myDreams/myDreams.html',
						controller: 'myDreamsController',
						controllerAs: 'myDreamsVm',
					}
				}, params: { dreamsObj: null }
			})
			.state('menu.createMyDream', {
				url: '/createMyDream',
				cache: false,
				data: {
					pageId: 'MD_CRMYDM'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/myDeposits/myDreams/createDream/createMyDream.html',
						controller: 'createMyDreamController',
						controllerAs: 'createMyDreamVm',
					}
				}, params: { dreamsObj: null }
			})
			.state('menu.dreamAddFund', {
				url: '/dreamAddFund',
				data: {
					pageId: 'MD_DMADFU'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/myDeposits/myDreams/addFund/dreamAddFund.html',
						controller: 'dreamAddFundController',
						controllerAs: 'dreamAddFundVm',
					}
				}, params: { dreamsObj: null }
			})
			.state('menu.tdsEnquiry', {
				url: '/tdsEnquiry',
				data: {
					pageId: 'MD_TDSENQ'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/serviceRequest/tdsEnquiry.html',						
						controller: 'tdsEnquiryController',
						controllerAs: 'tdsEnquiryVm',
					}
				}, params: { dreamsObj: null }
			})
			.state('menu.ppfEReceipt', {
				url: '/ppfEReceipt',
				data: {
					pageId: 'NFS_PPFERCPT'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/ppfEReceipt/ppfEReceipt.html',
						controller: 'ppfEReceiptController',
						controllerAs: 'ppfEReceiptVm',
					}
				}, params: { dreamsObj: null }
			})
			.state('menu.ppfViewDetails', {
				url: '/ppfViewDetails',
				data: {
					pageId: 'NFS_PPFVIEW'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/ppfEReceipt/ppfViewDetails.html',
						controller: 'ppfViewDetailsController',
						controllerAs: 'ppfViewDetailsVm',
					}
				}, params: { dreamsObj: null }
			})
			.state('menu.ppfReviewDetails', {
				url: '/ppfReviewDetails',
				data: {
					pageId: 'NFS_PPFREVIEW'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/ppfEReceipt/ppfReviewDetails.html',
						controller: 'ppfReviewDtlController',
						controllerAs: 'ppfReviewDtlVm',
					}
				}, params: { dreamsObj: null }
			})			
			.state('menu.reprintChallan', {
				url: '/reprintChallan',
				data: {
					pageId: 'NFS_PRITCH'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/reprintITChallan/reprintITChallan.html',
						controller: 'reprintITChallanController',
						controllerAs: 'reprintITChallanVm',
					}
				}, params: { dreamsObj: null }
			})
			.state('menu.viewChallanDtl', {
				url: '/viewChallanDtl',
				data: {
					pageId: 'NFS_VIEWCH'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/reprintITChallan/viewChallanDtl.html',
						controller: 'viewChallanDtlController',
						controllerAs: 'viewChallanDtlVm',
					}
				}, params: { dreamsObj: null }
			})
			.state('menu.reviewChallanDtl', {
				url: '/reviewChallanDtl',
				data: {
					pageId: 'NFS_REVIEWCH'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/reprintITChallan/reviewChallanDtl.html',
						controller: 'reviewChallanDtlController',
						controllerAs: 'reviewChallanDtlVm',
					}
				}, params: { dreamsObj: null }
			})			
			.state('menu.reviewYourDream', {
				url: '/reviewYourDream',
				cache: false,
				data: {
					pageId: 'MD_RWYUDM'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/myDeposits/myDreams/addFund/reviewYourDream.html',
						controller: 'reviewYourDreamController',
						controllerAs: 'reviewYourDreamVm',
					}
				}, params: { dreamsObj: null }
			})
			.state('menu.viewTransactions', {
				url: '/viewTransactions',
				cache: false,
				data: {
					pageId: 'MD_VWTRN'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/myDeposits/myDreams/dreamDetails/viewTransactions.html',
						controller: 'viewTransactionsController',
						controllerAs: 'viewTransactionsVm',
					}
				}, params: { dreamsObj: null, transDetObj: null, dreamDetailsObj: null }
			})
			.state('menu.reviewCloseDream', {
				url: '/myDreams',
				cache: false,
				data: {
					pageId: 'MD_RWCLSMD'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/myDeposits/myDreams/dreamDetails/reviewCloseDream.html',
						controller: 'reviewCloseDreamController',
						controllerAs: 'reviewCloseDreamVm',
					}
				}, params: { dreamIdObj: null, rdAccountNumber: null, reviewDreamsObj: null, imgId: null }
			})
			.state('menu.dreamTerms', {
				url: '/dreamTerms',
				cache: false,
				data: {
					pageId: 'MD_DMTRM'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/myDeposits/myDreams/termsConditions/terms.html',
						controller: 'termsController',
						controllerAs: 'termsVm',
					}
				}, params: { termsObj: null }
			})
			//My Deposits ends

			//General Insurance start
			.state('menu.commonComponent', {
				url: '/commonComponent',
				cache: false,
				data: {
					pageId: 'GI_CMCPNT'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/generalInsurance/commonComponent.html',
						controller: 'commonComponentController',
						controllerAs: 'commonComponentVM',
					}
				}
			})
			//General Insurance ends

			//Cards starts here
			.state('menu.Details', {
				url: '/cardDetails',
				cache: false,
				data: {
					pageId: 'CRDS_CRDDETL'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/cards/cardDetails.html',
						controller: 'cardDetailsController',
						controllerAs: 'cardDetailsVm',
					}
				}
			})
			.state('menu.ckAgreeRedirect', {
				url: '/ckAgreeRedirect',
				cache: false,
				data: {
					pageId: 'CRDS_AGREDRT'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/cards/ckAgreeRedirect.html',
						controller: 'ckAgreeRedirectController',
						controllerAs: 'ckAgreeRedirectVm',
					}
				}
			})
			.state('menu.sbiCommonComponents', {
				url: '/sbiAccidentRecommendations',
				cache: false,
				data: {
					pageId: 'CRDS_SBIACDTRCDN'
				},
				params: { page: 'accident' },
				views: {
					'menuContent': {
						templateUrl: 'pages/cards/commonComponent.html',
						controller: 'commonComponentController',
					}
				}
			})
			//Cards ends

			//Securities start
			.state('menu.introSecurities', {
				url: '/introSecurities',
				cache: false,
				data: {
					pageId: 'SEC_INTRO'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/securities/introSecurities/introSecurities.html',
						controller: 'introSecuritiesController',
						controllerAs: 'introSecuritiesVm',
					}
				}
			})
			.state('menu.securityKnowledgeSeries', {
				url: '/securityKnowledgeSeries',
				cache: false,
				data: {
					pageId: 'SEC_KNOWLDGESRES'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/securities/securityKnowledgeSeries.html',
						controller: 'securityKnowledgeSeriesController',
						controllerAs: 'securityKnowledgeSeriesVm',
					}
				}
			})
			.state('menu.securityKnowledgeSeriesDetail', {
				url: '/securityKnowledgeSeriesDetail',
				cache: false,
				data: {
					pageId: 'SEC_KNOWLDGEDTL'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/securities/securityKnowledgeSeriesDetail.html',
						controller: 'securityKnowledgeSeriesDetailController',
						controllerAs: 'securityKnowledgeSeriesDetailVm',
					}
				}
			})
			.state('menu.linkAccount', {
				url: '/linkAccount',
				cache: false,
				data: {
					pageId: 'SEC_LNKACCT'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/securities/linkAccount/linkAccount.html',
						controller: 'linkAccountController',
						controllerAs: 'linkAccountVm',
					}
				}
			})
			.state('menu.securitiesPortfolio', {
				url: '/securitiesPortfolio',
				cache: false,
				data: {
					pageId: 'SEC_PRTFO'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/securities/securityProfile/securitiesPortfolio/securitiesPortfolio.html',
						controller: 'securitiesPortfolioController',
						controllerAs: 'securitiesPortfolioVm',
					}
				}
			})
			.state('menu.dematAccountHome', {
				url: '/dematAccountHome',
				cache: false,
				data: {
					pageId: 'SEC_DMTACCHOM'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/securities/dematAccount/dematAccountHome.html',
						controller: 'dematAccountHomeController',
						controllerAs: 'dematVm',
					}
				}
			})
			.state('menu.openAccountSuccess', {
				url: '/openAccountSuccess',
				cache: false,
				data: {
					pageId: 'SEC_OPNACCTSUC'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/securities/openSecurityAccount/openAccountSuccess.html',
						controller: 'openAccountSuccessController',
						controllerAs: 'openAccountSuccessVm',
					}
				}
			})
			.state('menu.openSecurityAccount', {
				url: '/openSecurityAccount',
				cache: false,
				data: {
					pageId: 'SEC_OPNSECACCT'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/securities/openSecurityAccount/openSecurityAccount.html',
						controller: 'openSecurityAccountController',
						controllerAs: 'openSecurityAccountVm',

					}
				}
			})
			.state('menu.openDematAccount', {
				url: '/openSecurityAccount',
				cache: false,
				data: {
					pageId: 'SEC_OPNDEMATACCT'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/securities/openSecurityAccount/openDematAccount.html',
						controller: 'openSecurityAccountController',
						controllerAs: 'openAccountVm',

					}
				}
			})
			.state('menu.dematAndTradingAccount', {
				url: '/dematAndTradingAccount',
				cache: false,
				data: {
					pageId: 'SEC_OPNDEMATTRADACCT'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/securities/openNewDematAndTradingAccount/dematAndTradingAccountHome.html',
						controller: 'dematAndTradingAccountController',
						controllerAs: 'dematAndTradingAccountVm',

					}
				}
			})
			.state('menu.accountToBeMapped', {
				url: '/accountToBeMapped',
				cache: false,
				data: {
					pageId: 'SEC_OPNDEMATACTMAPED'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/securities/openNewDematAndTradingAccount/accountToBeMapped.html',
						controller: 'accountToBeMappedController',
						controllerAs: 'accountToBeMappedVm',

					}
				}
			})
			.state('menu.appStatus', {
				url: '/appStatus',
				cache: false,
				data: {
					pageId: 'SEC_OPNDEMATACAPPSTUS'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/securities/openNewDematAndTradingAccount/appStatus.html',
						controller: 'appStatusController',
						controllerAs: 'appStatusVm',

					}
				}
			})
			.state('menu.capsecNavigate', {
				url: '/capsecNavigate',
				cache: false,
				data: {
					pageId: 'SEC_OPNDEMATACAPPNAV'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/securities/openNewDematAndTradingAccount/capsecNavigate.html',
						controller: 'capsecNavigateController',
						controllerAs: 'capsecNavigateVm',

					}
				}
			})
			.state('menu.dematOTPAuthenticate', {
				url: '/dematOTPAuthenticate',
				cache: false,
				data: {
					pageId: 'SEC_OPNDEMATOTPAUTH'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/securities/openNewDematAndTradingAccount/otpAuthenticate.html',
						controller: 'otpAuthenticateController',
						controllerAs: 'dematOTPAuthVm',

					}
				}
			})
			.state('menu.openAccountDetails', {
				url: '/openAccountDetails',
				cache: false,
				data: {
					pageId: 'SEC_OPNACCTDETL'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/securities/openSecurityAccount/openAccountDetails.html',
						controller: 'openAccountDetailsController',
						controllerAs: 'openAccountDetailsVm',

					}
				},
				params: { obj: null }
			})
			.state('menu.openAccountDetailsCon', {
				url: '/openAccountDetailsCon',
				cache: false,
				data: {
					pageId: 'SEC_OPNACCTDETLCON'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/securities/openSecurityAccount/openAccountDetailsCon.html',
						controller: 'openAccountDetailsController',
						controllerAs: 'openAccountConVm',

					}
				}
			})
			.state('menu.launchAsset', {
				url: '/assetsDetails',
				cache: false,
				data: {
					pageId: 'SEC_ASSTDETL'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/securities/securityProfile/assetsData/assetsDetails.html',
						controller: 'assetsDetailsController',
						controllerAs: 'assetsVm',

					}
				},
				params: { obj: null, obj1: null }
			})
			.state('menu.sbiCAPSecuritiesPortfolio', {
				url: '/sbiCAPSecuritiesPortfolio',
				cache: false,
				data: {
					pageId: 'SEC_MYSECPRTFO'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/securities/mySecurityPortfolio.html',
						controller: 'sbiCAPSecuritiesPortfolioController',
						controllerAs: 'sbiCAPSecuritiesPortfolioVm'
					}
				},
				params: { obj: null, obj1: null }
			})
			.state('menu.securityLanding', {
				url: '/securityLanding',
				cache: false,
				data: {
					pageId: 'SEC_LNDNG'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/securities/securityLanding.html',
						controller: 'securityLandingController',
						controllerAs: 'securityLandingControllerVm'
					}
				},
				params: { obj: null, obj1: null }
			})
			.state('menu.sbiCAPSecuritiesPortfolioDis', {
				url: '/sbiCAPSecuritiesPortfolioDis',
				cache: false,
				data: {
					pageId: 'SEC_MYSECPRTFODIS'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/securities/mySecurityPortfolioDis.html',
						controller: 'sbiCAPSecuritiesPortfolioDisController',
						controllerAs: 'sbiCAPSecuritiesPortfolioDisVm'
					}
				},
				params: { obj: null, obj1: null }
			})
			.state('menu.sbiCAPSecuritiesError', {
				url: '/sbiCAPSecuritiesError',
				cache: false,
				data: {
					pageId: 'SEC_SBICAPSECERR'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/securities/sbiCAPSecuritiesError.html',
						controller: 'sbiCAPSecuritiesErrorController',
						controllerAs: 'sbiCAPSecuritiesErrorVm'
					}
				},
				params: { obj: null, obj1: null }

			})
			//Securities ends


			//Home Screen starts
			.state('menu.homeScreen', {
				url: '/homeScreen',
				cache: false,
				data: {
					pageId: 'HM_HOM'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/homeScreen/homeScreen.html',
						controller: 'homeScreenController',
						controllerAs: 'homeScreenVM',
					}
				}
			})
			//Home Screen ends

			//Settings Start
			.state('menu.settings', {
				url: '/settings',
				cache: false,
				data: {
					pageId: 'STG_HOM'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/settings/settings.html',
						controller: 'settingsController',
						controllerAs: 'settingsVm',
					}
				}
			})
			.state('menu.profilePassword', {
				url: '/settings',
				cache: false,
				data: {
					pageId: 'STG_PRFPWD'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/settings/profilePassword.html',
						controller: 'settingsController',
						controllerAs: 'settingsVm',
					}
				}
			})
			.state('menu.funding', {
				url: '/funding',
				cache: false,
				data: {
					pageId: 'STG_FUNDG'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/settings/accountDetails/funding/funding.html',
						controller: 'fundingController',
						controllerAs: 'fundingVm',
					}
				}
			})
			.state('menu.createVPA', {
				url: '/createVPA',
				cache: false,
				data: {
					pageId: 'STG_CRTVPA'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/settings/payments/manageVPA/createVPA.html',
						controller: 'createVpaController',
						controllerAs: 'createVpaVm'
					}
				}
			})
			.state('menu.confirmVPA', {
				url: '/confirmVPA',
				cache: false,
				data: {
					pageId: 'STG_CNFMVPA'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/settings/payments/manageVPA/confirmVPA.html',
						controller: 'confirmVpaController',
						controllerAs: 'confirmVpaVm'
					}
				}
			})
			.state('menu.question', {
				url: '/question',
				data: {
					pageId: 'STG_QUSTN'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/settings/payments/manageVPA/question.html',
						controller: 'createVpaController',
						controllerAs: 'createVpaVm'
					}
				}
			})
			.state('menu.settingsSetUpiPin', {
				url: '/settingsSetUpiPin',
				data: {
					pageId: 'STG_SETUPIPIN'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/settings/payments/manageVPA/settingsSetUpiPin.html',
						controller: 'createVpaController',
						controllerAs: 'createVpaVm'
					}
				}
			})
			/*
			.state('menu.genQrCode', {
				url: '/genQrCode',
				cache: false,
				data: {
					pageId: 'STG_GNTQRCD'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/settings/payments/manageQrCode/genQrCode.html',
						controller: 'genQrCodeController',
						controllerAs: 'genQrCodeVm'
					}
				}
			})
			*/
			.state('menu.qrCode', {
				url: '/qrCode',
				cache: false,
				data: {
					pageId: 'STG_QRCD'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/settings/payments/manageQrCode/qrCode.html',
						controller: 'qrCodeController',
						controllerAs: 'qrCodeVm'
					}
				}
			})
			.state('menu.selPrimaryAcc', {
				url: '/selPrimaryAcc',
				cache: false,
				data: {
					pageId: 'STG_SELPRMYACCT'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/settings/personalisation/selPrimaryAcc/selectPrimaryAcc.html',
						controller: 'selPrimaryAccController',
						controllerAs: 'selPrimaryAccVm'
					}
				}
			})
			.state('menu.settingsNotifications', {
				url: '/settingsNotifications',
				cache: false,
				data: {
					pageId: 'STG_STGNOTFN'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/settings/personalisation/notification/notifications.html',
						controller: 'notificationsController',
						controllerAs: 'notificationsVm'
					}
				}
			})
			.state('menu.myProfile', {
				url: '/myProfile',
				data: {
					pageId: 'STG_MYPROF'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/settings/profile/myProfile.html',
						controller: 'myProfileController',
						controllerAs: 'myProfileVm'
					}
				}
			})
			.state('menu.changeMpin', {
				url: '/changeMpin',
				cache: false,
				data: {
					pageId: 'STG_CNGMPIN'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/settings/security/changeMpin.html',
						controller: 'changeMpinController',
						controllerAs: 'changeMpinVm'
					}
				}
			})
			.state('menu.confirmChangeMpin', {
				url: '/confirmChangeMpin',
				cache: false,
				data: {
					pageId: 'STG_CNFMCNGMPIN'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/settings/security/confirmChangeMpin.html',
						controller: 'confirmChangeMpinController',
						controllerAs: 'confirmChangeMpinVm'
					}
				}
			})
			.state('menu.mmidDetails', {
				url: '/mmidDetails',
				cache: false,
				data: {
					pageId: 'STG_MMIDDETL'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/settings/payments/mmid/mmidDetails.html',
						controller: 'mmidDetailsController',
						controllerAs: 'mmidDetailsVm'
					}
				}
			})
			//Settings End

			//Mutual Funds start
			.state('menu.mutualFunds', {
				url: '/mutualFunds',
				cache: false,
				data: {
					pageId: 'MF_HOM'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/mutualFunds/mutualFunds.html',
						controller: 'mutualFundsController',
						controllerAs: 'mutualFundsVm',
					}
				}
			})
			.state('menu.cancelFunds', {
				url: '/cancelFunds',
				cache: false,
				data: {
					pageId: 'MF_CANCELFUNDS'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/cancelFunds/cancelFunds.html',
						controller: 'cancelFundsController',
						controllerAs: 'cancelFundsVm',
					}
				}
			})
			.state('menu.cancelPaymentSuccess', {
				url: '/cancelPaymentSuccess',
				cache: false,
				data: {
					pageId: 'MF_CNCLPYMTSUCS'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/OTP/paymentSuccess.html',
						controller: 'cancelFundsController',
						controllerAs: 'cancelFundsVm',
					}
				}
			})
			.state('menu.cancelFundOTP', {
				url: '/cancelFundOTP',
				cache: false,
				data: {
					pageId: 'MF_CNCLFNDOTP'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/OTP/mfEnterOTP.html',
						controller: 'cancelFundsController',
						controllerAs: 'cancelFundsVm',
					}
				}
			})
			.state('menu.introMutualFunds', {
				url: '/introMutualFunds',
				cache: false,
				data: {
					pageId: 'MF_INTROMUTLFND'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/introMutualFunds/introMutualFunds.html',
						controller: 'introMutualFundsController',
						controllerAs: 'introMutualFundsVm',
					}
				}
			})
			.state('menu.startInvesting', {
				url: '/startInvesting',
				cache: false,
				data: {
					pageId: 'MF_STRTINVT'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/startInvesting/startInvesting.html',
						controller: 'startInvestingController',
						controllerAs: 'startInvestingVm',
					}
				}
			})
			.state('menu.riskProfileQA', {
				url: '/riskProfileQA',
				cache: false,
				data: {
					pageId: 'MF_RSKPROFQA'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/riskProfileQA/riskProfileQA.html',
						controller: 'riskProfileQAController',
						controllerAs: 'riskProfileQAVm',
					}
				}
			})
			.state('menu.goalPlanning', {
				url: '/goalPlanning',
				cache: false,
				data: {
					pageId: 'MF_GOALPLNG'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/goalPlanning/goalPlanning.html',
						controller: 'goalPlanningController',
						controllerAs: 'goalPlanningVm',
					}
				}
			})
			.state('menu.mutualFundsList', {
				url: '/mutualFundsList',
				cache: false,
				data: {
					pageId: 'MF_MUTLFUNDLIST'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/mutualFundsList/mutualFundsList.html',
						controller: 'mutualFundsListController',
						controllerAs: 'mutualFundsListVm',
					}
				},
				params: { obj: null }
			})
			.state('menu.mutualTaxSaver', {
				url: '/mutualTaxSaver',
				cache: false,
				data: {
					pageId: 'MF_TAX_SAVER'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/taxSaver/taxSaver.html',
						controller: 'taxSaverController',
						controllerAs: 'taxSaverVm',
					}
				},
				params: { obj: null }
			})
			.state('menu.fundDetails', {
				url: '/fundDetails',
				cache: false,
				data: {
					pageId: 'MF_FUNDDETL'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/fundDetails/fundDetails.html',
						controller: 'fundDetailsController',
						controllerAs: 'fundDetailsVm',
					}
				},
				params: { obj: null }
			})
			.state('menu.KYC', {
				url: '/KYC',
				cache: false,
				data: {
					pageId: 'MF_KYC'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/KYC/KYC.html',
						controller: 'KYCController',
						controllerAs: 'KYCVm',
					}
				}
			})
			.state('menu.eKYC', {
				url: '/KYC',
				cache: false,
				data: {
					pageId: 'MF_EKYC'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/eKYC/eKYC.html',
						controller: 'eKYCController',
						controllerAs: 'eKYCVm',
					}
				}
			})
			.state('menu.createInvestmentAccount', {
				url: '/createInvestmentAccount',
				cache: false,
				data: {
					pageId: 'MF_CRTINVTACCT'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/createInvestmentAccount/createInvestmentAccount.html',
						controller: 'createInvestmentAccountController',
						controllerAs: 'createInvestmentAccountVm',
					}
				}
			})
			.state('menu.investmentAccountForm', {
				url: '/investmentAccountForm',
				cache: false,
				data: {
					pageId: 'MF_INVTACCTFORM'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/investmentAccountForm/investmentAccountForm.html',
						controller: 'investmentAccountFormController',
						controllerAs: 'investmentAccountFormVm',
					}
				},
				params: { obj: null }
			})
			.state('menu.createFolioOTP', {
				url: '/createFolioOTP',
				cache: false,
				data: {
					pageId: 'MF_CREATE_FOLIO_OTP'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/OTP/mfEnterOTP.html',
						controller: 'investmentAccountFormController',
						controllerAs: 'investAccountVm',
					}
				}
			})

			.state('menu.typeOfInvestment', {
				url: '/typeOfInvestment',
				cache: false,
				data: {
					pageId: 'MF_TYPOFINVT'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/typeOfInvestment/typeOfInvestment.html',
						controller: 'typeOfInvestmentController',
						controllerAs: 'typeOfInvestmentVm',
					}
				}
			})
			.state('menu.lumpsum', {
				url: '/lumpsum',
				cache: false,
				data: {
					pageId: 'MF_LMPSUM'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/lumpsum/lumpsum.html',
						controller: 'lumpsumController',
						controllerAs: 'lumpsumVm',
					}
				}
			})
			.state('menu.lumpsumReview', {
				url: '/lumpsumReview',
				data: {
					pageId: 'MF_LMPSUMRVW'
				},
				cache: false,

				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/lumpsum/lumpsumReview.html',
						controller: 'lumpsumController',
						controllerAs: 'lumpsumVm',
					}
				}
			})
			.state('menu.lumpsumOTP', {
				url: '/lumpsumOTP',
				cache: false,
				data: {
					pageId: 'MF_LMPSUMOTP'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/OTP/mfEnterOTP.html',
						controller: 'lumpsumController',
						controllerAs: 'lumpsumVm',
					}
				}
			})
			.state('menu.paymentSuccess', {
				url: '/paymentSuccess',
				cache: false,
				data: {
					pageId: 'MF_LMPSUMOTPSUCS'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/OTP/paymentSuccess.html',
						controller: 'lumpsumController',
						controllerAs: 'lumpsumVm',
					}
				}
			})
			.state('menu.createSIP', {
				url: '/createSIP',
				cache: false,
				data: {
					pageId: 'MF_CRTSIP'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/createSIP/createSIP.html',
						controller: 'createSIPController',
						controllerAs: 'createSIPVm',
					}
				}
			})
			.state('menu.createSIPReview', {
				url: '/createSIPReview',
				data: {
					pageId: 'MF_CRTSIPRVW'
				},
				cache: false,

				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/createSIP/createSIPReview.html',
						controller: 'createSIPController',
						controllerAs: 'createSIPVm',
					}
				}
			})
			.state('menu.sipOTP', {
				url: '/sipOTP',
				cache: false,
				data: {
					pageId: 'MF_SIPOTP'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/OTP/mfEnterOTP.html',
						controller: 'lumpsumController',
						controllerAs: 'lumpsumVm',
					}
				}
			})
			.state('menu.sipPaymentSuccess', {
				url: '/sipPaymentSuccess',
				cache: false,
				data: {
					pageId: 'MF_SIPOTPSUCS'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/OTP/paymentSuccess.html',
						controller: 'lumpsumController',
						controllerAs: 'lumpsumVm',
					}
				}
			})
			.state('menu.createSIPSuccess', {
				url: '/createSIPSuccess',
				cache: false,
				data: {
					pageId: 'MF_CRTSIPSUC'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/createSIP/createSIPSuccess.html',
						controller: 'createSIPSuccessController',
						controllerAs: 'createSIPSuccessVm',
					}
				}
			})
			.state('menu.redeem', {
				url: '/redeem',
				cache: false,
				data: {
					pageId: 'MF_REDM'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/redeem/redeem.html',
						controller: 'redeemController',
						controllerAs: 'redeemVm',
					}
				}
			})
			.state('menu.redeemReview', {
				url: '/redeemReview',
				cache: false,
				data: {
					pageId: 'MF_REDMRVW'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/redeem/redeemReview.html',
						controller: 'redeemController',
						controllerAs: 'redeemVm',
					}
				}
			})
			.state('menu.redeemOTP', {
				url: '/redeemOTP',
				cache: false,
				data: {
					pageId: 'MF_REDEEMOTP'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/OTP/mfEnterOTP.html',
						controller: 'redeemController',
						controllerAs: 'redeemVm',
					}
				}
			})
			.state('menu.redeemPaymentSuccess', {
				url: '/redeemPaymentSuccess',
				cache: false,
				data: {
					pageId: 'MF_REDEEMOTPSUCS'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/OTP/paymentSuccess.html',
						controller: 'redeemController',
						controllerAs: 'redeemVm',
					}
				}
			})
			.state('menu.mfEnterOTP', {
				url: '/mfEnterOTP',
				cache: false,
				data: {
					pageId: 'MF_ENTROTP'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/OTP/mfEnterOTP.html',
						controller: 'mfEnterOTPController',
						controllerAs: 'mfEnterOTPVm',
					}
				}
			})
			.state('menu.portfolio', {
				url: '/portfolio',
				cache: false,
				data: {
					pageId: 'MF_PRTFO'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/portfolio/portfolio.html',
						controller: 'portfolioController',
						controllerAs: 'portfolioVm',
					}
				}
			})
			.state('menu.switch', {
				url: '/switch',
				cache: false,
				data: {
					pageId: 'MF_SWCH'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/switch/switch.html',
						controller: 'switchController',
						controllerAs: 'switchVm',
					}
				}
			})
			.state('menu.switchReview', {
				url: '/switchReview',
				data: {
					pageId: 'MF_SWCHRVW'
				},
				cache: false,

				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/switch/switchReview.html',
						controller: 'switchController',
						controllerAs: 'switchVm',
					}
				}
			})
			.state('menu.switchOTP', {
				url: '/switchOTP',
				cache: false,
				data: {
					pageId: 'MF_SWTHOTP'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/OTP/mfEnterOTP.html',
						controller: 'switchController',
						controllerAs: 'switchVm',
					}
				}
			})
			.state('menu.switchPaymentSuccess', {
				url: '/switchPaymentSuccess',
				cache: false,
				data: {
					pageId: 'MF_SWTHPYMTSUCS'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/OTP/paymentSuccess.html',
						controller: 'switchController',
						controllerAs: 'switchVm',
					}
				}
			})
			.state('menu.SWP', {
				url: '/SWP',
				cache: false,
				data: {
					pageId: 'MF_SWP'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/SWP/SWP.html',
						controller: 'SWPController',
						controllerAs: 'SWPControllerVm',
					}
				}
			})
			.state('menu.SWPReview', {
				url: '/SWPReview',
				data: {
					pageId: 'MF_SWPRVW'
				},
				cache: false,

				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/SWP/SWPReview.html',
						controller: 'SWPController',
						controllerAs: 'SWPControllerVm',
					}
				}
			})
			.state('menu.swpOTP', {
				url: '/swpOTP',
				cache: false,
				data: {
					pageId: 'MF_SWPOTP'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/OTP/mfEnterOTP.html',
						controller: 'SWPController',
						controllerAs: 'SWPControllerVm',
					}
				}
			})
			.state('menu.swpPaymentSuccess', {
				url: '/swpPaymentSuccess',
				cache: false,
				data: {
					pageId: 'MF_SWPPYMTSUCS'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/OTP/paymentSuccess.html',
						controller: 'SWPController',
						controllerAs: 'SWPControllerVm',
					}
				}
			})
			.state('menu.STP', {
				url: '/STP',
				cache: false,
				data: {
					pageId: 'MF_STP'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/STP/STP.html',
						controller: 'STPController',
						controllerAs: 'STPVm',
					}
				}
			})
			.state('menu.STPReview', {
				url: '/STPReview',
				data: {
					pageId: 'MF_STPRVW'
				},
				cache: false,

				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/STP/STPReview.html',
						controller: 'STPController',
						controllerAs: 'STPVm',
					}
				}
			})

			.state('menu.stpOTP', {
				url: '/stpOTP',
				cache: false,
				data: {
					pageId: 'MF_STPOTP'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/OTP/mfEnterOTP.html',
						controller: 'STPController',
						controllerAs: 'STPVm',
					}
				}
			})
			.state('menu.stpPaymentSuccess', {
				url: '/stpPaymentSuccess',
				cache: false,
				data: {
					pageId: 'MF_STPPYMTSUCS'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/accountOverview/mutualFunds/OTP/paymentSuccess.html',
						controller: 'STPController',
						controllerAs: 'STPVm',
					}
				}
			})
			//Mutual Funds ends

			//Support started
			.state('menu.support', {
				url: '/support',
				data: {
					pageId: 'SPRT_HOM'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/support/support.html',
						controller: 'supportController',
						controllerAs: 'supportVm'
					}
				}
			})
			.state('menu.raiseQuery', {
				url: '/raiseQuery',
				data: {
					pageId: 'SPRT_RSEQRY'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/support/raiseQuery/raiseQuery.html',
						controller: 'raiseQueryController',
						controllerAs: 'raiseQueryVm'
					}
				}
			})
			.state('menu.categoryWiseQuery', {
				url: '/categoryWiseQuery',
				data: {
					pageId: 'SPRT_CTGWSEQRY'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/support/raiseQuery/categoryWiseQuery/categoryWiseQuery.html',
						controller: 'categoryWiseQueryController',
						controllerAs: 'categoryWiseQueryVm'
					}
				},
				params: { obj: null }
			})
			.state('menu.trackQuery', {
				url: '/trackQuery',
				data: {
					pageId: 'SPRT_TRKQRY'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/support/trackQuery/trackQuery.html',
						controller: 'trackQueryController',
						controllerAs: 'trackQueryVm'
					}
				}
			})
			.state('menu.trackQueryDetails', {
				url: '/trackQueryDetails',
				cache: false,
				data: {
					pageId: 'SPRT_TCKQRYDETL'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/support/trackQuery/trackQueryDetails/trackQueryDetails.html',
						controller: 'trackQueryDetailsController',
						controllerAs: 'trackQueryDetailsVm'
					}
				}, params: { queryObj: null }
			})
			.state('menu.discoverOurFeature', {
				url: '/discoverOurFeature',
				data: {
					pageId: 'SPRT_DISCOURFEAT'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/support/discoverOurFeature/discoverOurFeature.html',
						controller: 'discoverOurFeatureController',
						controllerAs: 'discoverOurFeatureVm'
					}
				}
			})
			.state('menu.contactUs', {
				url: '/contactUs',
				data: {
					pageId: 'SPRT_CTU'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/support/contactUs/contactUs.html',
						controller: 'contactUsController',
						controllerAs: 'contactUsVm'
					}
				}
			})
			.state('menu.FAQ', {
				url: '/FAQ',
				data: {
					pageId: 'SPRT_FAQ'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/support/FAQ/FAQ.html',
						controller: 'FAQController',
						controllerAs: 'FAQVm'
					}
				}
			})

			.state('menu.nfsFaq', {
				url: '/nfsFaq',
				data: {
					pageId: 'SPRT_NFSFAQ'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/support/FAQ/nfsFaq.html',
						controller: 'nfsFaqController',
						controllerAs: 'nfsFaqVm'
					}
				},
				params: { obj: null, obj1: null }
			})

			.state('menu.FAQDetails', {
				url: '/FAQDetails',
				data: {
					pageId: 'SPRT_FAQDETL'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/support/FAQ/FAQDetails/FAQDetails.html',
						controller: 'FAQDetailsController',
						controllerAs: 'FAQDetailsVm'
					}
				},
				params: { obj: null, obj1: null }
			})
			.state('menu.FAQListDetails', {
				url: '/FAQListDetails',
				data: {
					pageId: 'SPRT_FAQLSTDETL'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/support/FAQ/FAQDetails/FAQListDetails.html',
						controller: 'FAQListDetailsController',
						controllerAs: 'FAQListDetailsVm'
					}
				},
				params: { obj: null, obj1: null }

			})
			//Support ends

			//Report start
			.state('menu.report', {
				url: '/report',
				data: {
					pageId: 'RPRT_HOM'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/report/report.html',
						controller: 'reportController',
						controllerAs: 'reportVm'
					}
				},
			})
			//Report ends

			//Personal Loan start
			.state('menu.personalLoan', {
				url: '/personalLoan',
				data: {
					pageId: 'PAPL_HOM'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/personalLoan/personalLoan/personalLoan.html',
						controller: 'personalLoanController',
						controllerAs: 'personalLoanVm'
					}
				},
			})
			.state('menu.plOTP', {
				url: '/plOTP',
				cache: false,
				data: {
					pageId: 'PAPL_PLOTP'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/personalLoan/plOTP/plOTP.html',
						controller: 'plOTPController',
						controllerAs: 'plOTPVm'
					}
				},
			})
			.state('menu.congratulations', {
				url: '/congratulations',
				cache: false,
				data: {
					pageId: 'PAPL_CONG'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/personalLoan/plOTP/congratulations.html',
						controller: 'plOTPController',
						controllerAs: 'plOTPVm'
					}
				},
			})
			.state('menu.emiPayDate', {
				url: '/emiPayDate',
				data: {
					pageId: 'PAPL_EMIPYDT'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/personalLoan/emiPayDate/emiPayDate.html',
						controller: 'emiPayDateController',
						controllerAs: 'emiPayDateVm'
					}
				},
			})
			.state('menu.plTerms', {
				url: '/plTerms',
				data: {
					pageId: 'PAPL_PLTRM'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/personalLoan/plTerms/plTerms.html',
						controller: 'plTermsController',
						controllerAs: 'plTermsVm'
					}
				},
			})
			.state('menu.reviewLoan', {
				url: '/reviewLoan',
				data: {
					pageId: 'PAPL_RVWLON'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/personalLoan/reviewLoan/reviewLoan.html',
						controller: 'reviewLoanController',
						controllerAs: 'reviewLoanVm'
					}
				},
			})
			.state('menu.currentLoan', {
				url: '/currentLoan',
				data: {
					pageId: 'PAPL_CURTLON'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/personalLoan/currentLoan/currentLoan.html',
						controller: 'currentLoanController',
						controllerAs: 'currentLoanVm'
					}
				},
			})

			.state('menu.plPanDob', {
				url: '/plPanDob',
				data: {
					pageId: 'PAPL_PAN_DOB'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/personalLoan/personalLoan/plPanDob.html',
						controller: 'plPanDobController',
						controllerAs: 'plPanDobVm'
					}
				},
			})

			.state('menu.paplKawachDeclaration', {
				url: '/paplKawachDeclaration',
				data: {
					pageId: 'PAPL_KAWACH_DECLARATION'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/personalLoan/personalLoan/kawachDeclaration.html',
						controller: 'kawachDeclarationController',
						controllerAs: 'paplKawachDeclarationVm'
					}
				},
			})

			.state('menu.borrowingsDetails', {
				url: '/borrowingsDetails',
				cache: false,
				data: {
					pageId: 'PAPL_BRWNGSDETL'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/personalLoan/personalLoan/borrowingsDetails.html',
						controller: 'reviewLoanController',
						controllerAs: 'reviewLoanVm'
					}
				},
				params: { profileDetails: null }
			})
			//Personal Loan ends

			// NFS Starts here
			.state('menu.blockUnblock', {
				url: '/blockUnblock',
				data: {
					pageId: 'NFS_BLCKUNBLCK'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/blockUnblock/blockUnblock.html',
						controller: 'blockUnblockController',
						controllerAs: 'blockUnblockVm'
					}
				},
			})
			.state('menu.blockUnblockReview', {
				url: '/blockUnblockReview',
				data: {
					pageId: 'NFS_BLCKUNBLCKRVW'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/blockUnblock/blockUnblockReview.html',
						controller: 'blockUnblockReviewController',
						controllerAs: 'blockUnblockReviewVm'
					}
				},
			})
			.state('menu.blockUnblockOtp', {
				url: '/blockUnblockOtp',
				data: {
					pageId: 'NFS_BLCKUNBLCKOTP'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/blockUnblock/blockUnblockOTP.html',
						controller: 'blockUnblockOtpController',
						controllerAs: 'blockUnblockOtpVm'
					}
				},
			})
			.state('menu.manageAtm', {
				url: '/manageAtm',
				data: {
					pageId: 'NFS_MNGATM'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/manageAtm/manageAtm.html',
						controller: 'manageAtmController',
						controllerAs: 'manageAtmVm'
					}
				},
			})
			.state('menu.manageAtmOtp', {
				url: '/manageAtmOtp',
				data: {
					pageId: 'NFS_MNGATMOTP'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/manageAtm/manageAtmOTP.html',
						controller: 'manageAtmOtpController',
						controllerAs: 'manageAtmOtpVm'
					}
				},
			})
			.state('menu.atmCardActivation', {
				url: '/atmCardActivation',
				data: {
					pageId: 'NFS_ATMCRDACTN'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/atmCardActivation/atmCardActivation.html',
						controller: 'atmCardActivationController',
						controllerAs: 'atmCardActivationVm'
					}
				},
			})
			.state('menu.atmCardActivationOtp', {
				url: '/atmCardActivationOtp',
				data: {
					pageId: 'NFS_ATMCRDACTNOTP'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/atmCardActivation/atmCardActivationOTP.html',
						controller: 'atmCardActivationOtpController',
						controllerAs: 'atmCardActivationOtpVm'
					}
				},
			})
			.state('menu.newDebitCard', {
				url: '/newDebitCard',
				data: {
					pageId: 'NFS_NWDBTCRD'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/newDebitCard/newDebitCard.html',
						controller: 'newDebitCardController',
						controllerAs: 'newDebitCardVm'
					}
				},
			})
			.state('menu.newDebitCardOtp', {
				url: '/newDebitCardOtp',
				data: {
					pageId: 'NFS_NWDBTCRDOTP'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/newDebitCard/newDebitCardOTP.html',
						controller: 'newDebitCardOtpController',
						controllerAs: 'newDebitCardOtpVm'
					}
				},
			})
			.state('menu.profilePwd', {
				url: '/profilePwd',
				data: {
					pageId: 'NFS_PRFPWD'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/serviceRequest/profilePwd.html',
						controller: 'profilePasswordController',
						controllerAs: 'profilePasswordVm'
					}
				},
			})
      
			// NFS ends here
			.state('menu.smsAlertActivation', {
				url: '/smsAlertActivation',
				data: {
					pageId: 'NFS_SMS_ALERT'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/smsAlertActivation/smsAlertActivation.html',
						controller: 'smsAlertActivationController',
						controllerAs: 'smsAlertActivationVm'
					}
				},
			})
			//SMS activation End here
				//Change Account Type Starts here
			.state('menu.selAccToEnableChangeAcc', {
				url: '/selAccToEnableChangeAcc',
				data: {
					pageId: 'NFS_CHNGACCTYPEENABLECB'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/changeAccountType/selAccToEnableCB.html',
						controller: 'selAccToEnableCBController',
						controllerAs: 'selAccToEnableCBVm'
					}
				},
			})

			.state('menu.changeAccTypeOtp', {
				url: '/changeAccTypeOtp',
				data: {
					pageId: 'NFS_CHNGACCTYPEOTP'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/changeAccountType/changeAccTypeOtp.html',
						controller: 'changeAccTypeOtpController',
						controllerAs: 'changeAccTypeOtpVm'
					}
				},
			})



			//Change Account Type Ends here
			//INB Forgot Passwrd Starts here
			//INB Forgot Password Starts here
			.state('menu.inbForgotPassword', {
				url: '/inbForgotPassword',
				data: {
					pageId: 'NFS_INB_FORGOT_PW'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/inbForgotPassword/inbForgotPassword.html',
						controller: 'inbForgotPasswordController',
						controllerAs: 'inbForgotPasswordVm'
					}
				},
			})

			.state('menu.setPassword', {
				url: '/setPassword',
				data: {
					pageId: 'NFS_INB_SET_PW'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/inbForgotPassword/setPassword.html',
						controller: 'setPasswordController',
						controllerAs: 'setPasswordVm'
					}
				},
			})

			.state('menu.forgotPasswordOtp', {
				url: '/forgotPasswordOtp',
				data: {
					pageId: 'NFS_INB_FORGOT_PW_OTP'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/inbForgotPassword/forgotPasswordOtp.html',
						controller: 'forgotPasswordOtpController',
						controllerAs: 'forgotPasswordOtpVm'
					}
				},
			})
			//INB Forgot Passwrd End here



			//INB Reset Passwrd Starts here
			.state('menu.inbResetPassword', {
				url: '/inbResetPassword',
				data: {
					pageId: 'NFS_INB_RESET_PW'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/inbResetPassword/inbResetPassword.html',
						controller: 'inbResetPasswordController',
						controllerAs: 'inbResetPasswordVm'
					}
				},
			})
			.state('menu.resetPassword', {
				url: '/resetPassword',
				data: {
					pageId: 'NFS_INB_RESET_PWD'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/inbResetPassword/resetPassword.html',
						controller: 'resetPasswordController',
						controllerAs: 'resetPasswordVm'
					}
				},
			})

			.state('menu.resetPasswordOtp', {
				url: '/resetPasswordOtp',
				data: {
					pageId: 'NFS_INB_RESET_PWD_OTP'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/inbResetPassword/resetPasswordOtp.html',
						controller: 'resetPasswordOtpController',
						controllerAs: 'resetPasswordOtpVm'
					}
				},
			})


			//INB Reset Passwrd Ends here
			/* Forgot Profile Passwrd start here */
			/* Forgot Profile password start here */

			.state('menu.forgotProfilePwd', {
				url: '/forgotProfilePwd',
				data: {
					pageId: 'NFS_FORGOT_PWD'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/forgotProfilePassword/forgotProfilePwd.html',
						controller: 'forgotProfilePwdController',
						controllerAs: 'forgotProfilePwdVm'
					}
				},
			})

			.state('menu.resetProfilePwd', {
				url: '/resetProfilePwd',
				data: {
					pageId: 'NFS_RESET_PWD'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/forgotProfilePassword/resetProfilePwd.html',
						controller: 'resetProfilePwdController',
						controllerAs: 'resetProfilePwdVm'
					}
				},
			})

			.state('menu.forgotProfilePwdOtp', {
				url: '/forgotProfilePwdOtp',
				data: {
					pageId: 'NFS_FORGOT_PWD_OTP'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/forgotProfilePassword/forgotProfilePwdOTP.html',
						controller: 'forgotProfilePwdOtpController',
						controllerAs: 'forgotProfilePwdOtpVm'
					}
				},
			})

			/* Forgot Profile Passwrd End here */

			/* INB Lock Unlock Access starts here */
			.state('menu.inbLockAccessDeatils', {
				url: '/inbLockAccessDeatils',
				data: {
					pageId: 'NFS_IN_LOCK_ACCESS_DETAILS'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/inbLockUnlockAccess/LockAccess/inbLockAccessDeatils.html',
						controller: 'inbLockAccessDeatilsController',
						controllerAs: 'inbLockAccessDeatilsVm'
					}
				},
			})
			.state('menu.inbLockAccessOtp', {
				url: '/inbLockAccessOtp',
				data: {
					pageId: 'NFS_IN_LOCK_ACCESS_OTP'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/inbLockUnlockAccess/LockAccess/inbLockAccessOtp.html',
						controller: 'inbLockAccessOtpController',
						controllerAs: 'inbLockAccessOtpVm'
					}
				},
			})
				.state('menu.inbUnlockAccessDetails', {
				url: '/inbUnlockAccessDetails',
				data: {
					pageId: 'NFS_INB_UNLOCK_ACCESS'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/inbLockUnlockAccess/UnlockAccess/inbUnlockAccessDetails.html',
						controller: 'inbUnlockAccessDetailsController',
						controllerAs: 'inbUnlockAccessDetailsVm'
					}
				},
			})
			 	.state('menu.inbUnlockSetNewPassword', {
				url: '/inbUnlockSetNewPassword',
				data: {
					pageId: 'NFS_INB_UNLOCK_SET_NEW_PWD'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/inbLockUnlockAccess/UnlockAccess/inbUnlockSetNewPassword.html',
						controller: 'inbUnlockSetNewPasswordController',
						controllerAs: 'inbUnlockSetNewPasswordVm'
					}
				},
			})
			 	.state('menu.inbUnLockAccessOtp', {
				url: '/inbUnLockAccessOtp',
				data: {
					pageId: 'NFS_INB_UNLOCK_OTP'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/inbLockUnlockAccess/UnlockAccess/inbUnLockAccessOtp.html',
						controller: 'inbUnLockAccessOtpController',
						controllerAs: 'inbUnLockAccessOtpVm'
					}
				},
			})

			/* INB Lock Unlock Access End here */

			//SI CREATION STARTS FROM HERE
			   .state('menu.cancelSi', {
                url: '/cancelSi',
                cache: false,
                data: {
                    pageId: 'OD_SCHEDULED_REQ'
                },
                views: {
                    'menuContent': {
                        templateUrl: 'pages/nfs/siCreationAndCancellation/cancelSi.html',
                        controller: 'cancelSiController',
                        controllerAs: 'cancelSiVm',
                    }
                }
            })

			   .state('menu.siSelAccount', {
                url: '/siSelAccount',
                cache: false,
                data: {
                    pageId: 'SI_SETNEW'
                },
                views: {
                    'menuContent': {
                        templateUrl: 'pages/nfs/siCreationAndCancellation/selAccount.html',
                        controller: 'selAccountController',
                        controllerAs: 'selAccountVm',
                    }
                }
            })
			   .state('menu.siLanding', {
                url: '/siLanding',
                cache: false,
                data: {
                    pageId: 'SI_SETNEW'
                },
                views: {
                    'menuContent': {
                        templateUrl: 'pages/nfs/siCreationAndCancellation/siLanding.html',
                        controller: 'siLandingController',
                        controllerAs: 'siLandingVm',
                    }
                }
            })
				.state('menu.siSelFrequency', {
                url: '/siSelFrequency',
                cache: false,
                data: {
                    pageId: 'SI_SELECT_FREQUENCY'
                },
                views: {
                    'menuContent': {
                        templateUrl: 'pages/nfs/siCreationAndCancellation/selFrequency.html',
                        controller: 'selFrequencyController',
                        controllerAs: 'selFrequencyVm',
                    }
                }
            })
				   .state('menu.siReview', {
                url: '/siReview',
                cache: false,
                data: {
                    pageId: 'SI_REVIEW'
                },
                views: {
                    'menuContent': {
                        templateUrl: 'pages/nfs/siCreationAndCancellation/siReview.html',
                        controller: 'siReviewController',
                        controllerAs: 'siReviewVm',
                    }
                }
            })
				   .state('menu.siSchedule', {
                url: '/siSchedule',
                cache: false,
                data: {
                    pageId: 'SI_SHCEDULE'
                },
                views: {
                    'menuContent': {
                        templateUrl: 'pages/nfs/siCreationAndCancellation/siSchedule.html',
                        controller: 'siScheduleController',
                        controllerAs: 'siScheduleVm',
                    }
                }
            })
				.state('menu.siCreationOtp', {
                url: '/siCreationOtp',
                cache: false,
                data: {
                    pageId: 'SI_OTP'
                },
                views: {
                    'menuContent': {
                        templateUrl: 'pages/nfs/siCreationAndCancellation/siCreationOtp.html',
                        controller: 'siCreationOtpController',
                        controllerAs: 'siCreationOtpVm',
                    }
                }
            })
			   .state('menu.siViewCancel', {
                url: '/siViewCancel',
                cache: false,
                data: {
                    pageId: 'SI_VIEW'
                },
                views: {
                    'menuContent': {
                        templateUrl: 'pages/nfs/siCreationAndCancellation/siViewCancel.html',
                        controller: 'siViewCancelController',
                        controllerAs: 'siViewCancelVm',
                    }
                }
            })



			//SI CREATION STARTS FROM HERE



			//Nominee Management starts from here
			.state('menu.ppfAccSelType', {
                url: '/ppfAccSelType',
                cache: false,
                data: {
                    pageId: 'SI_OTP'
                },
                views: {
                    'menuContent': {
                        templateUrl: 'pages/nfs/nomineeManagement/ppfAccSelType.html',
                        controller: 'ppfAccSelTypeController',
                        controllerAs: 'ppfAccSelTypeVm',
                    }
                }
            })
					.state('menu.editNominee', {
                url: '/editNominee',
                cache: false,
                data: {
                    pageId: 'SI_OTP'
                },
                views: {
                    'menuContent': {
                        templateUrl: 'pages/nfs/nomineeManagement/editNominee.html',
                        controller: 'editNomineeController',
                        controllerAs: 'editNomineeVm',
                    }
                }
            })
					.state('menu.maangeNomineeSuccess', {
                url: '/maangeNomineeSuccess',
                cache: false,
                data: {
                    pageId: 'NOM_SUCCESS'
                },
                views: {
                    'menuContent': {
                        templateUrl: 'pages/nfs/nomineeManagement/maangeNomineeSuccess.html',
                        controller: 'maangeNomineeSuccessController',
                        controllerAs: 'maangeNomineeSuccessVm',
                    }
                }
            })

			//Nominee Management starts ends here



			// Cheque book joureny starts here
			.state('menu.chequeEnquiry', {
				url: '/chequeEnquiry',
				data: {
					pageId: 'NFS_CHQEENQY'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/chequeEnquiry/chequeEnquiry.html',
						controller: 'chequeEnquiryController',
						controllerAs: 'chequeEnquiryVm'
					}
				},
			})
			.state('menu.chequeEnquiryResult', {
				url: '/chequeEnquiryResult',
				data: {
					pageId: 'NFS_CHQEENQYRSLT'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/chequeEnquiry/chequeEnquiryResult.html',
						controller: 'chequeEnquiryResultController',
						controllerAs: 'chequeEnquiryResultVm'
					}
				},
			})
			// Cheque book joureny ends here

			// Request cheque book starts here
			.state('menu.requestChequeBook', {
				url: '/requestChequeBook',
				data: {
					pageId: 'NFS_RQSTCHQEBOOK'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/requestChequeBook/requestChequeBook.html',
						controller: 'requestChequeBookController',
						controllerAs: 'requestChequeBookVm'
					}
				},
			})
			.state('menu.requestAddressChequeBook', {
				url: '/requestAddressChequeBook',
				data: {
					pageId: 'NFS_RQSTADRSCHQEBOOK'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/requestChequeBook/requestAddressChequeBook.html',
						controller: 'requestAddressChequeBookController',
						controllerAs: 'requestAddressChequeBookVm'
					}
				},
			})
			.state('menu.requestReviewChequeBook', {
				url: '/requestReviewChequeBook',
				data: {
					pageId: 'NFS_RQSTRVWCHQEBOOK'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/requestChequeBook/requestReviewChequeBook.html',
						controller: 'requestReviewChequeBookController',
						controllerAs: 'requestReviewChequeBookVm'
					}
				},
			})
			.state('menu.stopCheque', {
				url: '/stopCheque',
				data: {
					pageId: 'NFS_STPCHEQUE'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/stopCheque/stopCheque.html',
						controller: 'stopChequeController',
						controllerAs: 'stopChequeVm'
					}
				},
			})
			.state('menu.stopChequeReview', {
				url: '/stopChequeReview',
				data: {
					pageId: 'NFS_STPCHEQUERVW'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/stopCheque/stopChequeReview.html',
						controller: 'stopChequeReviewController',
						controllerAs: 'stopChequeReviewVm'
					}
				},
			})
			.state('menu.revokeCheque', {
				url: '/revokeCheque',
				data: {
					pageId: 'NFS_REVKCHEQUE'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/revokeCheque/revokeCheque.html',
						controller: 'revokeChequeController',
						controllerAs: 'revokeChequeVm'
					}
				},
			})
			.state('menu.revokeChequeReview', {
				url: '/revokeChequeReview',
				data: {
					pageId: 'NFS_REVKCHEQUERVW'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/revokeCheque/revokeChequeReview.html',
						controller: 'revokeChequeReviewController',
						controllerAs: 'revokeChequeReviewVm'
					}
				},
			})
			// Request cheque book ends here
			
			// Personal details starts here

			.state('menu.emailDetails', {
				url: '/emailDetails',
				data: {
					pageId: 'NFS_PRSNLDETLS'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/emailUpdate/emailDetails.html',
						controller: 'emailDetailsController',
						controllerAs: 'emailDetailsVm'
					}
				},
			})

			.state('menu.emailUpdate', {
				url: '/emailUpdate',
				data: {
					pageId: 'NFS_EMAILUPDATE'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/emailUpdate/emailUpdate.html',
						controller: 'emailUpdateController',
						controllerAs: 'emailUpdateVm'
					}
				},
			})

			.state('menu.emailUpdateOtp', {
				url: '/emailUpdateOtp',
				data: {
					pageId: 'NFS_EMAILUPDATEOTP'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/emailUpdate/emailUpdateOTP.html',
						controller: 'emailUpdateOtpController',
						controllerAs: 'emailUpdateOtpVm'
					}
				},
			})
			.state('menu.emailUpdateOtpNew', {
				url: '/emailUpdateOtpNew',
				data: {
					pageId: 'NFS_EMAIL_UPDATE_OTP_NEW'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/emailUpdate/emailUpdateOTPNew.html',
						controller: 'emailUpdateOTPNewController',
						controllerAs: 'emailUpdateOtpNewVm'
					}
				},
			})

			//Notifications starts here
			//Notifications starts here
			.state('menu.notifications', {
				url: '/notifications',
				data: {
					pageId: 'NTFN_HOM'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/notifications/notifications.html',
						controller: 'notificationsController',
						controllerAs: 'notificationsVm',
					}
				}
			})
			//Notifications ends here

			//Book and Order start
			.state('menu.bookings', {
				url: '/bookings',
				data: {
					pageId: 'OMP_BKNG'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/bookAndOrder/bookings/bookings.html',
						controller: 'bookingsController',
						controllerAs: 'bookingsVm',
					}
				}
			})
			.state('menu.bookingList', {
				url: '/bookingList',
				data: {
					pageId: 'OMP_BKNGLST'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/bookAndOrder/bookingList/bookingList.html',
						controller: 'bookingListController',
						controllerAs: 'bookingListVm',
					}
				}
			})
			//Book and Order ends

			// Pre home login starts here
			.state('menu.payments', {
				url: '/payments',
				data: {
					pageId: 'PHL_PAYMENTS'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/preHomeLogin/payments.html',
						controller: 'paymentsController',
						controllerAs: 'paymentsVm'
					}
				}
			})
			.state('menu.preHomeLogin', {
				url: '/preHomeLogin',
				data: {
					pageId: 'PHL_HOM'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/preHomeLogin/preHomeLogin.html',
						controller: 'preHomeLoginController',
						controllerAs: 'preHomeLoginVm'
					}
				}
			})
			.state('menu.existingCustomer', {
				url: '/preHomeLogin',
				data: {
					pageId: 'PHL_HOM'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/preHomeLogin/existingCustomer.html',
						controller: 'preHomeLoginController',
						controllerAs: 'preHomeLoginVm'
					}
				}
			})
			.state('menu.grabOffers', {
				url: '/preHomeLogin',
				data: {
					pageId: 'PHL_HOM'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/preHomeLogin/grabOffers.html',
						controller: 'grabOffersController',
						controllerAs: 'grabOffersvm'
					}
				}
			})
			.state('menu.rootedDevice', {
				url: '/rootedDevicepage',
				data: {
					pageId: 'PHL_ROTDDEVC'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/preHomeLogin/rootedDevicepage.html',
						controller: 'rootedDeviceController'
					}
				}
			})
			.state('menu.financialProducts', {
				url: '/products',
				data: {
					pageId: 'PHL_PRDCT'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/preHomeLogin/products.html',
						controller: 'productsController',
						controllerAs: 'productsVm'
					}
				}
			})

			.state('menu.loansLanding', {
	                    url: '/loansLanding',
	                    data: {
                        pageId: 'LO_LNDNG'
	                    },
	                    cache: false,
	                    views: {
	                        'menuContent': {
	                            templateUrl: 'pages/loans/loansLanding.html',
	                            controller: 'loansLandingController',
	                            controllerAs: 'loansLandingVm'
	                        }
	                    }
	                })
			.state('menu.Investments', {
				url: '/investment',
				data: {
					pageId: 'PHL_INVSTMT'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/preHomeLogin/investment.html',
						controller: 'investmentController',
						controllerAs: 'investmentVm'
					}
				}
			})
			.state('menu.openNewDigitalAccount', {
				url: '/openNewDigitalAccount',
				data: {
					pageId: 'PHL_OPNNWDGTLACCT'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/preHomeLogin/openNewDigitalAccount.html',
						controller: 'openNewDigitalAccountController',
						controllerAs: 'openNewDigitalAccountVm'
					}
				}
			})
			.state('menu.inbLogin', {
				url: '/inbLogin',
				data: {
					pageId: 'PHL_INBLGN'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/preHomeLogin/InternetBanking/inbLogin.html',
						controller: 'inbLoginController',
						controllerAs: 'inbLoginVm'
					}
				},
				params: { previousPage: null }
			})
			.state('menu.setMPIN', {
				url: '/setMPIN',
				data: {
					pageId: 'PHL_SETMPIN'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/preHomeLogin/InternetBanking/setMPIN.html',
						controller: 'setMPINController',
						controllerAs: 'setMPINVm'
					}
				}
			})
			.state('menu.mpinConsent', {
				url: '/mpinConsent',
				data: {
					pageId: 'PHL_MPINCNSNT'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/preHomeLogin/InternetBanking/mpinConsent.html',
						controller: 'mpinConsentController',
						controllerAs: 'mpinConsentVm'
					}
				},
				params: { previousJourney: null }
			})
			.state('menu.loginTermsAndConditions', {
				url: '/loginTermsAndConditions',
				data: {
					pageId: 'PHL_LGNTNC'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/preHomeLogin/loginTermsAndConditions.html',
						controller: 'loginTnCController',
						controllerAs: 'loginTnCVm'
					}
				},
				params: { obj: null }
			})
			.state('menu.setMPINOTP', {
				url: '/setMPINOTP',
				data: {
					pageId: 'PHL_SETMPINOTP'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/preHomeLogin/InternetBanking/setMPINOTP.html',
						controller: 'setMPINOTPController',
						controllerAs: 'setMPINOTPVm'
					}
				},
				params: { mpin: null, simInfo: null }
			})
			.state('menu.userLogin', {
				url: '/userLogin',
				data: {
					pageId: 'PHL_USRLGN'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/preHomeLogin/InternetBanking/userLogin.html',
						controller: 'userLoginController',
						controllerAs: 'userLoginVm'
					}
				}
			})
			.state('menu.ompOffers', {
			url: '/ompOffers',
			data: {
				pageId: 'OMP_OFFERS'
			},
			cache: false,
			views: {
				'menuContent': {
					templateUrl: 'pages/ompOffers/ompOffers.html',
					controller: 'ompOffersController',
					controllerAs: 'ompOffersControllerVm',
				}
			}
		})
		.state('menu.ompDisclaimer', {
			url: '/ompDisclaimer',
			data: {
				pageId: 'OMP_DISCLAIMER'
			},
			cache: false,
			views: {
				'menuContent': {
					templateUrl: 'pages/ompOffers/disclaimerPopup.html',
					controller: 'ompOffersController',
					controllerAs: 'ompOffersControllerVm',
				}
			}
		})
			.state('menu.accountDetailsPage', {
				url: '/accountDetailsPage',
				cache: false,
				data: {
					pageId: 'PHL_ACCTDETLPG'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/preHomeLogin/AccountDetails/accountDetailsPage.html',
						controller: 'accountDetailsController',
						controllerAs: 'accountDetailsVm'
					}
				}
			})
			.state('menu.accAndBankDetails', {
				url: '/accAndBankDetails',
				cache: false,
				data: {
					pageId: 'PHL_ACCTBNKDETL'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/preHomeLogin/AccountDetails/accAndBankDetails.html',
						controller: 'accAndBankDetailsController',
						controllerAs: 'accAndBankDetailsVm'
					}
				},
				params: { accAndBankDetails: null, atmDetails: null }
			})
			.state('menu.generateOTP', {
				url: '/generateOTP',
				cache: false,
				data: {
					pageId: 'PHL_GNRTOTP'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/preHomeLogin/AccountDetails/generateOTP.html',
						controller: 'generateOTPController',
						controllerAs: 'generateOTPVm'
					}
				},
				params: { accAndBankDetails: null, atmDetails: null }
			})
			.state('menu.setTemporaryPassword', {
				url: '/setTemporaryPassword',
				cache: false,
				data: {
					pageId: 'PHL_SETTMPPWD'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/preHomeLogin/AccountDetails/setTemporaryPassword.html',
						controller: 'setTemporaryPasswordController',
						controllerAs: 'setTemporaryPasswordVm'
					}
				}
			})
			.state('menu.generateUserName', {
				url: '/generateUserName',
				cache: false,
				data: {
					pageId: 'PHL_GNRTUSRNAM'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/preHomeLogin/AccountDetails/generateUserName.html',
						controller: 'generateUserNameController',
						controllerAs: 'generateUserNameVm'
					}
				}
			})
			.state('menu.setUserName', {
				url: '/setUserName',
				cache: false,
				data: {
					pageId: 'PHL_SETUSRNAM'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/preHomeLogin/AccountDetails/setUserName.html',
						controller: 'setUserNameController',
						controllerAs: 'setUserNameVm'
					}
				}
			})
			.state('menu.generateMPIN', {
				url: '/generateMPIN',
				cache: false,
				data: {
					pageId: 'PHL_GNRTMPIN'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/preHomeLogin/AccountDetails/generateMPIN.html',
						controller: 'generateMPINController',
						controllerAs: 'generateMPINVm'
					}
				}
			})
			.state('menu.atmCardNumber', {
				url: '/atmCardNumber',
				cache: false,
				data: {
					pageId: 'PHL_ATM_CARD_NUMBER'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/preHomeLogin/AccountDetails/atmCardNumber.html',
						controller: 'atmCardNumberController',
						controllerAs: 'atmCardNumberVm'
					}
				}
			})
			.state('menu.atmCardPin', {
				url: '/atmCardPin',
				cache: false,
				data: {
					pageId: 'PHL_ATM_CARD_PIN'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/preHomeLogin/AccountDetails/atmCardPin.html',
						controller: 'atmCardPinController',
						controllerAs: 'atmCardPinVm'
					}
				}
			})
			.state('menu.setProfilePassword', {
				url: '/setProfilePassword',
				cache: false,
				data: {
					pageId: 'PHL_SETPRFPWD'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/preHomeLogin/InternetBanking/setProfilePassword.html',
						controller: 'setProfilePasswordController',
						controllerAs: 'setProfilePasswordVm'
					}
				}
			})
			.state('menu.securityQuestions', {
				url: '/securityQuestions',
				cache: false,
				data: {
					pageId: 'PHL_SECQSTN'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/preHomeLogin/InternetBanking/securityQuestions.html',
						controller: 'securityQuestionsController',
						controllerAs: 'securityQuestionsVm'
					}
				},
				params: { profileDetails: null }
			})
			.state('menu.landingPage', {
				url: '/landingPage',
				cache: false,
				data: {
					pageId: 'PHL_LNDG'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/landing/landing.html',
						controller: 'landingController',
						controllerAs: 'landingVm'
					}
				},
				params: { profileDetails: null }
			})
			// Pre home login ends here

			// Feedback starts here
			.state('menu.feedback', {
				url: '/feedback',
				data: {
					pageId: 'PHL_FEDBCK'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/Feedback/feedback.html',
						controller: 'feedbackController',
						controllerAs: 'feedbackVm'
					}
				}
			})
			//Feedback End

			//Terms and conditions Start
			.state('menu.termsandconditions', {
				url: '/termsandconditions',
				data: {
					pageId: 'PHL_TNC'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/preHomeLogin/InternetBanking/termsConditions.html',
						controller: 'termsandconditionsController',
						controllerAs: 'termsandconditionsVm'
					}
				}
			})
			//Terms and conditions End

			//privacyPolicy Start
			.state('menu.privacypolicy', {
				url: '/privacypolicy',
				data: {
					pageId: 'PHL_PRIVYPOLCY'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/preHomeLogin/InternetBanking/privacyPolicy.html',
						controller: 'privacyPolicyController',
						controllerAs: 'privacyPolicyVm'
					}
				}
			})
			//TprivacyPolicy End

			//ChatBot Start
			.state('menu.chatbot', {
				url: '/chatbot',
				data: {
					pageId: 'PHL_CHTBOT'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/chatBot/chatBot.html',
						controller: 'chatBotController',
						controllerAs: 'chatBotVm'
					}
				}
			})
			.state('menu.chatbotsecuritytip', {
				url: '/chatbot',
				data: {
					pageId: 'PHL_CHTBOT_SECURITYTIP'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/chatBot/chatBotSecurityTip.html',
						controller: 'chatBotSecurityTipController',
						controllerAs: 'chatBotSecurityTipVm'
					}
				}
			})
			.state('menu.chatbotlanding', {
				url: '/chatbotlanding',
				data: {
					pageId: 'PHL_CHTBOT_LANDING'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/chatBot/chatBotLanding.html',
						controller: 'chatBotLandingController',
						controllerAs: 'chatBotLandingVm'
					}
				}
			})
			.state('menu.chatbotwhatcanido', {
				url: '/chatbotwhatcanido',
				data: {
					pageId: 'PHL_CHTBOT_WATCANIDO'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/chatBot/chatBotWhatCanIDo.html',
						controller: 'chatBotWhatCanIDotController',
						controllerAs: 'chatBotWhatCanIDoVm'
					}
				}
			})
			.state('menu.chatbotwhatcanidoDetail', {
				url: '/chatbotwhatcanido',
				data: {
					pageId: 'PHL_CHTBOT_WATCANIDO_DTL'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/chatBot/chatBotWhatCanIDoDetail.html',
						controller: 'chatBotWhatCanIDoDetailController',
						controllerAs: 'chatBotWhatCanIDoDetailVm'
					}
				}
			})
			.state('menu.chatbotwhatsnew', {
				url: '/chatbotwhatcanido',
				data: {
					pageId: 'PHL_CHTBOT_WATSNEW'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/chatBot/chatBotWhatsNew.html',
						controller: 'chatBotWhatsNewController',
						controllerAs: 'chatBotWhatsNewVm'
					}
				}
			})
			//ChatBot End

			//ChatBot Feedback Start
			.state('menu.chatbotfeedback', {
				url: '/chatbotfeedback',
				data: {
					pageId: 'PHL_CHTBOTFEDBCK'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/chatBot/chatBotFeedback.html',
						controller: 'chatBotFeedbackController',
						controllerAs: 'chatBotFeedbackVm'
					}
				}
			})
			// ChatBot Feedback ends here

			// Service request starts here
			.state('menu.serviceRequest', {
				url: '/serviceRequest',
				data: {
					pageId: 'HM_SRVCRQST'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/serviceRequest/serviceRequest.html',
						controller: 'serviceRequestController',
						controllerAs: 'serviceRequestVm'
					}
				}
			})
			.state('menu.innerPage', {
				url: '/innerPage',
				data: {
					pageId: 'HM_SRVCRQSTINRPG'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/serviceRequest/innerPage.html',
						controller: 'serviceRequestInnerController',
						controllerAs: 'serviceRequestInnerVm'
					}
				}
			})
			// Service request end here

			// Scheduled requests starts here
			.state('menu.scheduledRequests', {
				url: '/serviceRequest',
				data: {
					pageId: 'HM_SCHDULDRQST'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/serviceRequest/scheduledRequests.html',
						controller: 'scheduledRequestsController',
						controllerAs: 'scheduledRequestVm'
					}
				}
			})
			.state('menu.scheduledIHLDetails', {
				url: '/scheduledIHLDetails',
				data: {
					pageId: 'IHL_SCHDULDFDRQST'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/serviceRequest/scheduledInstaDetails.html',
						controller: 'scheduledInstaDetailsController',
						controllerAs: 'scheduledInstaDetailsVm'
					}
				}
			})
			// Scheduled requests end
			// START Scheduled  ISSUE NEW DEBIT CARD Details Start HERE
			.state('menu.scheduledNewDebitCard', {
				url: '/scheduledNewDebitCard',
				data: {
					pageId: 'HM_SCHDULDNEWDEBTCRD'
				},
				views: {
					'menuContent' :{
						templateUrl: 'pages/serviceRequest/scheduledNewDebitCard.html',
						controller: 'scheduledNewDebitCardController',
						controllerAs:'scheduledNewDebitCardVm'
					}
				}
			})
			.state('menu.scheduledRDDetails', {
				url: '/scheduledRDDetails',
				data: {
					pageId: 'HM_SCHDULDRDDETLS'
				},
				views: {
					'menuContent' :{
						templateUrl: 'pages/serviceRequest/scheduledRDDetails.html',
						controller: 'scheduledRDDetailsController',
						controllerAs:'scheduledRDDetailsVm'
					}
				}
			})

	   		// END Scheduled  ISSUE NEW DEBIT CARD Details Start HERE
			// Scheduled FD details starts here
			.state('menu.scheduledFdDetails', {
				url: '/serviceRequest',
				data: {
					pageId: 'HM_SCHDULDFDRQST'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/serviceRequest/scheduledFdDetails.html',
						controller: 'scheduledFdDetailsController',
						controllerAs: 'scheduledFdDetailsVm'
					}
				}
			})
			//Scheduled FD details ends here
			.state('menu.haveInternetBanking', {
				url: '/haveInternetBanking',
				data: {
					pageId: 'PHL_HAVEACC'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/preHomeLogin/haveInternetBanking.html',
						controller: 'haveInternetBankingController',
						controllerAs: 'haveInternetBankingControllerVm'
					}
				}
			})
		//PPF Eligibilty Starts here
			.state('menu.ppfEligibility', {
				url: '/ppfEligibility',
				data: {
					pageId: 'NFS_PPFELIGIBILITY'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/ppfEligibility/ppfEligibility.html',						
						controller: 'ppfEligibilityController',
						controllerAs: 'ppfEligibilityVm',
					}
				}, params: { dreamsObj: null }
			})			
		//PPF Eligibilty ends here
			.state('menu.needHelp', {
				url: '/needHelp',
				data: {
					pageId: 'NEEDHELP'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/preHomeLogin/needHelp/needHelp.html',
						controller: 'needHelpController',
						controllerAs: 'needHelpVm'
					}
				}
			})
			// manage rights start here

			.state('menu.manageRights', {
				url: '/manageRights',
				data: {
					pageId: 'NFS_MANAGE_RIGHTS'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/manageTransactionRights/manageRights.html',
						controller: 'manageRightsController',
						controllerAs: 'manageRightsVm'
					}
				},
			})

			.state('menu.editManageRights', {
				url: '/editManageRights',
				data: {
					pageId: 'NFS_EDIT_MANAGE_RIGHTS'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/manageTransactionRights/editManageRights.html',
						controller: 'editManageRightsController',
						controllerAs: 'editManageRightsVm'
					}
				},
			})			

            .state('menu.validateProfilePwd', {
                url: '/validateProfilePwd',
                data: {
                    pageId: 'NFS_VALIDATE_PROFILE_PWD'
                },
                cache: false,
                views: {
                    'menuContent': {
                        templateUrl: 'pages/nfs/manageTransactionRights/validateProfilePwd.html',
                        controller: 'validateProfilePwdController',
                        controllerAs: 'validateProfilePwdVm'
                    }
                },
            })

            .state('menu.manageTxnRights_SuccessPopUp', {
                url: '/manageTxnRights_SuccessPopUp',
                data: {
                    pageId: 'NFS_SUCCESS_POP_UP_MANAGE_RIGHTS'
                },
                cache: false,
                views: {
                    'menuContent': {
                        templateUrl: 'pages/nfs/manageTransactionRights/manageTxnRights_SuccessPopUp.html',
                        controller: 'editManageRightsController',
                        controllerAs: 'editManageRightsVm'
                    }
                },
            })
			//Overdraft Closure & OD Repayment Starts here
	    //BHIM UPI STARTS HERE
			.state('menu.createNewVpa', {
				url: '/createNewVpa',
				data: {
					pageId: 'CREATEVPA'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/Registration/createNewVpa.html',
						controller: 'createNewVpaController',
						controllerAs: 'createNewVpaVm'
					}
				}
			})
			.state('menu.selectNumber', {
				url: '/selectNumber',
				data: {
					pageId: 'SELECTNUM'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/Registration/selectNumber.html',
						controller: 'selectNumberController',
						controllerAs: 'selectNumberVm'
					}
				}
			})
			.state('menu.selectBank', {
				url: '/selectBank',
				data: {
					pageId: 'SELECTBANK'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/Registration/selectBank.html',
						controller: 'selectBankController',
						controllerAs: 'selectBankVm'
					}
				}
			})
			.state('menu.fundtrans', {
				url: '/fundtrans',
				data: {
					pageId: 'FUNDTRANS'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/fundtrans.html',
						controller: 'fundtransController',
						controllerAs: 'fundtransVm'
					}
				}
			})
			.state('menu.vpaOptions', {
				url: '/vpaOptions',
				data: {
					pageId: 'VPAOPTIONS'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/Registration/vpaOptions.html',
						controller: 'vpaOptionsController',
						controllerAs: 'vpaOptionsVm'
					}
				}
			})
			.state('menu.fetchMyVpa', {
				url: '/fetchMyVpa',
				data: {
					pageId: 'FETCHMYVPA'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/Registration/fetchMyVpa.html',
						controller: 'fetchMyVpaController',
						controllerAs: 'fetchMyVpaVm'
					}
				}
			})
			.state('menu.upiRegistrationSuccess', {
				url: '/upiRegistrationSuccess',
				data: {
					pageId: 'REGISTRATIONSUCCESS'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/Registration/upiRegistrationSuccess.html',
						controller: 'upiRegistrationSuccessController',
						controllerAs: 'upiRegistrationSuccessVm'
					}
				}
			})
			.state('menu.deRegister', {
				url: '/deRegister',
				data: {
					pageId: 'DEREGISTER'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/Manage/UPI/De-Register/deRegister.html',
						controller: 'deRegisterController',
						controllerAs: 'deRegisterVm'
					}
				}
			})
			.state('menu.payToVpa', {
				url: '/payToVpa',
				data: {
					pageId: 'UPI_PAY_TO_VPA'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/Pay/PayToVpa/payToVpa_NewPayee.html',
						controller: 'payToVpaController',
						controllerAs: 'payToVpaVm'
					}
				}
			})
			.state('menu.payToVpa_PayeeDetails', {
				url: '/payToVpa_PayeeDetails',
				data: {
					pageId: 'UPI_PAY_TO_VPA_DTLS'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/Pay/PayToVpa/payToVpa_PayeeDetails.html',
						controller: 'payToVpa_PayeeDetailsController',
						controllerAs: 'payToVpa_PayeeDetailsVm'
					}
				}
			})
			.state('menu.payToVpa_Review', {
				url: '/payToVpa_Review',
				data: {
					pageId: 'UPI_PAY_TO_VPA_RVW'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/Pay/PayToVpa/payToVpa_Review.html',
						controller: 'payToVpa_ReviewController',
						controllerAs: 'payToVpa_ReviewVm'
					}
				}
			})
			.state('menu.payToVpa_Success', {
				url: '/payToVpa_Success',
				data: {
					pageId: 'UPI_PAY_TO_VPA_SUCC'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/Pay/PayToVpa/payToVpa_Success.html',
						controller: 'payToVpa_SuccessController',
						controllerAs: 'payToVpa_SuccessVm'
					}
				}
			})

			.state('menu.accounts', {
				url: '/accounts',
				data: {
					pageId: 'UPI_MANAGE_ACC'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/Manage/UPI/Accounts/accounts.html',
						controller: 'accountsController',
						controllerAs: 'accountsVm'
					}
				}
			})
			.state('menu.addAccount', {
				url: '/addAccount',
				data: {
					pageId: 'UPI_MANAGE_ADDACC'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/Manage/UPI/Accounts/addAccount.html',
						controller: 'addAccountController',
						controllerAs: 'addAccountVm'
					}
				}, params: { virtualAddress : null}
			})
			.state('menu.transactionHistory', {
				url: '/transactionHistory',
				data: {
					pageId: 'UPI_TRANSACTION_HISTORY'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/TransactionHistory/transactionHistory.html',
						controller: 'transactionHistoryController',
						controllerAs: 'transactionHistoryVm'
					}
				}, params: { transactionHistory: null}
			})

			.state('menu.transactionReceipt', {
				url: '/transactionReceipt',
				data: {
					pageId: 'UPI_TRANSACTION_SUCCESS'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/TransactionHistory/transactionReceipt.html',
						controller: 'transactionReceiptController',
						controllerAs: 'transactionReceiptVm'
					}
				}
			})

			.state('menu.raiseDispute', {
				url: '/raiseDispute',
				data: {
					pageId: 'UPI_RAISE_DISPUTE'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/TransactionHistory/RaiseDispute/raiseDispute.html',
						controller: 'raiseDisputeController',
						controllerAs: 'raiseDisputeVm'
					}
				}
			})

			.state('menu.payToQR', {
				url: '/payToQR',
				data: {
					pageId: 'UPI_PAY_QR'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/Pay/payToQR/payToQR.html',
						controller: 'payToQRController',
						controllerAs: 'payToQRVm'
					}
				}, params: { transactionHistory: null}
			})

			.state('menu.payToAccount', {
				url: '/payToAccount',
				data: {
					pageId: 'UPI_PAY_ACC'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/Pay/payToAccount/payToAccount.html',
						controller: 'payToAccountController',
						controllerAs: 'payToAccountVm'
					}
				}, params: { transactionHistory: null}
			})
			.state('menu.setUpiPin', {
				url: '/setUpiPin',
				data: {
					pageId: 'UPI_SET_UPIPIN'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/Manage/UPI/Accounts/setUpiPin.html',
						controller: 'setUpiPinController',
						controllerAs: 'setUpiPinVm'
					}
				}
			})
			.state('menu.sendCollectRequest', {
				url: '/sendCollectRequest',
				data: {
					pageId: 'UPI_COLLECT_SND_REQUEST'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/Collect/sendCollectRequest/sendCollectRequest.html',
						controller: 'sendCollectRequestController',
						controllerAs: 'sendCollectRequestVm'
					}
				}
			})
			.state('menu.sendCollectRequestReview', {
				url: '/sendCollectRequestReview',
				data: {
					pageId: 'UPI_COLLECT_SND_REQUEST_REVIEW'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/Collect/sendCollectRequest/sendCollectRequestReview.html',
						controller: 'sendCollectRequestReviewController',
						controllerAs: 'sendCollectRequestReviewVm'
					}
				}
			})
			.state('menu.generateQr', {
				url: '/generateQr',
				data: {
					pageId: 'UPI_COLLECT_GENERATE_QR'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/Collect/sendCollectRequest/generateQr.html',
						controller: 'generateQrController',
						controllerAs: 'generateQrVm'
					}
				}
			})
		
				.state('menu.upiPayments', {
				url: '/upiPayments',
				data: {
					pageId: 'UPI_COLLECT_GENERATE_QR'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/Pay/upiPayments.html',
						controller: 'upiPaymentsController',
						controllerAs: 'upiPaymentsVm'
					}
				}
			})

			.state('menu.collectRequestSuccess', {
				url: '/collectRequestSuccess',
				data: {
					pageId: 'UPI_COLLECT_REQUEST_SUCCESS'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/Collect/sendCollectRequest/collectRequestSuccess.html',
						controller: 'collectRequestSuccessController',
						controllerAs: 'collectRequestSuccessVm'
					}
				}
			})

			.state('menu.blockUnblockSuccess', {
				url: '/blockUnblockSuccess',
				data: {
					pageId: 'UPI_TRANSACTION_SUCCESS'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/TransactionHistory/blockUnblockSuccess.html',
						controller: 'blockUnblockSuccessController',
						controllerAs: 'blockUnblockSuccessVm'
					}
				}
			})
		.state('menu.disputeReceipt', {
				url: '/disputeReceipt',
				data: {
					pageId: 'UPI_DISPUTE_RECEIPT'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/TransactionHistory/disputeReceipt.html',
						controller: 'disputeReceiptController',
						controllerAs: 'disputeReceiptVm'
					}
				}
			})
			.state('menu.viewAllUpiIds', {
				url: '/viewAllUpiIds',
				data: {
					pageId: 'UPI_DISPUTE_RECEIPT'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/Manage/UPI/Accounts/viewAllUpiIds.html',
						controller: 'viewAllUpiIdsController',
						controllerAs: 'viewAllUpiIdsVm'
					}
				}
			})
			.state('menu.deRegisterSuccess', {
				url: '/deRegisterSuccess',
				data: {
					pageId: 'UPI_DEREGISTER_SUCCESS'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/Manage/UPI/De-Register/deRegisterSuccess.html',
						controller: 'deRegisterSuccessController',
						controllerAs: 'deRegisterSuccessVm'
					}
				}
			})
			.state('menu.viewBankAccounts', {
				url: '/viewBankAccounts',
				data: {
					pageId: 'UPI_DEREGISTER_SUCCESS'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/Manage/UPI/Accounts/viewBankAccounts.html',
						controller: 'viewBankAccountsController',
						controllerAs: 'viewBankAccountsVm'
					}
				}
			})
			.state('menu.createNewUpiId', {
				url: '/createNewUpiId',
				data: {
					pageId: 'UPI_CREATE_NEW'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/Manage/UPI/Accounts/createNewUpiId.html',
						controller: 'createNewUpiIdController',
						controllerAs: 'createNewUpiIdVm'
					}
				}
			})
				.state('menu.bhimUpiPayments', {
				url: '/bhimUpiPayments',
				data: {
					pageId: 'UPI_CREATE_NEW'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/preHomeLogin/InternetBanking/bhimUpiPayments.html',
						controller: 'bhimUpiPaymentsController',
						controllerAs: 'bhimUpiPaymentsVm'
					}
				}
			})
				.state('menu.pendingRequests', {
				url: '/pendingRequests',
				data: {
					pageId: 'UPI_CREATE_NEW'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/Pay/Requests/pendingRequests.html',
						controller: 'pendingRequestsController',
						controllerAs: 'pendingRequestsVm'
					}
				}
			})
				.state('menu.generateQRImage', {
				url: '/generateQRImage',
				data: {
					pageId: 'UPI_GENERATE_IMG'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/Collect/sendCollectRequest/generateQRImage.html',
						controller: 'generateQRImageController',
						controllerAs: 'generateQRImageVm'
					}
				}
			})
				.state('menu.viewMyQrCode', {
				url: '/viewMyQrCode',
				data: {
					pageId: 'UPI_VIEW_MY_QR'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/Collect/sendCollectRequest/viewMyQrCode.html',
						controller: 'viewMyQrCodeController',
						controllerAs: 'viewMyQrCodeVm'
					}
				}
			})
			.state('menu.raiseDisputeSuccess', {
				url: '/raiseDisputeSuccess',
				data: {
					pageId: 'UPI_RAISE_DISP_SUCCESS'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/TransactionHistory/RaiseDispute/raiseDisputeSuccess.html',
						controller: 'raiseDisputeSuccessController',
						controllerAs: 'raiseDisputeSuccessVm'
					}
				}
			})
			.state('menu.reVerifyDevice', {
				url: '/reVerifyDevice',
				data: {
					pageId: 'RE_VERIFY_DEVICE'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/Registration/reVerifyDevice.html',
						controller: 'reVerifyDeviceController',
						controllerAs: 'reVerifyDeviceVm'
					}
				}
			})
			.state('menu.createUPIPin', {
				url: '/createUPIPin',
				data: {
					pageId: 'CREATE_UPI_PIN'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/Registration/createUPIPin.html',
						controller: 'createUPIPinController',
						controllerAs: 'createUPIPinVm'
					}
				}
			})
			.state('menu.enableDisableUpi', {
				url: '/enableDisableUpi',
				data: {
					pageId: 'ENABLE_DISABLE_UPI'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/Manage/UPI/Enable-Disable/enableDisableUpi.html',
						controller: 'enableDisableUpiController',
						controllerAs: 'enableDisableUpiVm'
					}
				}
			})
			.state('menu.enableUPIAuthentication', {
				url: '/enableUPIAuthentication',
				data: {
					pageId: 'ENABLE_DISABLE_UPI_AUTH'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/Manage/UPI/Enable-Disable/enableUPIAuthentication.html',
						controller: 'enableUPIAuthenticationController',
						controllerAs: 'enableUPIAuthenticationVm'
					}
				}
			})
			// BQR start
			.state('menu.scanPay', {
				url: '/scanPay',
				data: {
					pageId: 'BQ_SCANPAY'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/fundTransfer/bhimUpi/BharatQR/scanPay.html',
						controller: 'scanPayController',
						controllerAs: 'scanPayVm'
					}
				}
			})
			.state('menu.ftPayment', {
                    url: '/ftPayment',
                    data: {
                        pageId: 'BQ_FTPAYMENT'
                    },
                    cache: false,
                    views: {
                        'menuContent': {
                            templateUrl: 'pages/fundTransfer/bhimUpi/BharatQR/ftPayment.html',
                            controller: 'ftPaymentController',
                            controllerAs: 'ftPaymentVm'
                        }
                    }
                })
				.state('menu.reviewPayment', {
                    url: '/reviewPayment',
                    data: {
                        pageId: 'BQ_REVIEWPAYMENT'
                    },
                    cache: false,
                    views: {
                        'menuContent': {
                            templateUrl: 'pages/fundTransfer/bhimUpi/BharatQR/reviewPayment.html',
                            controller: 'reviewPaymentController',
                            controllerAs: 'reviewPaymentVm'
                        }
                    }
                })
				.state('menu.bharatQrOtp', {
                    url: '/bharatQrOtp',
                    data: {
                        pageId: 'BQ_OTP'
                    },
                    cache: false,
                    views: {
                        'menuContent': {
                            templateUrl: 'pages/fundTransfer/bhimUpi/BharatQR/bharatQrOtp.html',
                            controller: 'bharatQrOtpController',
                            controllerAs: 'bharatQrOtpVm'
                        }
                    }
                })
				.state('menu.bharatQrSuccess', {
                    url: '/bharatQrSuccess',
                    data: {
                        pageId: 'BQ_SUCCESS'
                    },
                    cache: false,
                    views: {
                        'menuContent': {
                            templateUrl: 'pages/fundTransfer/bhimUpi/BharatQR/bharatQrSuccess.html',
                            controller: 'bharatQrSuccessController',
                            controllerAs: 'bharatQrSuccessVm'
                        }
                    }
                })
			//BQR end
		//BHIM UPI ENDS HERE
			 .state('menu.pensionSlip', {
				url: '/pensionSlip',
				data: {
					pageId: 'NFS_PENSIONSLIP'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/pensionSlip/pensionSlip.html',
						controller: 'pensionSlipController',
						controllerAs: 'pensionSlipVm',
					}
				}, params: { dreamsObj: null }
			})
				//Added for Pension From16B starts here
			.state('menu.pensionForm16B', {
			url: '/pensionForm16B',
			data: {
				pageId: 'NFS_FORM16B'
			},
			cache: false,
			views: {
				'menuContent': {
					templateUrl: 'pages/nfs/pensionForm16B/pensionForm16B.html',
					controller: 'pensionForm16BController',
					controllerAs: 'pensionForm16BVM',
				}
			}, params: { dreamsObj: null }
		})
		// Pension Form16B ends here
		// mpassbook starts here
			.state('menu.mpassbookdetails', {
				url: '/mpassbookdetails',
				data: {
						pageId: 'NFS_MPASSBOOKDETAILS'
					  },
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/mpassbookdetails/mpassbookdetails.html',
						controller: 'mpassbookdetailsController',
						controllerAs: 'mpassbookdetailsVm',
					}
				}, params: { dreamsObj: null }
			})

		// mpassbook ends here
			.state('menu.menudummy', {
				url: '/menudummy',
				data: {
					pageId: 'MENU_DUMMY'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/menu/menudummy.html',
						controller: 'menudummyController',
						controllerAs: 'menudummyVM',
					}
				}
			})
			// Form 15 Submission/Enquiry starts here
		.state('menu.form15SubmissionLanding', {
			url: '/formSubmissionLanding',
			data: {
				pageId: 'FORM15_LANDING'
			},
			cache: false,
			views: {
				'menuContent': {
					templateUrl: 'pages/nfs/form15/form15SubmissionLanding.html',
					controller: 'form15SubmissionLandingController',
					controllerAs: 'form15SubmissionLandingControllerVm',
				}
			}
		})
	.state('menu.formSubmisDetailScreenOne', {
				url: '/formSubmisDetailScreenOne',
				data: {
					pageId: 'FORM15_SCREEN1'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/form15/formSubmisDetailScreenOne.html',
						controller: 'formSubmisDetailScreenOneController',
						controllerAs: 'formSubmisDetailScreenOneControllerVm',
					}
				}
			})
			.state('menu.formSubmisDetailScreenTwo', {
				url: '/formSubmisDetailScreenTwo',
				data: {
					pageId: 'FORM15_SCREEN2'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/form15/formSubmisDetailScreenTwo.html',
						controller: 'formSubmisDetailScreenTwoController',
						controllerAs: 'formSubmisDetailScreenTwoControllerVm',
					}
				}
			})
			.state('menu.formSubmisDetailScreenThree', {
				url: '/formSubmisDetailScreenThree',
				data: {
					pageId: 'FORM15_SCREEN3'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/form15/formSubmisDetailScreenThree.html',
						controller: 'formSubmisDetailScreenThreeController',
						controllerAs: 'formSubmisDetailScreenThreeControllerVm',
					}
				}
			})
			.state('menu.formSubDetailScreenFour', {
				url: '/formSubDetailScreenFour',
				data: {
					pageId: 'FORM15_SCREEN4'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/form15/formSubDetailScreenFour.html',
						controller: 'formSubDetailScreenFourController',
						controllerAs: 'formSubDetailScreenFourControllerVm',
					}
				}
			})
			.state('menu.formFiledDeclarations', {
				url: '/formFiledDeclarations',
				data: {
					pageId: 'FORM15_DECLARATIONS'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/form15/formFiledDeclarations.html',
						controller: 'formFiledDeclarationsController',
						controllerAs: 'formFiledDeclarationsControllerVm',
					}
				}
			})
			.state('menu.formSubDetailReview', {
				url: '/formSubDetailReview',
				data: {
					pageId: 'FORM15_REVIEW'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/form15/formSubDetailReview.html',
						controller: 'formSubDetailReviewController',
						controllerAs: 'formSubDetailReviewControllerVm',
					}
				}
			})
				.state('menu.formSubmisOtp', {
				url: '/formSubmisOtp',
				data: {
					pageId: 'FORM15_OTP'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/form15/formSubmisOtp.html',
						controller: 'formSubmisOtpController',
						controllerAs: 'formSubmisOtpControllerVm',
					}
				}
			})
				.state('menu.formSubmissionSuccess', {
				url: '/formSubmissionSuccess',
				data: {
					pageId: 'FORM15_SUCCESS'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/form15/formSubmissionSuccess.html',
						controller: 'formSubmissionSuccessController',
						controllerAs: 'formSubmissionSuccessControllerVm',
					}
				}
			})


			// Form 15 Submission Ends Here
			.state('menu.formEnquiryLanding', {
				url: '/formEnquiryLanding',
				data: {
					pageId: 'FORM15_ENQUIRY'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/form15Enquiry/formEnquiryLanding.html',
						controller: 'formEnquiryLandingController',
						controllerAs: 'formEnquiryLandingVm',
					}
				}
			})
			
			// Form 15 Enquiry ends here
			.state('menu.cifDetails', {
				url: '/cifDetails',
				cache: false,
				data: {
					pageId: 'CIF_DETAILS'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/preHomeLogin/AccountDetails/cifDetails.html',
						controller: 'cifDetailsController',
						controllerAs: 'cifDetailsVm'
					}
				}
			})
			.state('menu.regOTPForATM', {
				url: '/regOTPForATM',
				cache: false,
				data: {
					pageId: 'REG_OTPFORATM'
				},
				views: {
					'menuContent': {
						templateUrl: 'pages/preHomeLogin/AccountDetails/regOTP.html',
						controller: 'regOTPATMController',
						controllerAs: 'regOTPATMControllerVm'
					}
				}
			})
			//ATM HOT FIX END
			
			//Registration With Account Number START
		.state('menu.regProcessMenu', {
			url: '/regProcessMenu',
			data: {
				pageId: 'REGPROCESSMENU'
			},
			cache: false,
			views: {
				'menuContent': {
					templateUrl: 'pages/preHomeLogin/registrationWithAccount/regProcessMenu.html',
					controller: 'regProcessMenuController',
					controllerAs: 'regProcessMenuControllerVm',
				}
			}
		})
		.state('menu.regAccountDetails', {
			url: '/regAccountDetails',
			data: {
				pageId: 'REGACCOUNTDETAILS'
			},
			cache: false,
			views: {
				'menuContent': {
					templateUrl: 'pages/preHomeLogin/registrationWithAccount/regAccountDetails.html',
					controller: 'regAccountDetailsController',
					controllerAs: 'regAccountDetailsControllerVm',
				}
			}
		})
		.state('menu.regOTP', {
			url: '/regOTP',
			data: {
				pageId: 'REGOTP'
			},
			cache: false,
			views: {
				'menuContent': {
					templateUrl: 'pages/preHomeLogin/registrationWithAccount/regOTP.html',
					controller: 'regOTPController',
					controllerAs: 'regOTPControllerVm',
				}
			}
		})
		.state('menu.regReviewUserDetails', {
			url: '/regReviewUserDetails',
			data: {
				pageId: 'REGREVIEWUSERDETAILS'
			},
			cache: false,
			views: {
				'menuContent': {
					templateUrl: 'pages/preHomeLogin/registrationWithAccount/regReviewUserDetails.html',
					controller: 'regReviewUserDetailsController',
					controllerAs: 'regReviewUserDetailsControllerVm',
				}
			}
		})
		.state('menu.setInternetBankingDetails', {
			url: '/setInternetBankingDetails',
			data: {
				pageId: 'SETINTERNALBANKINGDETAILS'
			},
			cache: false,
			views: {
				'menuContent': {
					templateUrl: 'pages/preHomeLogin/registrationWithAccount/regSetIntBankingDetails.html',
					controller: 'regSetIntBankingDetailsController',
					controllerAs: 'regSetBankDetailsVM',
				}
			}
		})
		.state('menu.activationCodeInbLogin', {
			url: '/activationCodeInbLogin',
			data: {
				pageId: 'ACTIVATIONCODEINBLOGIN'
			},
			cache: false,
			views: {
				'menuContent': {
					templateUrl: 'pages/preHomeLogin/registrationWithAccount/activationCodeInbLogin.html',
					controller: 'activationCodeInbLoginController',
					controllerAs: 'activationCodeInbLoginVM',
				}
			}
		})
		.state('menu.activationCode', {
			url: '/activationCode',
			data: {
				pageId: 'ACTIVATIONCODE'
			},
			cache: false,
			views: {
				'menuContent': {
					templateUrl: 'pages/preHomeLogin/registrationWithAccount/activationCode.html',
					controller: 'activationCodeController',
					controllerAs: 'activationCodeVm',
				}
			}
		})
		.state('menu.successAccount', {
			url: '/successAccount',
			data: {
				pageId: 'SUCCESSACCOUNT'
			},
			cache: false,
			views: {
				'menuContent': {
					templateUrl: 'pages/preHomeLogin/registrationWithAccount/successAccount.html',
					controller: 'successAccountController',
					controllerAs: 'successAccountVm',
				}
			}
		})
		.state('menu.regSetInbPassword', {
			url: '/regSetInbPassword',
			data: {
				pageId: 'REGSETINBPASSWORD'
			},
			cache: false,
			views: {
				'menuContent': {
					templateUrl: 'pages/preHomeLogin/registrationWithAccount/regSetInbPassword.html',
					controller: 'regSetInbPasswordController',
					controllerAs: 'regSetInbPasswordVm',
				}
			}
		})
		.state('menu.skipsetMpin', {
			url: '/skipsetMpin',
			data: {
				pageId: 'SKIPSETMPIN'
			},
			cache: false,
			views: {
				'menuContent': {
					templateUrl: 'pages/preHomeLogin/registrationWithAccount/skipsetMpin.html',
					controller: 'skipsetMpinController',
					controllerAs: 'skipsetMpinVm',
				}
			}
		})
		//Registration With Account Number END
		//ATM HOT FIX START
		.state('menu.chequeDeposits', {
			url: '/chequeDeposits',
			data: {
				pageId: 'CHEQUEDEPOSITS'
			},
			cache: false,
			views: {
				'menuContent': {
					templateUrl: 'pages/nfs/chequeDeposits/chequeDeposits.html',
					controller: 'chequeDepositsController',
					controllerAs: 'chequeDepositsVm',
				}
			}
		})

		.state('menu.locateCDK', {
			url: '/locateCDK',
			data: {
				pageId: 'LOCATECDK'
			},
			cache: false,
			views: {
				'menuContent': {
					templateUrl: 'pages/nfs/chequeDeposits/locateCDK.html',
					controller: 'locateCDKController',
					controllerAs: 'locateCDKVm',
				}
			}
		})

		.state('menu.reviewCDK', {
			url: '/reviewCDK',
			data: {
				pageId: 'REVIEWCDK'
			},
			cache: false,
			views: {
				'menuContent': {
					templateUrl: 'pages/nfs/chequeDeposits/cdReview.html',
					controller: 'cdReviewController',
					controllerAs: 'cdReviewVm',
				}
			}
		})

		.state('menu.thankYouCDK', {
			url: '/thankYouCDK',
			data: {
				pageId: 'TYCDK'
			},
			cache: false,
			views: {
				'menuContent': {
					templateUrl: 'pages/nfs/chequeDeposits/cdThankyou.html',
					controller: 'cdThankyouController',
					controllerAs: 'cdThankyouVm',
				}
			}
		})

		//Cheque Deposits ends here
		
			
		//Pension Payment Info start here
		.state('menu.paymentInformation', {
				url: '/paymentInformation',
				data: {
					pageId: 'NFS_PAYMENTINFOPENSION'
				},
				cache: false,
				views: {
					'menuContent': {
						templateUrl: 'pages/nfs/paymentInformation/paymentInformation.html',
						controller: 'paymentInformationController',
						controllerAs: 'paymentInformationVM',
					}
				}, params: { dreamsObj: null }
			})

		//Pension Payment Info ends here
		/* start donation code remove from iOS */
		.state('menu.donation', {
			url: '/donation',
			cache: false,
			data: {
				pageId: 'COV_DON_PAG'
			},
			views: {
				'menuContent': {
					templateUrl: 'pages/covid/donation.html',
					controller: 'donationController',
					controllerAs: 'donationVm'
				}
			}
		})
		.state('menu.covidOtp', {
			url: '/covidOtp',
			cache: false,
			data: {
				pageId: 'COV_DON_OTP'
			},
			views: {
				'menuContent': {
					templateUrl: 'pages/covid/otpCovid.html',
					controller: 'otpCovidController',
					controllerAs: 'otpCovidVm'
				}
			}
		})
		.state('menu.covidSuccess', {
			url: '/covidSuccess',
			cache: false,
			data: {
				pageId: 'COV_DON_SUC'
			},
			views: {
				'menuContent': {
					templateUrl: 'pages/covid/covidSuccess.html',
					controller: 'covidSuccessController',
					controllerAs: 'covidSuccessVm'
				}
			}
		})
		/* end donation code remove from iOS */

		.state('menu.userTour', {
			url: '/userTour',
			cache: false,
			data: {
				pageId: 'USER_TOUR'
			},
			views: {
				'menuContent': {
					templateUrl: 'pages/homeScreen/userTour/userTour.html',
					controller: 'userTourController',
					controllerAs: 'userTourVm'
				}
			}
		})
		
		/* Register With SIM Start*/
		.state('menu.selectSim', {
			url: '/selectSim',
			cache: false,
			data: {
				pageId: 'SELECT_SIM'
			},
			views: {
				'menuContent': {
					templateUrl: 'pages/preHomeLogin/registerWithSim/selectSim.html',
					controller: 'selectSimController',
					controllerAs: 'selectSimVm'
				}
			}
		})
		.state('menu.loadSimData', {
			url: '/loadSimData',
			cache: false,
			data: {
				pageId: 'LOAD_SIM_DATA'
			},
			views: {
				'menuContent': {
					templateUrl: 'pages/preHomeLogin/registerWithSim/loadSimData.html',
					controller: 'loadSimDataController',
					controllerAs: 'loadSimDataVm'
				}
			}
		})
		.state('menu.userEligibility', {
			url: '/userEligibility',
			cache: false,
			data: {
				pageId: 'USER_ELIGIBILTIY'
			},
			views: {
				'menuContent': {
					templateUrl: 'pages/preHomeLogin/registerWithSim/userEligibility.html',
					controller: 'userEligibilityController',
					controllerAs: 'userEligibilityVm'
				}
			}
		})
		/* Register With SIM End*/

		.state('menu.vurnableApps', {
			url: '/vurnableApps',
			cache: false,
			data: {
				pageId: 'VERNABLE_APPS'
			},
			views: {
				'menuContent': {
					templateUrl: 'pages/landing/vurnableApps/vurnableApp.html',
					controller: 'vurnableAppController',
					controllerAs: 'vAppVM'
				}
			}
		})
		.state('menu.landingWithOptions', {
			url: '/landingWithOptions',
			cache: false,
			data: {
				pageId: 'LANDING_WITH_OPTIONS'
			},
			views: {
				'menuContent': {
					templateUrl: 'pages/landing/landingWithOptions.html',
					controller: 'landingWithOptionsController',
					controllerAs: 'landingWOVM'
				}
			}
		})
		.state('menu.redirectionToRbiGilt', {
			url: '/redirectionToRbiGilt',
			data: {
				pageId: 'REDIRECTION_RBI_GILT'
			},
			cache: false,
			views: {
				'menuContent': {
					templateUrl: 'pages/redirectionToRbiGilt/redirectionToRbiGilt.html',
					controller: 'redirectionToRbiGiltController',
					controllerAs: 'redirectionToRbiGiltVm'
				}
			}
		})
		.state('menu.termsAndConditionsOutboundAnalytics', {
			url: '/termsAndConditionsOutboundAnalytics',
			cache: false,
			params: {data:null },
			views: {
				'menuContent': {
					templateUrl: 'pages/accountOverview/outboundAnalytics/termsAndConditionsOutboundAnalytics.html',
					controller: 'termsAndConditionsOutboundAnalyticsController',
					controllerAs: 'termsAndConditionsOutboundAnalyticsControllerVm'
				}
			}
		})

		.state('menu.consentRevocation', {
			url: '/consentRevocation',
			cache: false,
			views: {
				'menuContent': {
					templateUrl: 'pages/accountOverview/outboundAnalytics/consentRevocation.html',
					controller: 'consentRevocationController',
					controllerAs: 'consentRevocationControllerVm'
				}
			}
		})

		.state('menu.leadGenerationInvestment', {
			url: '/leadGenerationInvestment',
			cache: false,
			views: {
				'menuContent': {
					templateUrl: 'pages/accountOverview/outboundAnalytics/leadGenerationInvestment.html',
					controller: 'leadGenerationInvestmentController',
					controllerAs: 'leadGenerationInvestmentControllerVm'
				}
			}
		})
	}]);
