'use strict';

angularApp.controller('locateBranchByLocalityController', ["$state",
    "$scope",
    "locateNearestBranchService",
    "aoService",
    "utilityService",
    "$ionicHistory",
    "$translate",
    "$ionicSideMenuDelegate",
    "mPinLoginService",

    function($state,
        $scope,
        locateNearestBranchService,
        aoService,
        utilityService,
        $ionicHistory,
        $translate,
        $ionicSideMenuDelegate,
        mPinLoginService) {

        var locateBranchLocVm = this;

        function initPage() {
            locateBranchLocVm.showBack = true;
            locateBranchLocVm.showNext = false;
            locateBranchLocVm.disableNext = true;
            locateBranchLocVm.bankListLocality = [];
            locateBranchLocVm.aofooter = true;
            locateBranchLocVm.showRadioBtn = false;
            locateBranchLocVm.showLink = true;
            locateBranchLocVm.localityname="";


            $translate('AO_OK_LABEL').then(function(translatedvalue) {
                locateBranchLocVm.okBtntext = translatedvalue;
            });
        }

        locateBranchLocVm.goBacktoPrevious = function() {
            //$ionicHistory.goBack();
            $state.go('menu.locateNearestBranch');
        }

        locateBranchLocVm.navigatePage = function(param){
           var geocoords = param.latitude + ',' + param.longitude;
           if(utilityService.isUndefined(param.latitude) || utilityService.isUndefined(param.longitude)){
                var title = '';
                var template = '{{"NO_DIR" | translate}}';
                var onTap = 'menu.locateBranchByLocality';
                var buttontext = '<b>' + locateBranchLocVm.okBtntext + '</b>';
                utilityService.showAlertModal(title, template, onTap, $scope, $state, buttontext);
            }
            else{
                if (utilityService.isIOSPlatform()) {
                  window.open('maps://?q=' + geocoords, '_system');
                }
                else {
                  var label = encodeURI('Your Destination'); // encode the label!
                  window.open('geo:0,0?q=' + geocoords + '(' + label + ')', '_system');
                }  
            }
        }

        $scope.goToHome = function() {
            aoService.homeNav();
        }

        locateBranchLocVm.onChangeFn = function(value) {
            if (!utilityService.isUndefined(value)) {
                if (value.length == 3) {
                    locateBranchLocVm.loadBranchesLocality();
                }
            } else {
                locateBranchLocVm.bankListLocality = [];
                locateBranchLocVm.disableNext = true;
            }

        }

        //Make the radio button checked if the respective div is clicked
        locateBranchLocVm.checkDiv = function(param) {
            locateBranchLocVm.branchList = param.id;
            locateBranchLocVm.disableNext = false;
            aoService.homeBranchLocalityId = param.id;
            aoService.homeBranchLocalityCity = param.city;
        }

        locateBranchLocVm.onclickValidation = function(isValid) {
            locateBranchLocVm.hideOptions = true;
            for(var i=0;i<locateBranchLocVm.displayCities.length;i++){
                if(!utilityService.isUndefined(locateBranchLocVm.localityname)){
                    if(locateBranchLocVm.displayCities[i].toLowerCase() == locateBranchLocVm.localityname.toLowerCase()){
                        locateBranchLocVm.loadBranchesLocality();
                    }
                }
                else {
                    locateBranchLocVm.bankListLocality = [];
                    locateBranchLocVm.disableNext = true;
                }
                
            }
        }

        locateBranchLocVm.showHideFilterDropDown = function(city) {
            if (!utilityService.isUndefined(city)) {
                locateBranchLocVm.localityname = city;
                locateBranchLocVm.loadBranchesLocality();
            } else {
                locateBranchLocVm.hideOptions = false;
            }
        }

        locateBranchLocVm.getCountriesList = function() {
            locateNearestBranchService.getAllCities().then(function(body) {
                if(!utilityService.isUndefined(body)){
                    for (var i = 0; i < body.length; i++) {                    
                        locateBranchLocVm.displayCities.push(body[i]);
                        locateBranchLocVm.displayCities.sort();
                    }
                }
            }, function(error) {
                utilityService.showErrorMessage(error.responseMessage);
            });
        }


        locateBranchLocVm.validateForm = function(isValid) {
            if (isValid) {
                locateBranchLocVm.disableNext = false;
            }
        }

        locateBranchLocVm.selectedBranch = function(param) {
            aoService.branchname = param.branchName;
            aoService.branchaddress = param.address;
            aoService.homeBranchLocalityId = param.id;
            aoService.homeBranchLocalityCity = param.city;
        }

        //Service for displaying branch list for locality
        locateBranchLocVm.loadBranchesLocality = function() {
            locateBranchLocVm.hideOptions = false;
            locateBranchLocVm.bankListLocality.length = 0;
            var params = {
                "locality": locateBranchLocVm.localityname
            }
            locateNearestBranchService.getBranchesForLocality(params).then(function(data) {
                if (utilityService.isUndefined(data.branches) || data.branches.length === 0) {
                    var title = '';
                    var template = '{{"BRANCH_UNAVLBL" | translate}}';
                    var onTap = 'menu.locateBranchByLocality';
                    var buttontext = '<b>' + locateBranchLocVm.okBtntext + '</b>';
                    utilityService.showAlertModal(title, template, onTap, $scope, $state, buttontext);
                } else {
                    for (var i = 0; i < data.branches.length; i++) {
                        locateBranchLocVm.bankListLocality.push(data.branches[i]);
                    }
                }
            }, function(error) {
                utilityService.showErrorMessage(error.responseMessage);
            });
        }

        //one time initialization to be done when the controller is loaded
        $scope.$on('$ionicView.loaded', function() {
            initPage();
        });

        //actions to done everytime the view is shown
        $scope.$on('$ionicView.beforeEnter', function() {
            locateBranchLocVm.displayCities = [];
            locateBranchLocVm.getCountriesList();
            $ionicSideMenuDelegate.canDragContent(mPinLoginService.isLoggedIn);   
        });   

        return this;
    }
]);
