'use strict';

angularApp.controller('mapController', ["$state",
    "$scope",
    "utilityService",
    "$translate",
    "$ionicHistory",
    "currentLocationService",
    "aoService",
    "mapService",
    "$ionicSideMenuDelegate",
    "mPinLoginService",

    function($state,
        $scope,
        utilityService,
        $translate,
        $ionicHistory,
        currentLocationService,
        aoService,
        mapService,
        $ionicSideMenuDelegate,
        mPinLoginService) {

        var mapVm = this;
        var Map;
        var Latitude = undefined;
        var Longitude = undefined;
        var service;
        var cur_lat;
        var cur_long;        
        var directionsService;
        var directionsDisplay;
        var dest_lat;
        var dest_lng;
        var markers=[];
        var contents = [];
        var infowindows = [];

        function initPage() {
            mapVm.showBack = true;
            mapVm.showNext = false;
            mapVm.aofooter = true;
            
            $translate('AO_OK_LABEL').then(function (translatedvalue) {
                mapVm.okBtntext = translatedvalue;  
            });
        }

        mapVm.mapInitialize = function() {
            currentLocationService.getCurrentPosition().then(
                function(position) {  
                    Latitude = position.coords.latitude;
                    Longitude = position.coords.longitude;
                    cur_lat = position.coords.latitude;
                    cur_long = position.coords.longitude;                    
                    var latNew = Latitude.toFixed(3);
                    var lonNew = Longitude.toFixed(3);
                    aoService.mapCoords.latitude = latNew;
                    aoService.mapCoords.longitude = lonNew;
                    var params = {
                        "latitude": aoService.mapCoords.latitude,
                        "longitude": aoService.mapCoords.longitude
                    }
                    mapService.getBranchesForGeo(params).then(function(data) {
                        if(!utilityService.isUndefined(data.branches)){
                            for (var i = 0; i < data.branches.length; i++) {
                                aoService.mapGPS.push(data.branches[i]);
                                //mapVm.getPlaces(Latitude,Longitude);
                            }
                        }
                         mapVm.getPlaces(Latitude,Longitude);
                    }, function(error) {
                        utilityService.showErrorMessage(error.responseMessage);
                    });
                },
                function(err) {
                    var title = '';
                    var template = err.message;
                    var onTap = '';
                    var buttontext = '<b>' + mapVm.okBtntext + '</b>';
                    utilityService.showAlertModal(title, template, onTap, $scope, $state, buttontext);
                }
            );
        }


        function loadScript(src){  
            var script = document.createElement("script");
            script.type = "text/javascript";
            document.getElementsByTagName("head")[0].appendChild(script);
            script.src = src;
        }

        mapVm.getPlaces = function(latitude, longitude) {
            var latLong = new google.maps.LatLng(latitude, longitude);
            var mapOptions = {
                center: new google.maps.LatLng(latitude, longitude),
                zoom: 15,
                mapTypeId: google.maps.MapTypeId.ROADMAP
            };
             
            Map = new google.maps.Map(document.getElementById("map"), mapOptions);
            mapVm.foundStoresCallback(aoService.mapGPS);
        } 

        // Success callback for locating bank in the area
        
        mapVm.foundStoresCallback = function(markerArr) {
            var markerArr = aoService.mapGPS;
                for (var i = 0; i < markerArr.length; i++) {
                     markers[i] = new google.maps.Marker({
                        position: new google.maps.LatLng(markerArr[i].latitude,markerArr[i].longitude),
                        map: Map
                    });

                    markers[i].index = i; 
                    contents[i] = '<div id="content">'+markerArr[i].branchName+'</div>';

                    infowindows[i] = new google.maps.InfoWindow({
                        content: contents[i]
                    });

                    google.maps.event.addListener(markers[i], 'click', function() {
                        infowindows[this.index].open(Map,markers[this.index]);
                    });               
                }          
        }
    

        //Set the height of the map
        mapVm.setMapHeight = function() {
            var screenheight = Math.round(window.innerHeight * .83) + 'px';
            document.getElementById("map").style.height = screenheight;
        }

        mapVm.goBacktoPrevious = function() {
            $ionicHistory.goBack();
            currentLocationService.clearWatch();
        }
        
        $scope.goToHome = function() {
            aoService.homeNav();
        }

        mapVm.gpsBack = function(){
            var backBtn = $ionicHistory.backView();
            var backState= backBtn.stateName;
            return backState;
        }

        //one time initialization to be done when the controller is loaded
        $scope.$on('$ionicView.loaded', function() {
            initPage();
        });

        //actions to done everytime the view is shown
        $scope.$on('$ionicView.beforeEnter', function() {
            CheckGPS.check(function(){
                mapVm.setMapHeight();
                mapVm.mapInitialize();   
                loadScript('http://maps.googleapis.com/maps/api/js?key=AIzaSyD36sPDwe0BMMnTuAvXCh6K7k4StShJ-V8');   
            },
            function(){
                var title = '';
                var template = '{{"ENABLE_GPS" | translate}}';
                var onTap = mapVm.gpsBack();
                var buttontext = 'OK';
                utilityService.showAlertModal(title, template, onTap, $scope, $state, buttontext);
            }); 

            $ionicSideMenuDelegate.canDragContent(mPinLoginService.isLoggedIn);   
                
        });

        return this;
    }
]);
