'use strict';

angularApp.controller('resumeJourneyController', ["$state",
    "$scope",
    "aoService",
    "utilityService",
    "resumeJourneyService",
    "encryptionService",
    "cryptoService",
    "$translate",
    "$ionicSideMenuDelegate",
    "mPinLoginService",
    "loggedInUserService",
    "AdapterUtils",
    "constantConfig",
    "ConnectivityMonitorUtils",
    function ($state,
        $scope,
        aoService,
        utilityService,
        resumeJourneyService,
        encryptionService,
        cryptoService,
        $translate,
        $ionicSideMenuDelegate,
        mPinLoginService,
        loggedInUserService,
        AdapterUtils,
        constantConfig,
        ConnectivityMonitorUtils) {

        var resumeJourneyVm = this;

        resumeJourneyVm.isChallenged = false;
        resumeJourneyVm.securityCheckName = "AOSecurityCheck";
        resumeJourneyVm.aoAuthChallengeHandler = WL.Client.createSecurityCheckChallengeHandler(resumeJourneyVm.securityCheckName);
        resumeJourneyVm.aoAuthChallengeHandler.securityCheckName = resumeJourneyVm.securityCheckName;

        function initPage() {
            resumeJourneyVm.showBack = true;
            resumeJourneyVm.showNext = false;
            $translate('AO_OK_LABEL').then(function (translatedvalue) {
                resumeJourneyVm.okBtntext = translatedvalue;
            });
            if (aoService.isJTSixPostLoginStarted) {
                resumeJourneyVm.resumeMobile = aoService.isJTSixPostLoginData.newMobile;
                resumeJourneyVm.disableResumeMobile = true;
            }

        }

        resumeJourneyVm.goBacktoPrevious = function () {
            $state.go('menu.applyNewOrResume');
        }

        $scope.goToHome = function () {
            aoService.homeNav();
        }

        resumeJourneyVm.resumeJourneyCall = function () {
            if (ConnectivityMonitorUtils.isOffline()) {
                utilityService.showErrorMessage("Unable to connect to Internet. Please check your connectivity.");
                return true;
            }
            resumeJourneyVm.loginWithResume();
        };

        resumeJourneyVm.forgotPassword = function () {
            $state.go("menu.passwordRecovery");
        }

        resumeJourneyVm.getPageDetails = function (proFlag) {
            var requestParams = resumeJourneyVm.resumeMobile;
            resumeJourneyService.getPageDetails(resumeJourneyVm.resumeMobile).then(function (response) {
                var splitUrls = [];
                var splittedUrl1, splittedUrl2;
                if (response.payLoad.commonId == "FATCA") {
                    if (aoService.fatcaFlag == false) {
                        $state.go("menu.locateBranch");
                    }
                    else {
                        $state.go(response.payLoad.mobileURL);
                    }
                }
                else if (response.payLoad.commonId == "AadharManual") {
                    splitUrls = response.payLoad.mobileURL.split("/");
                    splittedUrl1 = splitUrls[0];
                    splittedUrl2 = splitUrls[1];
                    if (aoService.isCustManualCorresChkBox == true || aoService.isresumeCustManualCorresChkBox == true) {
                        $state.go(splittedUrl1);
                    } else {
                        $state.go(splittedUrl2);
                    }

                } else if (response.payLoad.commonId == "AadharScanned") {
                    splitUrls = response.payLoad.mobileURL.split("/");
                    splittedUrl1 = splitUrls[0];
                    splittedUrl2 = splitUrls[1];
                    if (aoService.correspondenceCheckStatus == true) {
                        $state.go(splittedUrl1);
                    } else {
                        $state.go(splittedUrl2);
                    }

                } else if (response.payLoad.commonId == "NomineeDetails") {
                    splitUrls = response.payLoad.mobileURL.split("/");
                    splittedUrl1 = splitUrls[0];
                    splittedUrl2 = splitUrls[1];
                    if (parseInt(aoService.nomineeAadhaarCardDetails.age) < 18 || parseInt(aoService.nominee.age) < 18) {
                        if (aoService.nominee.guardianAddressFlag == "nomineeAddress") {
                            $state.go("menu.nomineeEnteredAddress");
                        }
                        else if (aoService.nominee.guardianAddressFlag == "applicantAddress") {
                            $state.go("menu.nomineeAddress");
                        }
                        else if (aoService.nominee.guardianAddressFlag == "newAddress") {
                            $state.go("menu.nomineeCAddress");
                        }
                        else {
                            $state.go(splittedUrl1);
                        }
                    } else {
                        $state.go(splittedUrl2);
                    }
                }
                else if (response.payLoad.commonId == "PAN") {
                    if (aoService.cifNumber == '0000') {
                        $state.go(response.payLoad.mobileURL);
                    }
                    else if (aoService.cifNumber == "0001") {
                        $state.go("menu.panDetails");
                    } else if (aoService.cifNumber == '1000') {
                        $state.go('menu.panDetails');
                    }
                    else {
                        $state.go("menu.multipleCustomer");
                    }

                } else {
                    $state.go(response.payLoad.mobileURL);
                }

                resumeJourneyVm.getCommonId(response.payLoad.commonId, proFlag);

            }, function (error) {
                var title = '';
                var template = error.responseMessage;
                var onTap = '';
                var buttontext = '<b>' + resumeJourneyVm.okBtntext + '</b>';
                utilityService.showAlertModal(title, template, onTap, $scope, $state, buttontext);
            });
        }

        resumeJourneyVm.getCommonId = function (commonId, proFlag) {

            aoService.getCommonId(commonId, proFlag);
        }

        resumeJourneyVm.getCustomerDetails = function () {
            var hashedAppPassword = cryptoService.getSHA512EncryptedData(resumeJourneyVm.resumePassword);
            resumeJourneyVm.encoded = hashedAppPassword.toString();

            var requestParams = {
                "id": resumeJourneyVm.resumeMobile,
                "password": resumeJourneyVm.encoded
            }

            resumeJourneyService.getCustomerDetails(requestParams).then(function (response) {
                var customerDetails = response.data;
                aoService.getResumeDocument(response.data);
                resumeJourneyVm.getPageDetails(response.data.productOfferingFlag);
            }, function (error) {
                if (!utilityService.isUndefined(error.data)) {
                    if (error.data.type.toLowerCase() == "ao_insta") {
                        var title = '';
                        var template = '{{"NOT_J23_ACC" | translate}}';
                        var onTap = 'menu.instaKit_resumeJourney';
                        var buttontext = '<b>' + resumeJourneyVm.okBtntext + '</b>';
                        utilityService.showAlertModal(title, template, onTap, $scope, $state, buttontext);
                    }
                } else if (error.responseCode == "0008") {
                    var title = '';
                    var template = error.responseMessage;
                    var onTap = '';
                    var buttontext = '<b>' + resumeJourneyVm.okBtntext + '</b>';
                    utilityService.showAlertModal(title, template, onTap, $scope, $state, buttontext);
                } else {
                    var title = '';
                    var template = 'Details do not match.';
                    var onTap = '';
                    var buttontext = '<b>' + resumeJourneyVm.okBtntext + '</b>';
                    utilityService.showAlertModal(title, template, onTap, $scope, $state, buttontext);
                }

            });
        }
        //Challenge Handler
        resumeJourneyVm.loginWithResume = function () {
            utilityService.showSpinner();
            resumeJourneyVm.aoAuthChallengeHandler.handleChallenge = function (challenge) {
                resumeJourneyVm.isChallenged = true;
                utilityService.hideSpinner();
                if (challenge.errorMsg !== null) {
                    utilityService.showErrorMessage(utilityService.getServerExceptionMessage(challenge));
                } else {
                    utilityService.showErrorMessage(constantConfig.adapter.CANNOT_PROCESS_NOW);
                }
            };

            resumeJourneyVm.aoAuthChallengeHandler.handleSuccess = function (data) {
                resumeJourneyVm.isChallenged = false;
                utilityService.hideSpinner();
                if (data.user) {
                    loggedInUserService.keyId = AdapterUtils.secretData == "" ? data.user.attributes.keyId : encryptionService.getAES256DecryptedData(data.user.attributes.keyId);
                    loggedInUserService.tokenLotus = AdapterUtils.secretData == "" ? data.user.attributes.lotusToken : encryptionService.getAES256DecryptedData(data.user.attributes.lotusToken);
                }
            };

            resumeJourneyVm.aoAuthChallengeHandler.handleFailure = function (error) {
                resumeJourneyVm.aoAuthChallengeHandler.cancel();
                resumeJourneyVm.isChallenged = false;
                utilityService.hideSpinner();
                if (error.failure) {
                    utilityService.showErrorMessage(error.failure);
                } else {
                    utilityService.showErrorMessage(constantConfig.adapter.CANNOT_PROCESS_NOW);
                }
            }

            var newKey = loggedInUserService.keyId;
            var passKey1Hashed = cryptoService.getSHA512EncryptedData(resumeJourneyVm.resumePassword);
            var passKeyHashed = cryptoService.getSHA512EncryptedData(passKey1Hashed + newKey);
            resumeJourneyVm.passKey = passKeyHashed.toString();

            var payload = {};
            var requestParams = {
                "mobileKey": resumeJourneyVm.resumeMobile,
                "passKey": resumeJourneyVm.passKey,
                "mfDeviceId": loggedInUserService.deviceIdForMpin
            }

            var passphraseSession;
            if (sessionStorage) {
                passphraseSession = sessionStorage.getItem('passphrase');
            }
            var passphrase = passphraseSession ? passphraseSession : encryptionService.passphrase;
            var src = cryptoService.encryptRSAWithPublicKey(encryptionService.iv + "^" + passphrase + "^" + encryptionService.salt, cryptoService.rsaPublicKey);
            payload = {
                "data": AdapterUtils.secretData + encryptionService.getAES256EncryptedData(JSON.stringify(requestParams)),
                "src": src
            }

            payload = AdapterUtils.secretData == "" ? requestParams : payload;

            if (resumeJourneyVm.isChallenged) {
                resumeJourneyVm.aoAuthChallengeHandler.submitChallengeAnswer(payload);
            } else {
                WLAuthorizationManager.login(resumeJourneyVm.aoAuthChallengeHandler.securityCheckName, payload).then(
                    function (data) {
                        utilityService.accessRestricted = utilityService.AOAuthRequired;
                        utilityService.hideSpinner();
                        resumeJourneyVm.getCustomerDetails();
                    },
                    function (error) {
                        utilityService.accessRestricted = "";
                        utilityService.hideSpinner();
                        if (error.errorCode == 'CHALLENGE_HANDLING_CANCELED' || error.errorCode == 'APPLICATION_DISABLED') {
                            return;
                        }
                        if (error.errorCode == "LOGIN_ALREADY_IN_PROCESS") {
                            resumeJourneyVm.aoAuthChallengeHandler.cancel();
                        }
                        utilityService.showErrorMessage(utilityService.getServerExceptionMessage(error));
                    });
            }
        }

        //one time initialization to be done when the controller is loaded
        $scope.$on('$ionicView.loaded', function () {
            initPage();
        });

        //actions to done everytime the view is shown
        $scope.$on('$ionicView.beforeEnter', function () {
            $ionicSideMenuDelegate.canDragContent(mPinLoginService.isLoggedIn);
        });

        $scope.$on('$ionicView.beforeLeave', function () {
            
        });

        return this;
    }
]);
