/**
 * @file : kucLandingController
 * Description : This files is for Apply screen of KUC journey
 *
 * @author : Hitesh Mandhan.
 * @since : 08-08-2020
 */
'use strict';

angularApp.controller('kucLandingController', [
    '$state',
    '$scope',
    '$translate','agriMandiService','cardsService','applyNowService',
    'newCardService','clickStreamService','cardConfig',
    '$ionicSideMenuDelegate',
    '$filter', 'utilityService','$ionicPopup','linkCardService','loggedInUserService','leadGenerationService',

    function ($state,
        $scope,
        $translate,agriMandiService,cardsService,applyNowService,
        newCardService,clickStreamService,cardConfig,
        $ionicSideMenuDelegate,
        $filter, utilityService, $ionicPopup,linkCardService,loggedInUserService,leadGenerationService) {

        var kucLandingVm = this;
        /* function call on back button */
        kucLandingVm.goBack = function () {
            if(agriMandiService.kucBannerFlag == true){
                agriMandiService.kucBannerFlag = false;
                $state.go('menu.agriLanding');
            }else{
                $state.go('menu.bachat');
            }
        };
        /* function call to set cards parameter and get cities master */
        function allowApplication() {
            applyNowService.resetApplyForm();
            newCardService.setParams({ "applyCardType": "SKU2" });
            newCardService.setParams({ "applyCardName": "KRISHAK UNNATI CARD" });
            newCardService.setParams({ "applyPictureURL": kucLandingVm.cardImageUrl });
            /* service call to get cities master */
            applyNowService.getCities().then(function(response) {
                cardsService.errorLogger(response);

                cardsService.setParams({ "city": response.data.cities });
                cardsService.setParams({ 'pendingApplication': false });
                //Adding below code for centralised consent sprint 2 journey cards module 
                leadGenerationService.checkConsent().then(function(response){
                    if(response.customerRecordExists == "false"){
                        newCardService.setPreLoginSelectedMenu('cards');
                        loggedInUserService.productClicked = 'menu.termsAndConditionsOutboundAnalytics';
                        $state.go('menu.termsAndConditionsOutboundAnalytics');
                    }else{
                        clickStreamService.sendClickStreamData(clickStreamService.setClickStreamData("OA_TNC_CONSENT" + "_" + "CC_START_NXT_BTN"));
                        $state.go('menu.cardPersonalDetails1');    
                    }
                }, function(error) {
                   utilityService.showErrorMessage(error.responseMessage);
                });
               
            }, function(error) {
                utilityService.showErrorMessage(error.responseMessage);
            });
        };

        /**
        * @desc function call on click of Apply button
        */
        kucLandingVm.applyNow = function() {
            agriMandiService.redirectionFlag = true;

            clickStreamService.clickStreamData = cardsService.getParams().cardName;
            var randomNumber;
            var requestDate = new Date();
            requestDate = requestDate.getTime();
            randomNumber=Math.floor((Math.random()) + requestDate);
            randomNumber = (randomNumber * 10 + 1);
            var payload = {
                secKey: randomNumber
            };

            applyNowService.getAllowApply(payload).then(function(response) {
                var newNumber=parseInt(response.data.secKey) ;
                var generatedNumber=(newNumber/2)-1;
                generatedNumber=generatedNumber/99;
                if (randomNumber !== generatedNumber) {
                    utilityService.showErrorMessage("We are Unable to Process Your Request")
                }else if (response.data.allowOverride == "true") {
                    var successAlertObj = {
                        cssClass: 'sbi-alert-popup',
                        buttons: [{
                            text: 'OK',
                            type: 'button-positive'
                        }]
                    }
                    var popTemplate = '<div class="text-align-center font-content sbi-sub-label roboto-regular" translate="CARDS_OVERWRITE_MSG"></div>'
                    var alertObj = {
                        template: popTemplate,
                        cssClass: 'sbi-alert-popup',
                        buttons: [{
                            text: 'Start New',
                            type: 'button-positive',
                            onTap: function(e) {
                                allowApplication();
                            }
                        }, {
                            text: 'Retreive',
                            type: 'button-positive',
                            onTap: function(e) {
                                $state.go('menu.retrieveTrackApplication');
                            }
                        }]
                    }
                    cardsService.alertModal(alertObj, function(res) {
                        //Just to load the alert
                        });
                } else {
                    allowApplication();
                }
            }, function(error) {
                if (error.responseCode == "8505") {
                    var messageTitle = "Message!";
                    var alertPop = $ionicPopup.alert({
                        title: messageTitle,
                        template: error.responseMessage
                    });
                } else {
                    utilityService.showErrorMessage(error.responseMessage);
                }
            });
        };
        /* function call on back button */
        kucLandingVm.goToKnowMore = function () {
            $state.go('menu.kucKnowMore');
        };
        /* function call on back button from know more screen */
        kucLandingVm.goBacktoPrevious = function () {
            $state.go('menu.kucLanding');
        }

        $scope.$on('$ionicView.beforeEnter', function () {
            kucLandingVm.showBack = true;
            kucLandingVm.showNext = false;
            kucLandingVm.cardImage = agriMandiService.kucKnowMoreData.krishakUnnatiCard.krishakImage;
            kucLandingVm.cardImageUrl = kucLandingVm.cardImage.replace(cardConfig.cardUrl.other_card, "https://www");
            kucLandingVm.features = agriMandiService.kucKnowMoreData.krishakUnnatiCard.featureSummery;
            kucLandingVm.knowMoreFeatures = agriMandiService.kucKnowMoreData.krishakUnnatiCard.feature;
            kucLandingVm.knowMoreFee = agriMandiService.kucKnowMoreData.krishakUnnatiCard.fe2;
            kucLandingVm.knowMoreCriteria = agriMandiService.kucKnowMoreData.krishakUnnatiCard.criteria;
        });

        return this;
    }
]);
