'use strict';

angularApp.controller('manageAggregatorsController', ["$state",
    "$rootScope",
    "utilityService",
    "constantConfig",
    "$ionicPlatform",
    "$scope",
    "$interval",
    "$filter",
    "$timeout",
    "$ionicScrollDelegate",
    "getAccountDetailsService",
    "$ionicPopup",
    "accountOverviewService",
    "cryptoService",
    "loggedInUserService",

    function ($state,
        $rootScope,
        utilityService,
        constantConfig,
        $ionicPlatform,
        $scope,
        $interval,
        $filter,
        $timeout,
        $ionicScrollDelegate,
        getAccountDetailsService,
        $ionicPopup,
        accountOverviewService,
        cryptoService,
        loggedInUserService) {

        var manageAggregatorsVm = this;

        manageAggregatorsVm.goBack = function () {
            $state.go('menu.accountOverviewMyBalance');
        }

        manageAggregatorsVm.addAggregator = function () {
            var reqParams = {}
            accountOverviewService.getAggregatorList(reqParams).then(function (data) {
                accountOverviewService.aggregatorList = data.aggLists;
                $state.go('menu.availableAggregators');
            }, function (error) {
                utilityService.hideSpinner();
                utilityService.showErrorMessage(error.responseMessage);
            });
        }

        manageAggregatorsVm.confirmDelink = function () {
            manageAggregatorsVm.deLinkAggregatorPopup.close();
            var reqParams = {
                consentId: manageAggregatorsVm.selectedAggregator.consentId,
                hash: cryptoService.getSHA512EncryptedData(loggedInUserService.tokenLotus + manageAggregatorsVm.selectedAggregator.consentId).toString()
            }
            accountOverviewService.deLinkAggregator(reqParams).then(function (data) {
                for (var i = 0; i < manageAggregatorsVm.aggConsentList.length; i++) {
                    if (manageAggregatorsVm.aggConsentList[i].consentId == manageAggregatorsVm.selectedAggregator.consentId) {
                        manageAggregatorsVm.aggConsentList[i].status = "Revoked";
                    }
                }
            }, function (error) {
                utilityService.hideSpinner();
                utilityService.showErrorMessage(error.responseMessage);
            });
        }

        manageAggregatorsVm.closeDelinkPopup = function () {
            manageAggregatorsVm.deLinkAggregatorPopup.close();
        }

        manageAggregatorsVm.deLinkAggregator = function (consent) {
            manageAggregatorsVm.selectedAggregator = consent;
            manageAggregatorsVm.deLinkAggregatorPopup = $ionicPopup.show({
                title: '',
                cssClass: 'removePopup-head popupWidth90 popupMargin popupBackgroundWhite inb-pop-btn ss-popup custOpacity',
                templateUrl: 'pages/accountOverview/accountAggregator/deLinkAggregatorPopup.html',
                scope: $scope
            });
        }

        manageAggregatorsVm.getConsentList = function () {
            manageAggregatorsVm.verifyAggPopup.close();
            var reqParams = {}
            accountOverviewService.getConsentList().then(function (data) {
                manageAggregatorsVm.aggConsentList = data.details;
                accountOverviewService.aggConsentList = manageAggregatorsVm.aggConsentList;
                if (manageAggregatorsVm.aggConsentList && manageAggregatorsVm.aggConsentList.length > 0) {
                    manageAggregatorsVm.verifyAggCardFlag = false;
                } else {
                    manageAggregatorsVm.verifyAggCardFlag = true;
                }
            }, function (error) {
                utilityService.hideSpinner();
                utilityService.showErrorMessage(error.responseMessage);
            });
        }

        manageAggregatorsVm.verifyAggregator = function () {
            if (!manageAggregatorsVm.accAggregatorId) {
                manageAggregatorsVm.formSubmitted = true;
                return true;
            }

            var reqParams = {
                vua: manageAggregatorsVm.accAggregatorId,
                hash: cryptoService.getSHA512EncryptedData(loggedInUserService.tokenLotus + manageAggregatorsVm.accAggregatorId).toString()
            }
            accountOverviewService.verifyAggregatorId(reqParams).then(function (data) {
                manageAggregatorsVm.verifyAggPopup = $ionicPopup.show({
                    title: '',
                    cssClass: 'removePopup-head popupWidth90 popupMargin popupBackgroundWhite inb-pop-btn ss-popup custOpacity',
                    templateUrl: 'pages/accountOverview/accountAggregator/verifyAggregatorPopup.html',
                    scope: $scope
                });
            }, function (error) {
                utilityService.hideSpinner();
                utilityService.showErrorMessage(error.responseMessage);
            });
        }

        manageAggregatorsVm.linkAccAggregator = function () {
            manageAggregatorsVm.verifyAggCardFlag = true;
        }

        manageAggregatorsVm.closeVerifyAggCard = function () {
            manageAggregatorsVm.verifyAggCardFlag = false;
            manageAggregatorsVm.accAggregatorId = "";
        }

        $scope.$on('$ionicView.beforeEnter', function () {
            manageAggregatorsVm.formSubmitted = false;
            manageAggregatorsVm.aggConsentList = accountOverviewService.aggConsentList;
            if (manageAggregatorsVm.aggConsentList && manageAggregatorsVm.aggConsentList.length > 0) {
                manageAggregatorsVm.verifyAggCardFlag = false;
            } else {
                manageAggregatorsVm.verifyAggCardFlag = true;
            }
        });

    }
]);
