

'use strict';

angularApp.factory('cardsService', ['$ionicPopup', '$window', 'cardConfig', '$q', "$filter", "$state",
    function($ionicPopup, $window, cardConfig, $q, $filter, $state) {
        var cardsService = this;
        var cardList = [];
        var selectedCard = 0;
        var cardToCompare = [];
        var callCenterNumber = [];
        var params = {};
        var applicationDetail;

        // common alert modal across cards
        function alertModal(obj, callback) {
            var alertPopup = $ionicPopup.alert(obj);

            alertPopup.then(function(res) {
                if (callback) {
                    callback(res);
                }
            });
        }

        // open external link in new tab
        function externalLink(url) {
            var link = cardConfig.links[url];
            $window.open(link, '_system');
        }

        function findIndex(array, key, val) {
            var index = 0;
            for (var i = 0; i < array.length; i++) {
                if (array[i][key] == val) {
                    index = i;
                    break;
                }
            }
            return index;
        }
        // Get Card List
        function getCardList() {
            return cardList;
        }
        // Set Card List
        function setCardList(list) {
            cardList = list;
            for (var i = 0; i < cardList.length; i++) {
                cardList[i]['id'] = i;
            }
        }
        // Get and Set Card Details inside cardList
        function getSetCardDetail(cardDetails, index) {
            if (index) setSelectedCard(index);
            if (cardDetails && cardList[selectedCard].hasOwnProperty('id')) {
                cardList[selectedCard]['cardDetails'] = cardDetails;
                return selectedCard;
            } else {

                return cardList[selectedCard];
            }
        }

        // Get Selected card index
        function getSelectedCard() {
            return selectedCard;
        }

        // Set Selected card index
        function setSelectedCard(index) {
            selectedCard = index;
        }

        function setParams(obj) {
            var setParams = angular.extend(params, obj);
        }

   
        function getParams() {
            return params;
        }
   
        function resetParams() {
            params = {};
        }

        function setApplicationDetail(data) {
            applicationDetail = data;
        }

        function getApplicationDetail() {
            return applicationDetail;

        }

        function getFutureYear(date, year) {
            date = new Date(date);
            var futureYear = date.setFullYear(date.getFullYear() + year);
            var days = new Date(date);
            days.setDate(days.getDate() + -1);
            return $filter('chosenDate')(days);
        }

        
        function errorLogger(response, callback) {
            if (response.responseCode != cardConfig.responseCode.success) {
                var popupObject = {
                    cssClass: 'sbi-alert-popup',
                    buttons: [{
                        text: cardConfig.buttons.OK_LABEL,
                        type: 'button-positive',

                    }]
                };
                popupObject.template = '<div class="text-align-center font-content sbi-sub-label roboto-regular">' + response.responseMessage + '</div>';
                alertModal(popupObject, callback);
            }

        }

        function inAppBrowser(url, closeCallback, backCallback) {
            cordova.ThemeableBrowser.open(url, '_blank', {
                statusbar: {
                    color: '#ffffffff'
                },
                toolbar: {
                    height: 37,
                    color: '#ffffffff',
                    image: 'share'
                },

                closeButton: {
                    image: 'back',
                    height: 37,
                    width: 32,
                    align: 'left',
                    event: 'closePressed'
                },


                backButtonCanClose: true
            }).addEventListener('backPressed', function(e) {
                backCallback();
            }).addEventListener('helloPressed', function(e) {

            }).addEventListener('sharePressed', function(e) {

            }).addEventListener(cordova.ThemeableBrowser.EVT_ERR, function(e) {

            }).addEventListener(cordova.ThemeableBrowser.EVT_WRN, function(e) {

            }).addEventListener('closePressed', function(e) {
              
            }).addEventListener('loadstart', function(e) {
			 $state.go('menu.cardOverview');
		});
        }


        function getPageRoute(pagename) {
            var currentDevice = pagename.split('_');
            var pageRoute = currentDevice[1];
            var pageDetail = {
                "cardPersonalDetails1": "personal.Details",
                "cardPersonalDetails2": "cardProfessional.Details",
                "cardProfessional1": "cardProfessional.Details",
                "cardProfessional2": "cardProfessional.Details"
            }
            
            if (currentDevice[0] == 'mobile') {
                return pageRoute;
            } else {
                for (var key in pageDetail) {
                    if (pageDetail.hasOwnProperty(key)) {
                        if (pageDetail[key] == pagename) {
                            return key;
                        }
                    }
                }
            }
        }


        return {
            alertModal: alertModal,
            externalLink: externalLink,
            findIndex: findIndex,
            getCardList: getCardList,
            setCardList: setCardList,
            getSelectedCard: getSelectedCard,
            setSelectedCard: setSelectedCard,
            getSetCardDetail: getSetCardDetail,
            setParams: setParams,
            getParams: getParams,
            resetParams: resetParams,
            setApplicationDetail: setApplicationDetail,
            getApplicationDetail: getApplicationDetail,
            getFutureYear: getFutureYear,
            errorLogger: errorLogger,
            inAppBrowser: inAppBrowser,
            getPageRoute: getPageRoute

        };

    }
]);
