/*
    Module Name  : Cards,
    File Name    : cardExpensesController.js,
    Description  : card Expenses page controller function
*/

'use strict';

angularApp.controller('cardExpensesController', ["$state", "$scope", "$translate", "newCardService", "cardConfig", "$interval", "cardsService", "simplifierService", "utilityService", "$timeout",
    function($state, $scope, $translate, newCardService, cardConfig, $interval, cardsService, simplifierService, utilityService, $timeout) {

        //functions, variables that can be accessed from the HTML come here
        var expensesVm = this;
        var currentIndex = 1;
        var exprensesValue, monthlyExpenseValue, rzSlideOptions;
        var rupeeSymbol = String.fromCharCode(8377);


        //Entry point
        function initPage() {
            expensesVm.totalExpense = 0;
            expensesVm.maxLimit = 50000;
            expensesVm.minLimit = 0;

            rzSlideOptions = {
                onChange: function() {
                    angular.forEach(expensesVm.groups, function(group) {
                        var amount = parseInt(group.value / 1000, 10) * 1000;
                        group.amount = amount;
                    });
                    newCardService.setParams({
                        expenses: expensesVm.groups
                    });

                },
                translate: function(value) {
                    value = (value) ? value : 0;
                    value = parseInt(value / 1000, 10);
                    return (value > 0) ? '&#8377; ' + value + ',000' : '&#8377; ' + value;
                }
            };
            var exprensesValue = newCardService.getParams().expenses;
            $scope.interval = $interval(function() {
                var totalExpense = 0;
                angular.forEach(expensesVm.groups, function(group) {
                    var amount = parseInt(group.value / 1000, 10) * 1000;
                    group.amount = amount;
                    totalExpense = parseInt(totalExpense) + parseInt(amount);


                });
                expensesVm.totalExpense = totalExpense;

            }, 50);
            if (exprensesValue) {
                expensesVm.groups = exprensesValue;
                angular.forEach(expensesVm.groups, function(group) {
                    group.value = group.amount;
                });

            } else {
                expensesVm.groups = cardsService.getParams().expenseWCM;

                for (var i = 0; i < expensesVm.groups.length; i++) {
                    expensesVm.groups[i].value = parseInt(expensesVm.groups[i].value);
                    expensesVm.groups[i].options["ceil"] = parseInt(expensesVm.groups[i].options["ceil"]);
                    expensesVm.groups[i].options["floor"] = parseInt(expensesVm.groups[i].options["floor"]);
                    expensesVm.groups[i].options["step"] = parseInt(expensesVm.groups[i].options["step"]);
                    expensesVm.groups[i].options = Object.assign(expensesVm.groups[i].options, rzSlideOptions);
                }
                var indexVar = 1;
                angular.forEach(expensesVm.groups, function(group) {
                    group.categoryName = group.category;
                    group.amount = 0;
                    group.isOpen = false;
                    group.index = indexVar;
                    indexVar++;
                });
            }



        }

        // close journey
        expensesVm.closeJourney = function() {
            $state.go('menu.cardIntroduction');
        }

        // group visibility toggle function
        expensesVm.isGroupShown = function(group) {
            return expensesVm.shownGroup === group;
        }

        // group toggle function
        expensesVm.toggleGroup = function(group) {
            group.isOpen = true; // Used to show expense on screen for particular category                  
            currentIndex = group.index;
            if (expensesVm.isGroupShown(group)) {
                expensesVm.shownGroup = null;
            } else {
                expensesVm.shownGroup = group;
            }
        }


        // go to cards suggestion page
        expensesVm.goToNext = function() {
            var payLoad;
            newCardService.setParams({
                expenses: expensesVm.groups,
                monthlyExpense: expensesVm.totalExpense
            });
            var simplifierData = simplifierService.getSimplifierCards();
            if (simplifierData) {
                var cardsObj = simplifierData;
                var otherCardsArr = cardsObj.cards;
                var topCardId = cardsObj.topCardId;
                var topCardName = cardsObj.topCardName;
                var index = otherCardsArr.indexOf(topCardName);
                if (index > -1) {
                    otherCardsArr.splice(index, 1);
                } else {}
                payLoad = {
                    "suggestedCard": topCardName,
                    "otherCards": otherCardsArr
                };
            }
            newCardService.suggestedCards(payLoad).then(function(response) {
                cardsService.errorLogger(response);
                if (response.data) {

                    if (response.data.otherCards) {
                        angular.forEach(response.data.otherCards, function(value, key) {
                            value.pictureURL = value.pictureURL.replace(cardConfig.cardUrl.other_card, "https://www");
                            value.pictureURL = value.pictureURL.replace(cardConfig.cardUrl.tata_card, "https://www.tatacard.com");

                        });
                    }
                  if(response.data.suggestedCard)
                  {
                    response.data.suggestedCard.pictureURL = response.data.suggestedCard.pictureURL.replace(cardConfig.cardUrl.other_card, "https://www");
                    response.data.suggestedCard.pictureURL = response.data.suggestedCard.pictureURL.replace(cardConfig.cardUrl.tata_card, "https://www.tatacard.com");

                    }
                    cardsService.setParams({ "suggestedCards": response.data });

                }
                $state.go('menu.cardSuggestion');
            }, function(error) {
                utilityService.showErrorMessage(error.responseMessage);
            });
        }

        // go to previous screen
        expensesVm.goBacktoPrevious = function() {
            $state.go('menu.cardAnnualIncome');



                   


        }

        //one time initialization to be done when the controller is loaded
        $scope.$on('$ionicView.beforeEnter', function() {
            initPage();
        });
        $scope.$on('$ionicView.leave', function() {
            $interval.cancel($scope.interval);
        });
    }
]);
