/*
    Module Name  : Cards,
    File Name    : newCardService.js,
    Description  : contains new card service functions
*/
'use strict';


angularApp.service('newCardService', ['commonAPIService', 'cardConfig', '$q', 'AdapterUtils','cardsService','utilityService','$state',
    function(commonAPIService, cardConfig, $q, AdapterUtils, cardsService, utilityService,$state) {

        var newCardService = this;
        var params = {};
        var preLoginSelectedMenu = '';
        var postLoginSelectedMenu = '';
        var termsAndConditionsOutboundAnalyticsData = '';

        newCardService.checkInvestNowClicked='';
        newCardService.resetPin = function(requestParams, callback) {
            commonAPIService.invokeAdapter(cardConfig.adapterURL.resetPin[0],
                cardConfig.adapterURL.resetPin[1], requestParams, callback);
        };
      
        newCardService.getRecommendedCards = function(requestParams, callback) {
            var q = $q.defer();
            AdapterUtils.postData(cardConfig.adapterURL.getRecommendedCards[0], requestParams, true).then(
                function(response) {

                    q.resolve(response);
                },
                function(error) {
                    q.reject(error);
                }
            );
            return q.promise;
        };

       
        newCardService.getCardsList = function(callback) {
            var q = $q.defer();
            AdapterUtils.postData(cardConfig.adapterURL.getCardsList[0], {}, true).then(
                function(response) {

                    q.resolve(response);
                },
                function(error) {
                    q.reject(error);
                }
            );
            return q.promise;
        };


        newCardService.getCardsListPrelogin = function(callback) {
            var q = $q.defer();
            AdapterUtils.postData(cardConfig.adapterURL.getCardsListPreLogin[0], {}, true).then(
                function(response) {

                    q.resolve(response);
                },
                function(error) {
                    q.reject(error);
                }
            );
            return q.promise;
        };

        /*
            Function Name: getCard,
            Input: (callback function),
            Output: none,
            Description: Makes selected card get service call
        */
        newCardService.getCard = function(requestParams, callback) {
            var q = $q.defer();
            AdapterUtils.postData(cardConfig.adapterURL.getCard[0], requestParams, true).then(
                function(response) {

                    q.resolve(response);
                },
                function(error) {
                    q.reject(error);
                }
            );
            return q.promise;

        };

        newCardService.getCardPreLogin = function(requestParams, callback) {
            var q = $q.defer();
            AdapterUtils.postData(cardConfig.adapterURL.getCardPreLogin[0], requestParams, true).then(
                function(response) {

                    q.resolve(response);
                },
                function(error) {
                    q.reject(error);
                }
            );
            return q.promise;

        };

        newCardService.getWelcomeMessages = function(callback) {
            var q = $q.defer();
            AdapterUtils.getData(cardConfig.adapterURL.getWelcomeMessages[0], null, true).then(
                function(response) {

                    q.resolve(response);
                },
                function(error) {
                    q.reject(error);
                }
            );
            return q.promise;
        };


       
        newCardService.privilegeGroups = function(callback) {
            var q = $q.defer();
            AdapterUtils.getData(cardConfig.adapterURL.getCardPrivileges[0], null, true).then(
                function(response) {

                    q.resolve(response);
                },
                function(error) {
                    q.reject(error);
                }
            );
            return q.promise;
        };


      
        newCardService.suggestedCards = function(requestParams, callback) {
            var q = $q.defer();
            AdapterUtils.postData(cardConfig.adapterURL.suggestedCards[0], requestParams, true).then(
                function(response) {

                    q.resolve(response);
                },
                function(error) {
                    q.reject(error);
                }
            );
            return q.promise;
        };

        /*
            Function Name: simplifierRule,
            Input: (callback function),
            Output: none,
            Description: get simplifier rule service call for rendering suggested cards 
        */
        newCardService.simplifierRule = function(callback) {
            commonAPIService.invokeAdapter(cardConfig.adapterURL.simplifierRule[0],
                cardConfig.adapterURL.simplifierRule[1], null, callback);
        };


        /*
            Function Name:showPendingApplication ,
            Input: (callback function),
            Output: none,
            Description: get simplifier rule service call for rendering suggested cards 
        */

        newCardService.showPendingApplication = function(callback) {
            commonAPIService.invokeAdapter(cardConfig.adapterURL.getSavedApplication[0],
                cardConfig.adapterURL.getSavedApplication[1], null, callback);
        };
        /*
            Function Name: setParams,
            Input: state params object,
            Output: none,
            Description: Set state params
        */
        newCardService.setParams = function(obj) {
                var setParams = angular.extend(params, obj);
            }
            /*
                Function Name: getParams,
                Input: none,
                Output: none,
                Description: Get state params
            */
        newCardService.getParams = function() {
                return params;
            }
         
        newCardService.resetParams = function() {
            params = {};
        }

        newCardService.getExpenseList = function(callback) {
            var q = $q.defer();
            AdapterUtils.getData(cardConfig.adapterURL.getExpenseList[0], null, true).then(
                function(response) {

                    q.resolve(response);
                },
                function(error) {
                    q.reject(error);
                }
            );
            return q.promise;

        };

        newCardService.getSimplifier = function(callback) {
            /* commonAPIService.invokeAdapter(cardConfig.adapterURL.getExpenseList[0],
                 cardConfig.adapterURL.getExpenseList[1], null, callback);*/
            var q = $q.defer();
            AdapterUtils.getData(cardConfig.adapterURL.getSimplifierLogic[0], {}, true).then(
                function(response) {

                    q.resolve(response);
                },
                function(error) {
                    q.reject(error);
                }
            );
            return q.promise;

        };
        newCardService.needAnalysis = function() {
            newCardService.getWelcomeMessages().then(function(response) {
                cardsService.errorLogger(response);
                if (response.data && response.data.message) {
                    newCardService.resetParams();
                    cardsService.setParams({ "needAnalysisWelcome": response.data.message });
                    $state.go('menu.cardWelcome');
                }


            }, function(error) {
                utilityService.showErrorMessage(error.responseMessage);
            });

        };

          newCardService.browseCards = function() {
              newCardService.getCardsList().then(function(response) {
                  cardsService.errorLogger(response);
                  if (response.data && response.data.cards.length > 0) {
                      cardsService.setParams({ "browseAllCards": response.data.cards });
                      cardsService.setParams({ "browseCardsTabSelected": 'All' });
                      cardsService.isComingIntro = true;
                      $state.go('menu.browseCards');
                  }
              }, function(error) {
                  utilityService.showErrorMessage(error.responseMessage);
              });

        }
		  
		newCardService.browseCardsTabs = function(tabname) {
              newCardService.getCardsList().then(function(response) {
                  cardsService.errorLogger(response);
                  if (response.data && response.data.cards.length > 0) {
                      cardsService.setParams({ "browseAllCards": response.data.cards });
					  cardsService.setParams({ "browseCardsTabSelected": tabname });
                      cardsService.isComingIntro = true;
                      $state.go('menu.browseCards');
                  }
              }, function(error) {
                  utilityService.showErrorMessage(error.responseMessage);
              });
        }
        newCardService.browseCardsPreLogin = function() {
              newCardService.getCardsListPrelogin().then(function(response) {
                  cardsService.errorLogger(response);
                  if (response.data && response.data.cards.length > 0) {
                      cardsService.setParams({ "browseAllCards": response.data.cards });
                      cardsService.setParams({ "browseCardsTabSelected": 'All' });
                      cardsService.isComingIntro = true;
                      $state.go('menu.browseCards');
                  }
              }, function(error) {
                  utilityService.showErrorMessage(error.responseMessage);
              });

        }
		  
		newCardService.browseCardsTabsPreLogin = function(tabname) {
              newCardService.getCardsListPrelogin().then(function(response) {
                  cardsService.errorLogger(response);
                  if (response.data && response.data.cards.length > 0) {
                      cardsService.setParams({ "browseAllCards": response.data.cards });
					  cardsService.setParams({ "browseCardsTabSelected": tabname });
                      cardsService.isComingIntro = true;
                      $state.go('menu.browseCards');
                  }
              }, function(error) {
                  utilityService.showErrorMessage(error.responseMessage);
              });
        }
        newCardService.getRecommendedCardsPreLogin = function(requestParams, callback) {
            var q = $q.defer();
            AdapterUtils.postData(cardConfig.adapterURL.getRecommendedCardsPreLogin[0], requestParams, true).then(
                function(response) {

                    q.resolve(response);
                },
                function(error) {
                    q.reject(error);
                }
            );
            return q.promise;
        };

        //pick topic
        newCardService.getCardsTopPicksForPostLogin = function(requestParams, callback) {
            var q = $q.defer();
            AdapterUtils.postData("adapters/FSSCommonAdapter/oa/v1/getRecommendedProductsAndContent", requestParams, true).then(
                function(response) {

                    q.resolve(response);
                },
                function(error) {
                    q.reject(error);
                }
            );
            return q.promise;
        };

        newCardService.getTermsAndConditionsOA = function(requestParams, callback) {
            var q = $q.defer();
            AdapterUtils.postData(cardConfig.adapterURL.getTnCOA[0], requestParams, true).then(
                function(response) {

                    q.resolve(response);
                },
                function(error) {
                    q.reject(error);
                }
            );
            return q.promise;
        };

        newCardService.setPreLoginSelectedMenu = function(menu){
            preLoginSelectedMenu = menu;
        }

        newCardService.getPreLoginSelectedMenu = function(){
            return preLoginSelectedMenu;
        }

        newCardService.setPostLoginSelectedMenu = function(menu){
            postLoginSelectedMenu = menu;
        }

        newCardService.getPostLoginSelectedMenu = function(){
            return postLoginSelectedMenu;
        }

        newCardService.setTermsAndConditionsOutboundAnalyticsData = function(data){
            termsAndConditionsOutboundAnalyticsData = data;
        }

        newCardService.getTermsAndConditionsOutboundAnalyticsData = function(){
            return termsAndConditionsOutboundAnalyticsData;
        }
        return newCardService;

    }
]);
