'use strict';
angularApp.controller('scanPayController', [
	"$state",
	"$scope",
	"$ionicPopup",
	"$translate",
	"$ionicHistory",
	"utilityService",
	"bQRService",
	"mPinLoginService",
	"loggedInUserService",
	"customerInfoService",
	function ($state, $scope, $ionicPopup, $translate, $ionicHistory, utilityService, bQRService, mPinLoginService, loggedInUserService, customerInfoService) {

		var scanPayVm = this;

		scanPayVm.cancelPayment = function () {
			if (mPinLoginService.isLoggedIn == true) {
				if (customerInfoService.scanQrEntrypoint && customerInfoService.scanQrEntrypoint !== 'FTLANDING') {
					$state.go('menu.fundtrans');
				} else {
					$state.go('menu.fundsTransferLanding');
				}
			} else {
				$state.go('menu.userLogin');
			}
		}

		scanPayVm.goToNext = function () {
			if (scanPayVm.validateMandatoryFields()) {
				bQRService.convenienceFee = scanPayVm.convenienceFee || 0;
				bQRService.transactionAmount = scanPayVm.transactionAmount;
				bQRService.purpose = scanPayVm.purpose;
				bQRService.billNumber = scanPayVm.billNumber;
				bQRService.loyaltyNumber = scanPayVm.loyaltyNumber;
				if (mPinLoginService.isLoggedIn == true) {
					bQRService.merchantDetails = scanPayVm.merchantDetails;
					bQRService.accountUserSelectedMain = [];
					bQRService.selectedVpaDetails = {};
					$state.go("menu.ftPayment");
				} else {
					bQRService.merchantDetails = scanPayVm.merchantDetails;
					bQRService.accountUserSelectedMain = [];
					bQRService.selectedVpaDetails = {};
					loggedInUserService.productClicked = 'menu.ftPayment';
					$state.go('menu.userLogin');
				}
			}
		}

		scanPayVm.validateMandatoryFields = function () {
			if (scanPayVm.merchantDetails.convenienceFeeFixed) {
				scanPayVm.convenienceFee = scanPayVm.merchantDetails.convenienceFeeFixed;
			}
			if (scanPayVm.merchantDetails.transactionAmount) {
				scanPayVm.transactionAmount = scanPayVm.merchantDetails.transactionAmount;
			}
			if (!scanPayVm.transactionAmount || (scanPayVm.transactionAmount && scanPayVm.transactionAmount <= 0)) {
				utilityService.showBhimUpiAlert("error", "Please enter valid transaction amount");
				return false;
			}
			if (scanPayVm.convenienceFee && scanPayVm.convenienceFee < 0) {
				utilityService.showBhimUpiAlert("error", "Please enter the valid convenience fee");
				return false;
			}
			if (scanPayVm.merchantDetails.convenienceFeePercentage) {
				scanPayVm.convenienceFee = (Number.parseFloat(scanPayVm.transactionAmount) * Number.parseFloat(scanPayVm.merchantDetails.convenienceFeePercentage)) / 100;
			}
			if (!scanPayVm.merchantDetails.merchantCategoryCode) {
				utilityService.showBhimUpiAlert("error", "Invalid QR Code. Merchant Category Code(MCC) missing.");
				return false;
			}
			if (scanPayVm.merchantDetails.merchantCategoryCode && scanPayVm.merchantDetails.merchantCategoryCode.length !== 4) {
				utilityService.showBhimUpiAlert("error", "Invalid Merchant Category Code(MCC)");
				return false;
			}
			if (!scanPayVm.merchantDetails.transactionCurrencyCode) {
				utilityService.showBhimUpiAlert("error", "Invalid QR Code. Currency Code missing.");
				return false;
			}
			if (scanPayVm.merchantDetails.transactionCurrencyCode && (!Number.isInteger(Number.parseInt(scanPayVm.merchantDetails.transactionCurrencyCode)) || scanPayVm.merchantDetails.transactionCurrencyCode.length !== 3)) {
				utilityService.showBhimUpiAlert("error", "Invalid Currency Code");
				return false;
			}
			var alphaRegex = /^[A-Za-z]+$/;
			if (scanPayVm.merchantDetails.crc && (alphaRegex.test(scanPayVm.merchantDetails.crc) || scanPayVm.merchantDetails.crc.length !== 4)) {
				utilityService.showBhimUpiAlert("error", "Invalid CRC");
				return false;
			}
			if (!scanPayVm.merchantDetails.qrType) {
				utilityService.showBhimUpiAlert("error", "Invalid QR. Point of Initiation missing.");
				return false;
			}
			return true;
		}

		scanPayVm.goToBack = function () {
			// if (mPinLoginService.isLoggedIn == true)
			// 	$state.go('menu.payToQR');
			// else
			// 	$state.go('menu.userLogin');
			if (mPinLoginService.isLoggedIn == true) {
				if (customerInfoService.scanQrEntrypoint && customerInfoService.scanQrEntrypoint !== 'FTLANDING') {
					$state.go('menu.fundtrans');
				} else {
					$state.go('menu.fundsTransferLanding');
				}
			} else {
				$state.go('menu.userLogin');
			}
		}

		$scope.$on('$ionicView.beforeEnter', function () {
			scanPayVm.platform = device.platform.toLowerCase();
			bQRService.accountDetailsSelected = [];
			scanPayVm.convenienceFee = bQRService.convenienceFee;
			scanPayVm.transactionAmount = bQRService.transactionAmount;
			scanPayVm.purpose = bQRService.purpose;
			scanPayVm.billNumber = bQRService.billNumber;
			scanPayVm.loyaltyNumber = bQRService.loyaltyNumber;
			scanPayVm.merchantDetails = bQRService.merchantDetails;
			if (scanPayVm.merchantDetails.convenienceFeeFixed || scanPayVm.merchantDetails.convenienceFeePercentage)
				scanPayVm.convenienceFeeAvailable = true;
			if (scanPayVm.merchantDetails.transactionAmount)
				scanPayVm.transactionAmountAvailable = true;
			if (scanPayVm.merchantDetails.purpose && scanPayVm.merchantDetails.purpose !== '***')
				scanPayVm.purposeAvailable = true;
			if (scanPayVm.merchantDetails.loyaltyNumber && scanPayVm.merchantDetails.loyaltyNumber !== '***')
				scanPayVm.loyaltyNumberAvailable = true;
			if (scanPayVm.merchantDetails.billNumber && scanPayVm.merchantDetails.billNumber !== '***')
				scanPayVm.billNumberAvailable = true;
		});

		scanPayVm.goToHome = function () {
			if (mPinLoginService.isLoggedIn == true)
				$state.go('menu.payToQR');
			else
				$state.go('menu.userLogin');
		}
		return this;
	}
]);


