'use strict';

angularApp.controller('accountsController', ["$state",
    "$ionicPopup",
    "$scope",
    "customerInfoService",
    "utilityService",
    "constantConfig",
    "$rootScope",
    "bhimUpiService",
    "serviceRequestService",
    "getAccountDetailsService",
    function ($state,
        $ionicPopup,
        $scope,
        customerInfoService,
        utilityService,
        constantConfig,
        $rootScope,
        bhimUpiService,
        serviceRequestService,
        getAccountDetailsService) {

        var accountsVm = this;

        $scope.isGroupShown = function (accountType) {
            return ($scope.shownGroup === accountType);
        };

        $scope.toggleGroup = function (accountType) {
            if ($scope.isGroupShown(accountType)) {
                $scope.shownGroup = null;
            } else {
                $scope.shownGroup = accountType;
            }
        };

        accountsVm.viewAllUpiIds = function () {
            $state.go('menu.viewAllUpiIds');
        }

        accountsVm.enableDisableUPI = function () {

            bhimUpiService.accountListFromAPI = [];
            bhimUpiService.accountListFromSDK = [];
            bhimUpiService.accountList = [];
            if (!getAccountDetailsService.accountOverviewData) {
                utilityService.showErrorMessage('Cannot process now, please try after some time.');
            }
            else {
                if (getAccountDetailsService.accountOverviewData.accounts.length > 0) {
                    bhimUpiService.accountListFromAPI = getAccountDetailsService.accountOverviewData.accounts.filter(function (obj) {
                        return obj.accountType == "Current A/c" || obj.accountType == "Overdraft A/c" || obj.accountType == "Savings A/c";
                    });
                }


                bhimUpiService.accountList = angular.copy(bhimUpiService.accountListFromAPI);
                bhimUpiService.entryForEnableDisable = "menu.accounts";
                utilityService.showSpinner();
                getAccountListFromUPISDK();
            }
           


        }

        function getAccountListFromUPISDK() {

            var json = JSON.stringify({
                "requestInfo": {
                    "pspId": constantConfig.upiConstant.pspId,
                    "pspRefNo": generateRandomString(27)
                },
                "userInfo": {
                    "defVPAStatus": constantConfig.upiConstant.defVPAStatus,
                    "isMerchant": constantConfig.upiConstant.isMerchant,
                    "showMerchant": constantConfig.upiConstant.showMerchant
                }
            });
            bhimUpiService.getNativeData("getAccountListForEnableDisableServices", json).then(function (data) {
                var accObj = JSON.parse(data);
                utilityService.hideSpinner();
                var isAccountExists = -1;
                if (accObj.status == 'S') {
                    bhimUpiService.accountListFromSDK = accObj.accountList || [];
                    for (var i = 0; i < bhimUpiService.accountListFromSDK.length; i++) {
                        if (bhimUpiService.accountListFromAPI.length > 0) {
                            isAccountExists = -1;
                            bhimUpiService.accountListFromAPI.some(function (obj, j) {
                                var accNumberFromAPI = obj.accountNumber.substring(obj.accountNumber.length - 4);
                                var accNumberFromSDK = bhimUpiService.accountListFromSDK[i].maskedAccountNumber.substring(bhimUpiService.accountListFromSDK[i].maskedAccountNumber.length - 4);
                                return accNumberFromAPI == accNumberFromSDK ? isAccountExists = j : false;
                            });
                            if (isAccountExists !== -1) {
                                //account already exist
                            } else {
                                //push account to acc list
                                var arr = [];
                                arr.accountNumber = bhimUpiService.accountListFromSDK[i].maskedAccountNumber;
                                arr.unmaskedAccountNumber = bhimUpiService.accountListFromSDK[i].accountNumber;
                                arr.accounttype = bhimUpiService.accountListFromSDK[i].accountType;
                                arr.branchCode = bhimUpiService.accountListFromSDK[i].ifscCode.slice(6, 11);
                                arr.type = "sdk";
                                bhimUpiService.accountList.push(arr);
                            }
                        }
                    }
                    $state.go('menu.enableDisableUpi');
                } else {
                    utilityService.showBhimUpiAlert("alert", accObj.statusDesc);
                }
            }, function (msg) {
                utilityService.hideSpinner();
                utilityService.showBhimUpiAlert("error", msg);
            });
        }

        accountsVm.addBankAcc = function (action) {
            customerInfoService.action = action;
            if (customerInfoService.action == 'CREATENEWUPIID') {
                accountsVm.accountList = [];
                utilityService.showSpinner();
                var json = JSON.stringify({
                    "addInfo": {
                        "addInfo10": constantConfig.upiConstant.addInfo10,
                        "addInfo9": constantConfig.upiConstant.addInfo9
                    },
                    "bankCode": "SBIN",
                    "recoveryOptionFlag": constantConfig.upiConstant.recoveryOptionFlag,
                    "requestInfo": {
                        "pspId": constantConfig.upiConstant.pspId,
                        "pspRefNo": generateRandomString(27)
                    },
                    "requestType": "E",
                    "updateFlag": constantConfig.upiConstant.updateFlag,
                    "userInfo": {
                        "defVPAStatus": constantConfig.upiConstant.defVPAStatus,
                        "isMerchant": constantConfig.upiConstant.isMerchant,
                        "name": "",
                        "showMerchant": constantConfig.upiConstant.showMerchant,
                        "accountId": 0,
                        "virtualAddress": ""
                    }
                });
                bhimUpiService.getNativeData(constantConfig.upiConstant.getaccountListAPI, json).then(function (data) {
                    var accObj = JSON.parse(data);
                    utilityService.hideSpinner();
                    if (accObj.status == 'S') {
                        accountsVm.accountsLoaded = true;
                        accountsVm.accountList = accObj.accountList;
                        accountsVm.pspRespRefNo = accObj.requestInfo.pspRespRefNo;
                        customerInfoService.accountsDetails = {
                            "pspRespRefNo": accountsVm.pspRespRefNo,
                            "accountList": accountsVm.accountList,
                            "bank": "",
                            "accountObj": accObj
                        }
                        if (customerInfoService.action == 'ADDACC') {
                            $state.go('menu.viewBankAccounts');
                        } else {
                            $state.go('menu.createNewUpiId');
                        }
                    } else {
                        utilityService.showBhimUpiAlert("alert", accObj.statusDesc);
                    }
                }, function (msg) {
                    utilityService.hideSpinner();
                    utilityService.showBhimUpiAlert("error", msg);
                });
            } else {
                utilityService.showSpinner();
                var json = JSON.stringify({
                    "addInfo": {
                        "addInfo10": constantConfig.upiConstant.addInfo10,
                        "addInfo9": constantConfig.upiConstant.addInfo9
                    },
                    "recoveryOptionFlag": constantConfig.upiConstant.recoveryOptionFlag,
                    "requestInfo": {
                        "pspId": constantConfig.upiConstant.pspId,
                        "pspRefNo": generateRandomString(27)
                    },
                    "updateFlag": constantConfig.upiConstant.updateFlag
                });
                bhimUpiService.getNativeData(constantConfig.upiConstant.getbankListAPI, json).then(function (data) {
                    utilityService.hideSpinner();
                    accountsVm.banklistResponse = JSON.parse(data);
                    if (accountsVm.banklistResponse.status == 'S') {
                        customerInfoService.bankList = accountsVm.banklistResponse.bankMasterList;
                        customerInfoService.addAccountVpa = accountsVm.selectedVpa ? accountsVm.selectedVpa.virtualAddress : "";
                        $state.go('menu.addAccount', {});
                    } else {
                        utilityService.showBhimUpiAlert("error", "Currently system is facing some technical challanges for fetching the bank list. Please try after sometime.");
                    }
                }, function (msg) {
                    utilityService.hideSpinner();
                    utilityService.showBhimUpiAlert("error", msg);
                });
            }
        }

        accountsVm.setOrResetUpiPin = function (account) {
            customerInfoService.selectedAccountDtls = account;
            customerInfoService.vpaForSetPin = accountsVm.selectedVpa.virtualAddress;
            $state.go('menu.setUpiPin');
        }

        accountsVm.viewAccBalance = function (account) {
            utilityService.showSpinner();
            var json = JSON.stringify({
                "addInfo": {
                    "addInfo10": constantConfig.upiConstant.addInfo10,
                    "addInfo9": constantConfig.upiConstant.addInfo9
                },
                "requestInfo": {
                    "pspId": constantConfig.upiConstant.pspId,
                    "pspRefNo": generateRandomString(27)
                },
                "virtualAddress": accountsVm.selectedVpa.virtualAddress,
                "accountId": account.accId
            });
            bhimUpiService.getNativeData(constantConfig.upiConstant.onBalanceEnquiry, json).then(function (data) {
                var checkBalanceRes = JSON.parse(data).apiResp;
                utilityService.hideSpinner();
                if (checkBalanceRes.status == 'S') {
                    var balanceEnqPopup = $ionicPopup.show({
                        template: '<p><span>Acc No. : </span><span>' + checkBalanceRes.accountInfo.maskedAccountNumber + '</span><br><span>Balance : </span><span>' + checkBalanceRes.accountInfo.accountBalance + '</span></p>',
                        title: 'Balance Enquiry',
                        cssClass: 'dialog',
                        scope: $scope,
                        buttons: [{
                            text: 'Ok',
                            type: 'button-negative',
                            onTap: function (e) {
                                balanceEnqPopup.close();
                            }
                        }]
                    });
                } else {
                    utilityService.showBhimUpiAlert("error", checkBalanceRes.statusDesc);
                }
            }, function (msg) {
                utilityService.hideSpinner();
                if (msg != -101)
                    utilityService.showBhimUpiAlert("error", msg);
            });
        }

        accountsVm.setPrimaryAccount = function (account) {
            utilityService.showSpinner();
            var json = JSON.stringify({
                "recoveryOptionFlag": constantConfig.upiConstant.recoveryOptionFlag,
                "requestInfo": {
                    "pspId": constantConfig.upiConstant.pspId,
                    "pspRefNo": generateRandomString(27)
                },
                "requestType": constantConfig.upiConstant.requestType_DA,
                "accountList": [{
                    "accId": account.accId
                }],
                "updateFlag": 0,
                "userInfo": {
                    "defVPAStatus": constantConfig.upiConstant.defVPAStatus,
                    "isMerchant": false,
                    "showMerchant": false,
                    "accountId": 0,
                    "virtualAddress": accountsVm.selectedVpa.virtualAddress
                }
            });
            bhimUpiService.getNativeData(constantConfig.upiConstant.onUpdateAccountList, json).then(function (data) {
                var setPrimaryAccResp = JSON.parse(data);
                utilityService.hideSpinner();
                if (setPrimaryAccResp.status == 'S') {
                    utilityService.showBhimUpiAlert("success", setPrimaryAccResp.statusDesc);
                    //accountsVm.selectedVpa = "";
                    accountsVm.getProfileData();
                } else {
                    utilityService.showBhimUpiAlert("error", setPrimaryAccResp.statusDesc);
                }
            }, function (msg) {
                utilityService.hideSpinner();
                utilityService.showBhimUpiAlert("error", msg);
            });
        }

        accountsVm.deLinkAccount = function (account, indexValue) {
            var confirmPopup = $ionicPopup.confirm({
                title: '',
                template: '<p style="text-align: initial;"><b>Are you sure you want to delete your ' + account.maskedAccountNumber + ' Account from ' + accountsVm.selectedVpa.virtualAddress + '?</b></p>',
                cssClass: 'dialog',
                buttons: [{
                    text: 'Cancel'
                }, {
                    text: 'Confirm',
                    onTap: function (e) {
                        accountsVm.confirmDeLinkAccount(account, indexValue);
                    }
                }]
            });
        }

        accountsVm.confirmDeLinkAccount = function (account, indexValue) {
            utilityService.showSpinner();
            var json = JSON.stringify({
                "recoveryOptionFlag": constantConfig.upiConstant.recoveryOptionFlag,
                "requestInfo": {
                    "pspId": constantConfig.upiConstant.pspId,
                    "pspRefNo": generateRandomString(27)
                },
                "requestType": constantConfig.upiConstant.requestType_RA,
                "accountList": [{
                    "accId": account.accId
                }],
                "updateFlag": 0,
                "userInfo": {
                    "defVPAStatus": constantConfig.upiConstant.defVPAStatus,
                    "isMerchant": false,
                    "showMerchant": false,
                    "accountId": 0,
                    "virtualAddress": accountsVm.selectedVpa.virtualAddress
                }
            });
            bhimUpiService.getNativeData(constantConfig.upiConstant.onUpdateAccountList, json).then(function (data) {
                var setPrimaryAccResp = JSON.parse(data);
                utilityService.hideSpinner();
                if (setPrimaryAccResp.status == 'S') {
                    for (var i = 0; i < customerInfoService.payerProfileDtls.vpaAccountDetails.length; i++) {
                        if (customerInfoService.payerProfileDtls.vpaAccountDetails[i].virtualAddress == accountsVm.selectedVpa.virtualAddress) {
                            for (var j = 0; j < customerInfoService.payerProfileDtls.vpaAccountDetails[i].accountInfo.length; j++) {
                                if (customerInfoService.payerProfileDtls.vpaAccountDetails[i].accountInfo[j].accId == account.accId) {
                                    customerInfoService.payerProfileDtls.vpaAccountDetails[i].accountInfo.splice(j, 1);
                                    accountsVm.payerProfileDetails = customerInfoService.payerProfileDtls.vpaAccountDetails;


                                    //accountsVm.selectedVpa = '';
                                    for (var i = 0; i < accountsVm.payerProfileDetails.length; i++) {
                                        if (accountsVm.payerProfileDetails[i].virtualAddress == accountsVm.selectedVpa.virtualAddress) {
                                            accountsVm.selectedVpa = accountsVm.payerProfileDetails[i];
                                            accountsVm.accounts = accountsVm.selectedVpa.accountInfo;
                                        }
                                    }





                                    utilityService.showBhimUpiAlert("success", setPrimaryAccResp.statusDesc);
                                }
                            }
                        }
                    }
                    //accountsVm.accounts.splice(indexValue, 1);
                    // utilityService.showBhimUpiAlert("success", setPrimaryAccResp.statusDesc);
                } else {
                    utilityService.showBhimUpiAlert("error", setPrimaryAccResp.statusDesc);
                }
            }, function (msg) {
                utilityService.hideSpinner();
                utilityService.showBhimUpiAlert("error", msg);
            });
        }

        accountsVm.getProfileData = function () {
            utilityService.showSpinner();
            var json = JSON.stringify({
                "recoveryOptionFlag": constantConfig.upiConstant.recoveryOptionFlag,
                "requestInfo": {
                    "pspId": constantConfig.upiConstant.pspId,
                    "pspRefNo": generateRandomString(27)
                },
                "updateFlag": constantConfig.upiConstant.updateFlag
            });
            bhimUpiService.getNativeData(constantConfig.upiConstant.getProfile, json).then(function (data) {
                utilityService.hideSpinner();
                var getProfileResponse = JSON.parse(data);
                if (getProfileResponse.status == "S") {
                    //accountsVm.payerProfileDetails = '';
                    accountsVm.payerProfileDetails = getProfileResponse.vpaAccountDetails;
                    customerInfoService.payerProfileDtls = getProfileResponse;


                    for (var i = 0; i < accountsVm.payerProfileDetails.length; i++) {
                        if (accountsVm.payerProfileDetails[i].virtualAddress == accountsVm.selectedVpa.virtualAddress) {
                            accountsVm.selectedVpa = accountsVm.payerProfileDetails[i];
                            accountsVm.accounts = accountsVm.selectedVpa.accountInfo;
                        }
                    }




                } else {
                    utilityService.showBhimUpiAlert("error", getProfileResponse.statusDesc);
                }
            }, function (msg) {
                utilityService.hideSpinner();
                utilityService.showBhimUpiAlert("error", msg);
            });
        }

        accountsVm.changeUpiPin = function (account) {
            utilityService.showSpinner();
            var json = JSON.stringify({
                "addInfo": {
                    "addInfo10": constantConfig.upiConstant.addInfo10,
                    "addInfo9": constantConfig.upiConstant.addInfo9
                },
                "requestInfo": {
                    "pspId": constantConfig.upiConstant.pspId,
                    "pspRefNo": generateRandomString(27)
                },
                "accountId": account.accId,
                "virtualAddress": accountsVm.selectedVpa.virtualAddress
            });
            bhimUpiService.getNativeData(constantConfig.upiConstant.onChangeMpin, json).then(function (data) {
                var changeUpiPinResp = JSON.parse(data).apiResp;
                utilityService.hideSpinner();
                if (changeUpiPinResp.status == 'S') {
                    accountsVm.confirmPopup = $ionicPopup.confirm({
                        cssClass: 'dialog',
                        template: '<div class="button_fund fontSize-subHeading roboto-light font-dark-grey">You have successfully changed your UPI pin.</div>',
                        buttons: [{
                            text: '<span>OK</span>',
                            onTap: function (e) {
                                accountsVm.confirmPopup.close();
                            }
                        }]
                    });
                } else {
                    utilityService.showBhimUpiAlert("error", changeUpiPinResp.statusDesc);
                }
            }, function (msg) {
                utilityService.hideSpinner();
                if (msg != -101)
                    utilityService.showBhimUpiAlert("error", msg);
            });
        }

        accountsVm.changeVpa = function (selectedVpa) {
            if (selectedVpa)
                accountsVm.accounts = selectedVpa.accountInfo;
            else
                accountsVm.accounts = '';
        }

        accountsVm.close = function () {
            $state.go('menu.fundtrans');
        }

        $scope.$on('$ionicView.beforeEnter', function () {
            accountsVm.platform = device.platform.toLowerCase();
            // accountsVm.payerProfileDetails = '';
            // accountsVm.accounts = '';
            // accountsVm.selectedVpa = '';
            accountsVm.payerProfileDetails = customerInfoService.payerProfileDtls.vpaAccountDetails;


            for (var i = 0; i < accountsVm.payerProfileDetails.length; i++) {
                if (accountsVm.payerProfileDetails[i].defVPAStatus) {
                    accountsVm.selectedVpa = accountsVm.payerProfileDetails[i];
                    accountsVm.accounts = accountsVm.selectedVpa.accountInfo;
                    // for (var j = 0; j < accountsVm.selectedVpa.accountInfo.length; j++) {
                    //     if (accountsVm.selectedVpa.accountInfo[j].preferredFlag == 'T') {
                    //         accountsVm.accounts = accountsVm.selectedVpa.accountInfo[j];
                    //     }
                    // }
                }
            }



        });
        return this;
    }
]);
