'use strict';

angularApp.controller('payToVpa_PayeeDetailsController', ["$state",
	"$ionicPopup",
	"$scope",
	"customerInfoService",
	"utilityService",
	"constantConfig",
	"$rootScope",
	"ionicToast",
	"bhimUpiService",

	function ($state,
		$ionicPopup,
		$scope,
		customerInfoService,
		utilityService,
		constantConfig,
		$rootScope,
		ionicToast,
		bhimUpiService) {

		var payToVpa_PayeeDetailsVm = this;

		payToVpa_PayeeDetailsVm.changeAccount = function () {
			payToVpa_PayeeDetailsVm.accountBalance = "";
		}

		payToVpa_PayeeDetailsVm.viewBalance = function (account) {
			payToVpa_PayeeDetailsVm.accountBalance = "";
			utilityService.showSpinner();
			var json = JSON.stringify({
				"addInfo": {
					"addInfo10": constantConfig.upiConstant.addInfo10,
					"addInfo9": constantConfig.upiConstant.addInfo9
				},
				"requestInfo": {
					"pspId": constantConfig.upiConstant.pspId,
					"pspRefNo": generateRandomString(27)
				},
				"virtualAddress": payToVpa_PayeeDetailsVm.selectedVpa.virtualAddress,
				"accountId": account.accId
			});
			bhimUpiService.getNativeData(constantConfig.upiConstant.onBalanceEnquiry, json).then(function (data) {
				var checkBalanceRes = JSON.parse(data).apiResp;
				utilityService.hideSpinner();
				if (checkBalanceRes.status == 'S') {
					payToVpa_PayeeDetailsVm.accountBalance = checkBalanceRes.accountInfo.accountBalance;
				} else {
					utilityService.showBhimUpiAlert("error", checkBalanceRes.statusDesc);
				}
			}, function (msg) {
				utilityService.hideSpinner();
				if (msg != -101)
					utilityService.showBhimUpiAlert("error", msg);
			});
		}

		payToVpa_PayeeDetailsVm.changeVpa = function (selectedVpa) {
			if (selectedVpa) {
				payToVpa_PayeeDetailsVm.accounts = selectedVpa.accountInfo;
				for (var j = 0; j < selectedVpa.accountInfo.length; j++) {
					if (selectedVpa.accountInfo[j].preferredFlag == 'T') {
						payToVpa_PayeeDetailsVm.selectedAccount = selectedVpa.accountInfo[j];
					}
				}
			} else {
				payToVpa_PayeeDetailsVm.accounts = '';
			}
		}

		payToVpa_PayeeDetailsVm.validateFormFields = function () {
			if (!payToVpa_PayeeDetailsVm.payeeDetails.amount || payToVpa_PayeeDetailsVm.payeeDetails.amount < 1 || payToVpa_PayeeDetailsVm.payeeDetails.amount > 100000) {
				utilityService.showBhimUpiAlert("alert", "Please Enter Valid Amount Between ₹1 - ₹1,00,000");
				return false;
			}
			if (!payToVpa_PayeeDetailsVm.selectedVpa) {
				utilityService.showBhimUpiAlert("alert", "Please Select UPI ID from which you want to make a payment");
				return false;
			}
			if (!payToVpa_PayeeDetailsVm.selectedAccount) {
				utilityService.showBhimUpiAlert("alert", "Please Select an account number from which you want to make a payment");
				return false;
			}
			// if (payToVpa_PayeeDetailsVm.payeeDetails.savePayee && !payToVpa_PayeeDetailsVm.payeeDetails.nickName) {
			// 	utilityService.showBhimUpiAlert("alert", "Please Enter Nick Name");
			// 	return false;
			// }
			if(payToVpa_PayeeDetailsVm.remarkPurpose =="Other" && utilityService.isEmpty(payToVpa_PayeeDetailsVm.remarkOther))
			{
				utilityService.showBhimUpiAlert("alert", "Please Enter Remark");
				return false;
			}
			return true;
		}

		payToVpa_PayeeDetailsVm.goToReview = function () {
			if (payToVpa_PayeeDetailsVm.validateFormFields()) {
				if (customerInfoService.payeeDetails.requestType == 'collect' || customerInfoService.payeeDetails.requestType == 'collectFromLanding') {
					payToVpa_PayeeDetailsVm.approveCollect();
				} else {
					if (payToVpa_PayeeDetailsVm.selectedAccount.mpinFlag && payToVpa_PayeeDetailsVm.selectedAccount.mpinFlag == 'N') {
						utilityService.showBhimUpiAlert("alert", "Please set the UPI Pin for selected account number to make the payments");
						return false;
					}

					if (payToVpa_PayeeDetailsVm.payeeDetails.vpa && payToVpa_PayeeDetailsVm.payeeDetails.vpa == payToVpa_PayeeDetailsVm.selectedVpa.virtualAddress) {
						utilityService.showBhimUpiAlert("alert", "From and To UPI ID can not be same");
						return false;
					}

					customerInfoService.payeeDetails.nickName = payToVpa_PayeeDetailsVm.payeeDetails.nickName;
					customerInfoService.payeeDetails.amount = payToVpa_PayeeDetailsVm.payeeDetails.amount;
					customerInfoService.payeeDetails.remark = payToVpa_PayeeDetailsVm.payeeDetails.remark;
					customerInfoService.payeeDetails.savePayee = payToVpa_PayeeDetailsVm.payeeDetails.savePayee;

					customerInfoService.payerDetails = {
						vpa: payToVpa_PayeeDetailsVm.selectedVpa.virtualAddress,
						accountObj: payToVpa_PayeeDetailsVm.selectedAccount
					}
					if (!customerInfoService.payeeDetails.isBeneExist && (customerInfoService.payeeDetails.payeeType == 'AC' || customerInfoService.payeeDetails.payeeType == 'VA') && customerInfoService.payeeDetails.savePayee == true)
						payToVpa_PayeeDetailsVm.saveOrUpdateBeneficiary();
					else
						$state.go('menu.payToVpa_Review');
				}
			}
		}

		payToVpa_PayeeDetailsVm.saveOrUpdateBeneficiary = function () {
			utilityService.showSpinner();
			var json = {};
			if (customerInfoService.payeeDetails.payeeType == 'AC') {
				json = JSON.stringify({
					"appVersionCode": 0,
					"beneficiaryDetail": {
						"addressType": customerInfoService.payeeDetails.payeeType,
						"beneficiaryId": 0,
						"name": customerInfoService.payeeDetails.name,
						"ifsc": customerInfoService.payeeDetails.ifsc,
						"accountNo": customerInfoService.payeeDetails.accountNo
					},
					"recoveryOptionFlag": constantConfig.upiConstant.recoveryOptionFlag,
					"requestInfo": {
						"pspId": constantConfig.upiConstant.pspId,
						"pspRefNo": generateRandomString(27)
					},
					"requestType": "A",
					"updateFlag": 0
				});
			} else {
				json = JSON.stringify({
					"appVersionCode": 0,
					"beneficiaryDetail": {
						"addressType": customerInfoService.payeeDetails.payeeType,
						"beneficiaryId": 0,
						"name": customerInfoService.payeeDetails.name,
						"nickName": customerInfoService.payeeDetails.nickName || "",// || customerInfoService.payeeDetails.name,
						"virtualAddress": customerInfoService.payeeDetails.vpa
					},
					"recoveryOptionFlag": constantConfig.upiConstant.recoveryOptionFlag,
					"requestInfo": {
						"pspId": constantConfig.upiConstant.pspId,
						"pspRefNo": generateRandomString(27)
					},
					"requestType": "A",
					"updateFlag": 0
				});
			}

			bhimUpiService.getNativeData(constantConfig.upiConstant.updateBeneficiary, json).then(function (data) {
				// customerInfoService.payeeDetails.isBeneExist = true;
				// if (customerInfoService.payeeDetails.payeeType == 'AC') {
				// 	bhimUpiService.accBeneAdded = true;
				// } else {
				// 	bhimUpiService.upiBeneAdded = true;
				// }
				var updateBeneficiaryResp = JSON.parse(data);
				utilityService.hideSpinner();
				if (updateBeneficiaryResp.status == 'S') {
					customerInfoService.payeeDetails.isBeneExist = true;
					if (customerInfoService.payeeDetails.payeeType == 'AC') {
						bhimUpiService.accBeneAdded = true;
					} else {
						bhimUpiService.upiBeneAdded = true;
					}

					$state.go('menu.payToVpa_Review');
				} else {
					utilityService.showBhimUpiAlert("error", updateBeneficiaryResp.statusDesc);
					//$state.go('menu.payToVpa_Review');
				}
			}, function (msg) {
				utilityService.hideSpinner();
				utilityService.showBhimUpiAlert("error", msg);
			});
		}

		payToVpa_PayeeDetailsVm.approveCollect = function () {
			utilityService.showSpinner();
			var json = JSON.stringify({
				"addInfo": {
					"addInfo10": constantConfig.upiConstant.addInfo10,
					"addInfo9": constantConfig.upiConstant.addInfo9
				},
				"approvalStatus": "A",
				"expiryTime": 0,
				"npciTranId": customerInfoService.upiCollectRequest.txnId,
				"payerType": {
					"accountId": payToVpa_PayeeDetailsVm.selectedAccount.accId,
					"virtualAddress": payToVpa_PayeeDetailsVm.selectedVpa.virtualAddress
				},
				"requestInfo": {
					"pspId": constantConfig.upiConstant.pspId,
					"pspRefNo": generateRandomString(27)
				},
				"upiTransRefNo": customerInfoService.upiCollectRequest.upiTrnRefNo
			});
			bhimUpiService.getNativeData(constantConfig.upiConstant.onCollectApprove, json).then(function (data) {
				var collectApproveResp = JSON.parse(data).apiResp;
				utilityService.hideSpinner();
				if (collectApproveResp.status == 'S') {
					utilityService.setCsatJournies("fundTransfer");
					payToVpa_PayeeDetailsVm.approveCollectPopup = $ionicPopup.confirm({
						cssClass: 'bhim-alert-popup',
						template: '<div class="font-dark-grey"><div><img class="approvedIconPosition" src="img/FT/BhimUpi/successSymbol.svg" /></div><div class="roboto-regular trans-popup fontSize-title errorColor"></div></div><div class="popupTextBottomPadding fontSize-subHeading"><div class="textAlignCenter"><span>' + collectApproveResp.statusDesc + '</span></div></div></div>',
						buttons: [{
							text: 'OK',
							type: 'button-positive',
							onTap: function (e) {
								payToVpa_PayeeDetailsVm.approveCollectPopup.close();
								if (customerInfoService.payeeDetails.requestType == 'collect')
									$state.go('menu.transactionHistory');
								else
									$state.go('menu.fundtrans');
							}
						}]
					});
				} else {
					utilityService.showBhimUpiAlert("error", collectApproveResp.statusDesc);
				}
			}, function (msg) {
				utilityService.hideSpinner();
				if (msg != -101)
					utilityService.showBhimUpiAlert("error", msg);
			});
		}

		payToVpa_PayeeDetailsVm.goBack = function () {
			if (customerInfoService.payeeDetails.requestType == 'pay') {
				if (customerInfoService.payeeDetails.payeeType == 'AC')
					if (customerInfoService.payeeDetails.isBeneExist) {
						$state.go('menu.upiPayments');
					} else {
						$state.go('menu.payToAccount');
					}
				if (customerInfoService.payeeDetails.payeeType == 'VA')
					if (customerInfoService.payeeDetails.isBeneExist) {
						$state.go('menu.upiPayments');
					} else {
						$state.go('menu.payToVpa');
					}
				if (customerInfoService.payeeDetails.payeeType == 'QR')
					$state.go('menu.payToQR');
			} else if (customerInfoService.payeeDetails.requestType == 'qr_pay') {
				$state.go('menu.fundtrans');
			} else {
				$state.go('menu.transactionHistory');
			}
		}

		payToVpa_PayeeDetailsVm.cancel = function () {
			if (customerInfoService.payeeDetails.requestType == 'pay') {
				$state.go('menu.upiPayments');
			} else if (customerInfoService.payeeDetails.requestType == 'collect') {
				$state.go('menu.transactionHistory');
			} else {
				$state.go('menu.fundtrans');
			}
		}

		$scope.$on('$ionicView.beforeEnter', function () {
			utilityService.hideSpinner();
			payToVpa_PayeeDetailsVm.payeeDetails = {
				payeeType: customerInfoService.payeeDetails.payeeType,
				accountNo: customerInfoService.payeeDetails.accountNo,
				ifsc: customerInfoService.payeeDetails.ifsc,
				bankName: customerInfoService.payeeDetails.bankName,
				name: customerInfoService.payeeDetails.name,
				vpa: customerInfoService.payeeDetails.vpa,
				amount: customerInfoService.payeeDetails.amount,
				remark: customerInfoService.payeeDetails.remark,
				nickName: customerInfoService.payeeDetails.nickName || customerInfoService.payeeDetails.name,
				phoneNumber: customerInfoService.payeeDetails.phoneNumber,
				savePayee: customerInfoService.payeeDetails.savePayee,
				isBeneExist: customerInfoService.payeeDetails.isBeneExist
			}

			payToVpa_PayeeDetailsVm.selectedVpa = "";
			payToVpa_PayeeDetailsVm.selectedAccount = "";
			payToVpa_PayeeDetailsVm.accounts = "";
			payToVpa_PayeeDetailsVm.accountBalance = "";
			payToVpa_PayeeDetailsVm.remarkPurpose="";
			payToVpa_PayeeDetailsVm.remarkOther="";

			payToVpa_PayeeDetailsVm.remarkPurposes=payToVpa_PayeeDetailsVm.getFTPurposes();
		

			payToVpa_PayeeDetailsVm.payerProfileDetails = customerInfoService.payerProfileDtls;

			for (var i = 0; i < payToVpa_PayeeDetailsVm.payerProfileDetails.vpaAccountDetails.length; i++) {
				if (payToVpa_PayeeDetailsVm.payerProfileDetails.vpaAccountDetails[i].defVPAStatus) {
					payToVpa_PayeeDetailsVm.selectedVpa = payToVpa_PayeeDetailsVm.payerProfileDetails.vpaAccountDetails[i];
					
					var filteredArray = payToVpa_PayeeDetailsVm.selectedVpa.accountInfo.filter(function(itm){
  						return itm.mpinFlag == 'Y';
					});
					payToVpa_PayeeDetailsVm.selectedVpa.accountInfo = filteredArray;
					payToVpa_PayeeDetailsVm.accounts = payToVpa_PayeeDetailsVm.selectedVpa.accountInfo;
					payToVpa_PayeeDetailsVm.selectedAccount = payToVpa_PayeeDetailsVm.selectedVpa.accountInfo[0];
					for (var j = 0; j < payToVpa_PayeeDetailsVm.selectedVpa.accountInfo.length; j++) {
						if (payToVpa_PayeeDetailsVm.selectedVpa.accountInfo[j].preferredFlag == 'T') {
							payToVpa_PayeeDetailsVm.selectedAccount = payToVpa_PayeeDetailsVm.selectedVpa.accountInfo[j];
						}
						
					}
				}
			}

			payToVpa_PayeeDetailsVm.payeeDetails.requestType = customerInfoService.payeeDetails.requestType || "";

			payToVpa_PayeeDetailsVm.disableAmountField = false;
			if (payToVpa_PayeeDetailsVm.payeeDetails.payeeType == "QR") {
				payToVpa_PayeeDetailsVm.paymentType = "QR CODE";
				if(payToVpa_PayeeDetailsVm.payeeDetails.amount && payToVpa_PayeeDetailsVm.payeeDetails.amount >= 1){
					payToVpa_PayeeDetailsVm.disableAmountField = true;
				}
			} else if (payToVpa_PayeeDetailsVm.payeeDetails.payeeType == "AC") {
				payToVpa_PayeeDetailsVm.paymentType = "BANK ACCOUNT";
			} else {
				payToVpa_PayeeDetailsVm.paymentType = "UPI";
			}
		});
		

	payToVpa_PayeeDetailsVm.updateRemark =function(){
		payToVpa_PayeeDetailsVm.payeeDetails.remark=payToVpa_PayeeDetailsVm.remarkOther;			
	} 
	payToVpa_PayeeDetailsVm.updatePurpose = function(){
		if(payToVpa_PayeeDetailsVm.remarkPurpose=="Others"){					
		
			payToVpa_PayeeDetailsVm.payeeDetails.remark="";
	
								
						
	}
		else{
			payToVpa_PayeeDetailsVm.remarkOther="";
			payToVpa_PayeeDetailsVm.payeeDetails.remark=payToVpa_PayeeDetailsVm.remarkPurpose;
				
		}
	}
	payToVpa_PayeeDetailsVm.getFTPurposes = function(){
		
   
		   bhimUpiService.getFTPurposes().then(function(data){
	   payToVpa_PayeeDetailsVm.remarkPurposes=data.remarkPurposes;
	   },function (error) {
	   utilityService.showErrorMessage(error.responseMessage);
	   }
	   ); 
	
   }
	
	

		return this;
	}
]);
