'use strict';

angularApp.controller('payToAccountController', ["$state",
	"$ionicPopup",
	"$scope",
	"customerInfoService",
	"utilityService",
	"$rootScope",
	"constantConfig",
	"validationService",
	"bhimUpiService",
	"$http",

	function ($state,
		$ionicPopup,
		$scope,
		customerInfoService,
		utilityService,
		$rootScope,
		constantConfig,
		validationService,
		bhimUpiService, $http) {

		var payToAccountVm = this;

		payToAccountVm.goToPaymentDetails = function () {
			if (!(payToAccountVm.payeeDetails.ifsc && payToAccountVm.isValidIfscFormat)) {
				utilityService.showBhimUpiAlert("alert", "Please Enter Valid IFSC");
				return false;
			}
			if (payToAccountVm.payeeDetails.accountNo) {
				if (payToAccountVm.payeeDetails.accountNo !== payToAccountVm.payeeDetails.confirmAccountNo) {
					utilityService.showBhimUpiAlert("alert", "Account Number and Confirm Account Number should Be Same");
					return false;
				}
			} else {
				utilityService.showBhimUpiAlert("alert", "Please Enter Account Number");
				return false;
			}
			if (!payToAccountVm.payeeDetails.name) {
				utilityService.showBhimUpiAlert("alert", "Please Enter Beneficiary Name");
				return false;
			}
			if (payToAccountVm.payeeDetails.phoneNumber && !validationService.isValidMobile(payToAccountVm.payeeDetails.phoneNumber)) {
				utilityService.showBhimUpiAlert("alert", "Please Enter Valid Mobile Number");
				return false;
			}
			payToAccountVm.getProfile();
		}

		payToAccountVm.getProfile = function () {
			utilityService.showSpinner();
			var json = JSON.stringify({
				"recoveryOptionFlag": constantConfig.upiConstant.recoveryOptionFlag,
				"requestInfo": {
					"pspId": constantConfig.upiConstant.pspId,
					"pspRefNo": generateRandomString(27)
				},
				"updateFlag": constantConfig.upiConstant.updateFlag
			});
			bhimUpiService.getNativeData(constantConfig.upiConstant.getProfile, json).then(function (data) {
				utilityService.hideSpinner();
				var getProfileResponse = JSON.parse(data);
				if (getProfileResponse.status == "S") {
					bhimUpiService.getBankDetails().then(function (bankName) {
						var bankIfscCode = payToAccountVm.payeeDetails.ifsc.slice(0,4).toUpperCase();
						bankName = bankName[bankIfscCode];
						if(!bankName){
							utilityService.showBhimUpiAlert("error", "Please validate the IFSC code");
							return false;
						}
						customerInfoService.payerProfileDtls = getProfileResponse;
						customerInfoService.payeeDetails = {
							payeeType: "AC",
							requestType: 'pay',
							accountNo: payToAccountVm.payeeDetails.accountNo,
							ifsc: payToAccountVm.payeeDetails.ifsc,
							bankName : bankName || "",
							name: payToAccountVm.payeeDetails.name,
							vpa: payToAccountVm.payeeDetails.vpa || "",
							amount: payToAccountVm.payeeDetails.amount || "",
							remark: payToAccountVm.payeeDetails.remark || "",
							nickName: payToAccountVm.payeeDetails.nickName || "",
							phoneNumber: payToAccountVm.payeeDetails.phoneNumber || "",
							savePayee: payToAccountVm.payeeDetails.savePayee || false
						}
						$state.go('menu.payToVpa_PayeeDetails');
					}, function (error) {
						utilityService.showBhimUpiAlert("error", "There is some issue in validating the IFSC code");
					});
				} else {
					utilityService.showBhimUpiAlert("error", getProfileResponse.statusDesc);
				}
			}, function (msg) {
				utilityService.hideSpinner();
				utilityService.showBhimUpiAlert("error", msg);
			});
		};

		payToAccountVm.showInfoPopup = function () {
			payToAccountVm.oneTimePaymentPopup = $ionicPopup.show({
				template: '<p>One Time Payment.</p>',
				title: '',
				cssClass: 'dialog',
				scope: $scope,
				buttons: [{
					text: 'OK',
					type: 'button-positive',
					onTap: function (e) {
						payToAccountVm.oneTimePaymentPopup.close();
					}
				}]
			});
		}

		payToAccountVm.validateIfsc = function () {
			if (!utilityService.isEmpty(payToAccountVm.payeeDetails.ifsc)) {
				payToAccountVm.isValidIfscFormat = validationService.isValidIFSC(payToAccountVm.payeeDetails.ifsc);
			}
		}

		payToAccountVm.goBack = function () {
			$state.go('menu.upiPayments');
		}

		$scope.$on('$ionicView.beforeEnter', function () {
			payToAccountVm.isValidIfscFormat = true;

			payToAccountVm.payeeDetails = {
				payeeType: customerInfoService.payeeDetails.payeeType,
				accountNo: customerInfoService.payeeDetails.accountNo,
				confirmAccountNo: customerInfoService.payeeDetails.accountNo,
				ifsc: customerInfoService.payeeDetails.ifsc,
				name: customerInfoService.payeeDetails.name,
				vpa: customerInfoService.payeeDetails.vpa,
				amount: customerInfoService.payeeDetails.amount,
				remark: customerInfoService.payeeDetails.remark,
				nickName: customerInfoService.payeeDetails.nickName,
				phoneNumber: customerInfoService.payeeDetails.phoneNumber,
				savePayee: customerInfoService.payeeDetails.savePayee || false
			}
		});

		return this;
	}



]);
