'use strict';
angularApp.controller('upiPaymentsController', [
	"$state",
	"$ionicPopup",
	"$scope",
	"ionicToast",
	"customerInfoService",
	"utilityService",
	"homeLoanService",
	"$q",
	"fTBeneficiaryService",
	"constantConfig",
	"bhimUpiService",
	function ($state, $ionicPopup, $scope, ionicToast, customerInfoService, utilityService, homeLoanService, $q, fTBeneficiaryService, constantConfig, bhimUpiService) {

		var upiPaymentsVm = this;

		upiPaymentsVm.fetchUpiBeneficiaries = function () {
			if (customerInfoService.upiBeneficiaries && !bhimUpiService.upiBeneAdded) {
				upiPaymentsVm.upiBeneficiaries = customerInfoService.upiBeneficiaries;
			} else {
				if (customerInfoService.upiBeneficiaries && bhimUpiService.upiBeneAdded) {
					upiPaymentsVm.upiBeneficiaries = customerInfoService.upiBeneficiaries;
				} else {
					utilityService.showSpinner();
				}
				var json = JSON.stringify({
					"appVersionCode": 0,
					"recoveryOptionFlag": constantConfig.upiConstant.recoveryOptionFlag,
					"requestInfo": {
						"pspId": constantConfig.upiConstant.pspId,
						"pspRefNo": generateRandomString(27)
					},
					"requestType": "VA",
					"updateFlag": constantConfig.upiConstant.updateFlag
				});
				bhimUpiService.getNativeData(constantConfig.upiConstant.getBeneficiaryList, json).then(function (data) {
					utilityService.hideSpinner();
					var addOrRemoveFavBeniWebResponse = JSON.parse(data);
					if (addOrRemoveFavBeniWebResponse.status == 'S') {
						if (addOrRemoveFavBeniWebResponse.beneficiaryList && addOrRemoveFavBeniWebResponse.beneficiaryList.length > 0) {
							upiPaymentsVm.upiBeneficiaries = addOrRemoveFavBeniWebResponse.beneficiaryList;
							customerInfoService.upiBeneficiaries = upiPaymentsVm.upiBeneficiaries;
						} else {
							upiPaymentsVm.upiBeneficiaries = [];
							customerInfoService.upiBeneficiaries = upiPaymentsVm.upiBeneficiaries;
						}
					} else {
						if (customerInfoService.upiBeneficiaries) {
							ionicToast.show(addOrRemoveFavBeniWebResponse.statusDesc, 'bottom', false, 2000);
						}else{
							utilityService.showBhimUpiAlert("error", addOrRemoveFavBeniWebResponse.statusDesc);
						}
					}
				}, function (msg) {
					utilityService.hideSpinner();
					utilityService.showBhimUpiAlert("error", msg);
				});
			}
		}

		upiPaymentsVm.fetchUpiAccBeneficiaries = function () {
			if (customerInfoService.upiAccBeneficiaries && !bhimUpiService.accBeneAdded) {
				upiPaymentsVm.beneficiaries = customerInfoService.upiAccBeneficiaries;
			} else {
				if (customerInfoService.upiAccBeneficiaries && bhimUpiService.accBeneAdded) {
					upiPaymentsVm.beneficiaries = customerInfoService.upiAccBeneficiaries;
				} else {
					utilityService.showSpinner();
				}
				var json = JSON.stringify({
					"appVersionCode": 0,
					"recoveryOptionFlag": constantConfig.upiConstant.recoveryOptionFlag,
					"requestInfo": {
						"pspId": constantConfig.upiConstant.pspId,
						"pspRefNo": generateRandomString(27)
					},
					"requestType": "AC",
					"updateFlag": constantConfig.upiConstant.updateFlag
				});
				bhimUpiService.getNativeData(constantConfig.upiConstant.getBeneficiaryList, json).then(function (data) {
					bhimUpiService.accBeneAdded = bhimUpiService.accBeneAdded == true ? false : true;
					utilityService.hideSpinner();
					var getBeneficiaryList = JSON.parse(data);
					if (getBeneficiaryList.status == 'S') {
						if (getBeneficiaryList.beneficiaryList && getBeneficiaryList.beneficiaryList.length > 0) {
							upiPaymentsVm.beneficiaries = getBeneficiaryList.beneficiaryList;
							customerInfoService.upiAccBeneficiaries = upiPaymentsVm.beneficiaries;
						} else {
							upiPaymentsVm.beneficiaries = [];
							customerInfoService.upiAccBeneficiaries = upiPaymentsVm.beneficiaries;
						}
					} else {
						if(customerInfoService.upiAccBeneficiaries){
							ionicToast.show(getBeneficiaryList.statusDesc, 'bottom', false, 2000);
						}else{
							utilityService.showBhimUpiAlert("error", getBeneficiaryList.statusDesc);
						}
					}
				}, function (msg) {
					utilityService.hideSpinner();
					utilityService.showBhimUpiAlert("error", msg);
				});
			}
		}

		upiPaymentsVm.deleteUpiBeneficiary = function (upiBeneficiary, indexVal) {
			var deleteUpiBeneficiaryPopup = $ionicPopup.show({
				template: '<div class="button_fund fontSize-subHeading roboto-light font-dark-grey">Are you sure, you want to delete UPI beneficiary?</div>',
				title: 'Delete Beneficiary',
				cssClass: 'dialog',
				scope: $scope,
				buttons: [{
					text: 'Cancel',
					type: 'button-negative',
					onTap: function (e) {
						deleteUpiBeneficiaryPopup.close();
					}
				},
				{
					text: 'Ok',
					type: 'button-negative',
					onTap: function (e) {
						deleteUpiBeneficiaryPopup.close();
						if (upiBeneficiary.addressType == 'VA') {
							upiPaymentsVm.deleteUpiBeneficiaryConfirm(upiBeneficiary, indexVal);
						} else if (upiBeneficiary.addressType == 'AC') {
							upiPaymentsVm.deleteUpiAccBeneficiaryConfirm(upiBeneficiary, indexVal);
						}
					}
				}]
			});
		}

		upiPaymentsVm.deleteUpiAccBeneficiaryConfirm = function (upiBeneficiary, indexVal) {
			utilityService.showSpinner();
			var json = JSON.stringify({
				"appVersionCode": 0,
				"beneficiaryDetail": {
					"addressType": upiBeneficiary.addressType,
					"beneficiaryId": upiBeneficiary.beneficiaryId,
					"name": upiBeneficiary.name || "",
					"ifsc": upiBeneficiary.ifsc || "",
					"accountNo": upiBeneficiary.accountNo || ""
				},
				"recoveryOptionFlag": constantConfig.upiConstant.recoveryOptionFlag,
				"requestInfo": {
					"pspId": constantConfig.upiConstant.pspId,
					"pspRefNo": generateRandomString(27)
				},
				"requestType": "R",
				"updateFlag": 0
			});
			bhimUpiService.getNativeData(constantConfig.upiConstant.updateBeneficiary, json).then(function (data) {
				var deleteBeneficiaryResp = JSON.parse(data);
				utilityService.hideSpinner();
				if (deleteBeneficiaryResp.status == 'S') {
					for (var i = 0; i < upiPaymentsVm.beneficiaries.length; i++) {
						if (upiPaymentsVm.beneficiaries[i].beneficiaryId == upiBeneficiary.beneficiaryId) {
							delete upiPaymentsVm.beneficiaries[i];
						}
					}
					//delete upiPaymentsVm.beneficiaries[indexVal];
				} else {
					utilityService.showBhimUpiAlert("error", deleteBeneficiaryResp.statusDesc);
				}
			}, function (msg) {
				utilityService.hideSpinner();
				utilityService.showBhimUpiAlert("error", msg);
			});
		}

		upiPaymentsVm.deleteUpiBeneficiaryConfirm = function (upiBeneficiary, indexVal) {
			utilityService.showSpinner();
			var json = JSON.stringify({
				"appVersionCode": 0,
				"beneficiaryDetail": {
					"addressType": upiBeneficiary.addressType,
					"beneficiaryId": upiBeneficiary.beneficiaryId,
					"name": upiBeneficiary.name || "",
					"nickName": upiBeneficiary.nickName || "",
					"virtualAddress": upiBeneficiary.virtualAddress || ""
				},
				"recoveryOptionFlag": constantConfig.upiConstant.recoveryOptionFlag,
				"requestInfo": {
					"pspId": constantConfig.upiConstant.pspId,
					"pspRefNo": generateRandomString(27)
				},
				"requestType": "R",
				"updateFlag": 0
			});
			bhimUpiService.getNativeData(constantConfig.upiConstant.updateBeneficiary, json).then(function (data) {
				var deleteBeneficiaryResp = JSON.parse(data);
				utilityService.hideSpinner();
				if (deleteBeneficiaryResp.status == 'S') {
					for (var i = 0; i < upiPaymentsVm.upiBeneficiaries.length; i++) {
						if (upiPaymentsVm.upiBeneficiaries[i].beneficiaryId == upiBeneficiary.beneficiaryId) {
							delete upiPaymentsVm.upiBeneficiaries[i];
						}
					}
					//delete upiPaymentsVm.upiBeneficiaries[indexVal];
				} else {
					utilityService.showBhimUpiAlert("error", deleteBeneficiaryResp.statusDesc);
				}
			}, function (msg) {
				utilityService.hideSpinner();
				utilityService.showBhimUpiAlert("error", msg);
			});
		}

		upiPaymentsVm.payNewBeneficiary = function () {
			if (upiPaymentsVm.tabIndex == 'one') {
				customerInfoService.payerDetails = {};
				customerInfoService.payeeDetails = {};
				$state.go('menu.payToVpa');
			}
			if (upiPaymentsVm.tabIndex == 'two') {
				customerInfoService.payerDetails = {};
				customerInfoService.payeeDetails = {};
				upiPaymentsVm.verifyPayeePopUp();
			}
			if (upiPaymentsVm.tabIndex == 'three') {
				customerInfoService.payerDetails = {};
				customerInfoService.payeeDetails = {};
				$state.go('menu.payToAccount');
			}
		}

		upiPaymentsVm.payToUPIBeneficiary = function (upiBeneficiary) {

			if (!upiBeneficiary.virtualAddress) {
				utilityService.showBhimUpiAlert("alert", "Please Enter beneficiary UPI ID");
				return false;
			}
			utilityService.showSpinner();
			var json = JSON.stringify({
				"addInfo": {
					"addInfo10": constantConfig.upiConstant.addInfo10,
					"addInfo9": constantConfig.upiConstant.addInfo9
				},
				"payeeType": {
					"virtualAddress": upiBeneficiary.virtualAddress.toString()
				},
				"requestInfo": {
					"pspId": constantConfig.upiConstant.pspId,
					"pspRefNo": generateRandomString(27)
				},
				"vAReqType": constantConfig.upiConstant.vAReqType_T
			});
			bhimUpiService.getNativeData(constantConfig.upiConstant.checkVirtualAddressAPI, json).then(function (data) {
				var checkVpaResponse = JSON.parse(data);
				if (checkVpaResponse.status == 'VE') {
					customerInfoService.payeeDetails = {
						payeeType: "VA",
						requestType: 'pay',
						accountNo: "",
						ifsc: "",
						name: checkVpaResponse.payeeType.name || "",
						vpa: checkVpaResponse.payeeType.virtualAddress || "",
						amount: "",
						remark: "",
						nickName: upiBeneficiary.nickName || "",
						phoneNumber: "",
						savePayee: false,
						isBeneExist: true
					}
					upiPaymentsVm.getProfile();
				} else {
					utilityService.hideSpinner();
					utilityService.showBhimUpiAlert("error", checkVpaResponse.statusDesc);
				}
			}, function (msg) {
				utilityService.hideSpinner();
				utilityService.showBhimUpiAlert("error", msg);
			});
		}

		upiPaymentsVm.payToContactBeneficiary = function (contact) {
			if (contact.phoneNumbers && contact.phoneNumbers.length > 0) {
				if (contact.phoneNumbers[0].value) {
					var x = contact.phoneNumbers[0].value.replace(/\s/g, '');
					if (x.length >= 10) {
						upiPaymentsVm.vpa = x.substr(x.length - 10) + "@sbi";
					} else {
						return false;
						utilityService.showBhimUpiAlert("alert", 'Please select valid mobile number');
					}
				} else {
					return false;
					utilityService.showBhimUpiAlert("alert", 'There is some issue to fetch mobile number');
				}
			}
			customerInfoService.payeeDetails = {
				payeeType: "VA",
				requestType: 'pay',
				accountNo: "",
				ifsc: "",
				name: contact.displayName || "",
				vpa: upiPaymentsVm.vpa || "",
				amount: "",
				remark: "",
				nickName: contact.nickname || "",
				phoneNumber: contact.phoneNumbers && contact.phoneNumbers.length > 0 ? contact.phoneNumbers[0].value : "",
				savePayee: false
			}
			$state.go('menu.payToVpa');
		}

		upiPaymentsVm.payToAccountBeneficiary = function (beneficiary) {
			utilityService.showSpinner();
			var json = JSON.stringify({
				"recoveryOptionFlag": constantConfig.upiConstant.recoveryOptionFlag,
				"requestInfo": {
					"pspId": constantConfig.upiConstant.pspId,
					"pspRefNo": generateRandomString(27)
				},
				"updateFlag": constantConfig.upiConstant.updateFlag
			});
			bhimUpiService.getNativeData(constantConfig.upiConstant.getProfile, json).then(function (data) {
				utilityService.hideSpinner();
				var getProfileResponse = JSON.parse(data);
				if (getProfileResponse.status == "S") {
					customerInfoService.payerProfileDtls = getProfileResponse;
					customerInfoService.payeeDetails = {
						payeeType: "AC",
						requestType: 'pay',
						accountNo: beneficiary.accountNo,
						ifsc: beneficiary.ifsc,
						name: beneficiary.name,
						vpa: beneficiary.vpa || "",
						amount: "",
						remark: "",
						nickName: beneficiary.nickName || "",
						phoneNumber: beneficiary.mobileNumber || "",
						savePayee: false,
						isBeneExist: true
					}
					$state.go('menu.payToVpa_PayeeDetails');
				} else {
					utilityService.showBhimUpiAlert("error", getProfileResponse.statusDesc);
				}
			}, function (msg) {
				utilityService.hideSpinner();
				utilityService.showBhimUpiAlert("error", msg);
			});
		}

		upiPaymentsVm.tabClicked = function (id) {
			if (id == '1') {
				upiPaymentsVm.tabIndex = "one";
				bhimUpiService.tabIndex = upiPaymentsVm.tabIndex;
				upiPaymentsVm.buttonLabel = "Pay New UPI ID";
				upiPaymentsVm.fetchUpiBeneficiaries();
			} else if (id == '2') {
				upiPaymentsVm.tabIndex = bhimUpiService.tabIndex;
				if (device.platform.toLowerCase() == 'android') {
					bhimUpiService.getNativeData("getcontactpermission", {}).then(function (data) {
						if (data.contactpermission === 'Allowed') {
							bhimUpiService.getNativeData("openContacts", {}).then(function (data) {
								var contact = data;

								if (contact && contact.number) {
									var x = contact.number.replace(/\s/g, '');
									if (x.length >= 10) {
										upiPaymentsVm.vpa = x.substr(x.length - 10) + "@sbi";
									} else {
										return false;
										utilityService.showBhimUpiAlert("alert", 'Please select valid mobile number');
									}
								} else {
									return false;
									utilityService.showBhimUpiAlert("alert", 'Please select valid mobile number');
								}

								customerInfoService.payeeDetails = {
									payeeType: "VA",
									requestType: 'pay',
									accountNo: "",
									ifsc: "",
									name: "",
									vpa: upiPaymentsVm.vpa || "",
									amount: "",
									remark: "",
									nickName: "",
									phoneNumber: "",
									savePayee: false
								}
								$state.go('menu.payToVpa');
							}, function (msg) {
								utilityService.hideSpinner();
								utilityService.showBhimUpiAlert("error", msg);
							});
						} else {
							utilityService.hideSpinner();
							ionicToast.show("Contact permission denied. Please allow to proceed", 'bottom', false, 3000);
						}
					}, function (msg) {
						utilityService.hideSpinner();
						utilityService.showBhimUpiAlert("error", msg);
					});
				} else {
					bhimUpiService.getNativeData("openContacts", {}).then(function (data) {
						var contact = data;

						if (contact) {
							var x = contact.replace(/\s/g, '');
							if (x.length >= 10) {
								upiPaymentsVm.vpa = x.substr(x.length - 10) + "@sbi";
							} else {
								return false;
								utilityService.showBhimUpiAlert("alert", 'Please select valid mobile number');
							}
						} else {
							return false;
							utilityService.showBhimUpiAlert("alert", 'Please select valid mobile number');
						}

						customerInfoService.payeeDetails = {
							payeeType: "VA",
							requestType: 'pay',
							accountNo: "",
							ifsc: "",
							name: "",
							vpa: upiPaymentsVm.vpa || "",
							amount: "",
							remark: "",
							nickName: "",
							phoneNumber: "",
							savePayee: false
						}
						$state.go('menu.payToVpa');
					}, function (msg) {
						utilityService.hideSpinner();
						utilityService.showBhimUpiAlert("error", msg);
					});
				}
			} else if (id == '3') {
				upiPaymentsVm.tabIndex = "three";
				bhimUpiService.tabIndex = upiPaymentsVm.tabIndex;
				upiPaymentsVm.buttonLabel = "Pay New Bank Account";
				upiPaymentsVm.fetchUpiAccBeneficiaries();
			}
			fTBeneficiaryService.tabIndexVal = upiPaymentsVm.tabIndex;
		}

		upiPaymentsVm.goBack = function () {
			$state.go('menu.fundtrans');
		}

		upiPaymentsVm.searchBeneficiary = function () {
			upiPaymentsVm.isSearchText = true;
		}

		upiPaymentsVm.closeSearchBox = function () {
			upiPaymentsVm.isSearchText = false;
			upiPaymentsVm.searchText = '';
		}

		upiPaymentsVm.clearSearchBox = function () {
			upiPaymentsVm.searchText = '';
		}

		$scope.$on('$ionicView.beforeEnter', function () {
			upiPaymentsVm.upiBeneficiaries = customerInfoService.upiBeneficiaries;
			upiPaymentsVm.beneficiaries = customerInfoService.upiAccBeneficiaries;

			upiPaymentsVm.isSearchText = false;
			upiPaymentsVm.searchText = '';
			upiPaymentsVm.tabIndex = fTBeneficiaryService.tabIndexVal;
			bhimUpiService.tabIndex = upiPaymentsVm.tabIndex;
			if (upiPaymentsVm.tabIndex == "one") {
				upiPaymentsVm.buttonLabel = "Pay New UPI Id";
			} else if (upiPaymentsVm.tabIndex == "two") {
				upiPaymentsVm.buttonLabel = "Pay New Contact";
			} else if (upiPaymentsVm.tabIndex == "three") {
				upiPaymentsVm.buttonLabel = "Pay New Bank Account";
			} else {
				upiPaymentsVm.tabIndex = "one"
				upiPaymentsVm.buttonLabel = "Pay New UPI Id";
				fTBeneficiaryService.tabIndexVal = "one";
				customerInfoService.payerDetails = {};
				customerInfoService.payeeDetails = {};
				utilityService.showSpinner();
				var json = JSON.stringify({
					"appVersionCode": 0,
					"recoveryOptionFlag": constantConfig.upiConstant.recoveryOptionFlag,
					"requestInfo": {
						"pspId": constantConfig.upiConstant.pspId,
						"pspRefNo": generateRandomString(27)
					},
					"requestType": "VA",
					"updateFlag": constantConfig.upiConstant.updateFlag
				});
				bhimUpiService.getNativeData(constantConfig.upiConstant.getBeneficiaryList, json).then(function (data) {
					utilityService.hideSpinner();
					var getBeneficiaryListResponse = JSON.parse(data);
					if (getBeneficiaryListResponse.status == 'S') {
						if (getBeneficiaryListResponse.beneficiaryList && getBeneficiaryListResponse.beneficiaryList.length > 0) {
							customerInfoService.upiBeneficiaries = getBeneficiaryListResponse.beneficiaryList;
							upiPaymentsVm.upiBeneficiaries = customerInfoService.upiBeneficiaries;
						} else {
							customerInfoService.upiBeneficiaries = [];
							upiPaymentsVm.upiBeneficiaries = customerInfoService.upiBeneficiaries;
						}
					} else {
						utilityService.showBhimUpiAlert("error", getBeneficiaryListResponse.statusDesc);
					}
				}, function (msg) {
					utilityService.hideSpinner();
					utilityService.showBhimUpiAlert("error", msg);
				});
			}


			//upiPaymentsVm.contactList = customerInfoService.contactList || [];
			//if (upiPaymentsVm.contactList.length == 0) {
				//upiPaymentsVm.checkSMSPermission();
			//}
			utilityService.hideSpinner();

		});

		upiPaymentsVm.verifyPayeePopUp = function () {
			upiPaymentsVm.payeeUpiId = '';
			upiPaymentsVm.isVpaVerified = false;
			customerInfoService.payeeDetails = {};
			upiPaymentsVm.statusDesc = '';
			upiPaymentsVm.showSpinner = false;

			upiPaymentsVm.myPopup = $ionicPopup.show({
				title: '',
				cssClass: 'ftpopup-body popupWidth90 popupMargin popupBackgroundWhite removePopup-head textAlignCenter',
				templateUrl: 'pages/fundTransfer/bhimUpi/Pay/verifyPayee.html',
				scope: $scope
			})
		}

		upiPaymentsVm.cancel = function () {
			upiPaymentsVm.myPopup.close();
		}

		upiPaymentsVm.verifyUpiId = function (payeeUpiId) {
			if (!payeeUpiId) {
				upiPaymentsVm.statusDesc = 'Please Enter Mobile Number';
				return false;
			}
			upiPaymentsVm.showSpinner = true;
			var json = JSON.stringify({
				"addInfo": {
					"addInfo10": constantConfig.upiConstant.addInfo10,
					"addInfo9": constantConfig.upiConstant.addInfo9
				},
				"payeeType": {
					"virtualAddress": payeeUpiId.toString() + "@sbi"
				},
				"requestInfo": {
					"pspId": constantConfig.upiConstant.pspId,
					"pspRefNo": generateRandomString(27)
				},
				"vAReqType": constantConfig.upiConstant.vAReqType_T
			});
			bhimUpiService.getNativeData(constantConfig.upiConstant.checkVirtualAddressAPI, json).then(function (data) {
				var checkVpaResponse = JSON.parse(data);
				upiPaymentsVm.showSpinner = false;
				if (checkVpaResponse.status == 'VE') {
					customerInfoService.payeeDetails = {
						payeeType: "VA",
						requestType: 'pay',
						accountNo: "",
						ifsc: "",
						name: checkVpaResponse.payeeType.name || "",
						vpa: checkVpaResponse.payeeType.virtualAddress || "",
						amount: "",
						remark: "",
						nickName: "",
						phoneNumber: "",
						savePayee: false
					}
					upiPaymentsVm.payeeName = checkVpaResponse.payeeType.name;
					upiPaymentsVm.payeeVpa = checkVpaResponse.payeeType.virtualAddress;
					upiPaymentsVm.isVpaVerified = true;
				} else {
					upiPaymentsVm.showSpinner = false;
					upiPaymentsVm.statusDesc = checkVpaResponse.statusDesc;
				}
			}, function (msg) {
				upiPaymentsVm.showSpinner = false;
				utilityService.showBhimUpiAlert("error", msg);
			});
		}

		upiPaymentsVm.getProfile = function () {
			if (upiPaymentsVm.myPopup)
				upiPaymentsVm.myPopup.close();
			utilityService.showSpinner();
			var json = JSON.stringify({
				"recoveryOptionFlag": constantConfig.upiConstant.recoveryOptionFlag,
				"requestInfo": {
					"pspId": constantConfig.upiConstant.pspId,
					"pspRefNo": generateRandomString(27)
				},
				"updateFlag": constantConfig.upiConstant.updateFlag
			});
			bhimUpiService.getNativeData(constantConfig.upiConstant.getProfile, json).then(function (data) {
				utilityService.hideSpinner();
				var getProfileResponse = JSON.parse(data);
				if (getProfileResponse.status == "S") {
					customerInfoService.payerProfileDtls = getProfileResponse;
					$state.go('menu.payToVpa_PayeeDetails');
				} else {
					utilityService.showBhimUpiAlert("error", getProfileResponse.statusDesc);
				}
			}, function (msg) {
				utilityService.hideSpinner();
				utilityService.showBhimUpiAlert("error", msg);
			});
		};


		return this;
	}

]);
