'use strict';

angularApp.controller('selectBankController', ["$state",
	"$ionicPopup",
	"$scope",
	"$rootScope",
	"customerInfoService",
	"utilityService",
	"constantConfig",
	"$timeout",
	"loggedInUserService",
	"validationService",
	"bhimUpiService",

	function ($state,
		$ionicPopup,
		$scope,
		$rootScope,
		customerInfoService,
		utilityService,
		constantConfig,
		$timeout,
		loggedInUserService,
		validationService,
		bhimUpiService) {

		var selectBankVm = this;
		selectBankVm.accountDtlAgainstBank = [];
        selectBankVm.sbi="@sbi";
		selectBankVm.upiRegistration = function(){
			if(!selectBankVm.enteredVpa){
				utilityService.showBhimUpiAlert("alert", "Please enter UPI ID for registration.");
				return false;
			}
			if(!selectBankVm.secretQuestion){
				utilityService.showBhimUpiAlert("alert", "Please select the secret question, which will be used for de-register profile/fetch profile.");
				return false;
			}
			if(!selectBankVm.secretAnswer){
				utilityService.showBhimUpiAlert("alert", "Please select the secret answer, which will be used for de-register profile/fetch profile.");
				return false;
			}
			if(!selectBankVm.selectedBankAccount){
				utilityService.showBhimUpiAlert("alert", "Please select the primary account, which will be used for future transactions.");
				return false;
			}

			if(selectBankVm.enteredVpa.indexOf("@") == -1){
				if(!validationService.isValidVPA(selectBankVm.enteredVpa.split("@")[0].toLowerCase() + "@sbi")){
					utilityService.showBhimUpiAlert("alert", "Kindly check the UPI ID.");
					return false;
				}
			}else{
				if(!validationService.isValidVPA(selectBankVm.enteredVpa)){
					utilityService.showBhimUpiAlert("alert", "Kindly check the UPI ID.");
					return false;
				}
			}
				
			utilityService.showSpinner();
			var json = JSON.stringify({
                "requestInfo": {
                    "pspId": constantConfig.upiConstant.pspId,
                    "pspRefNo": generateRandomString(27),
                    "pspRespRefNo": selectBankVm.pspRespRefNo
                },
                "updateFlag": constantConfig.upiConstant.updateFlag,
                "userInfo": {
                    "altMobNo": $rootScope.checkDeviceInfo.deviceInfo.mobileNo || "",
                    "appPin": {
                        "credentialDataValue": constantConfig.upiConstant.credentialDataValue
                    },
                    "defVPAStatus": constantConfig.upiConstant.defVPAStatus,
                    "email": "", //Here need to add email from logged in user
                    "isMerchant": constantConfig.upiConstant.isMerchant,
                    "mobileNo": $rootScope.checkDeviceInfo.deviceInfo.mobileNo || "",
                    "name": localStorage.getItem("customername") ? localStorage.getItem("customername").substring(0, 50) : "", //Here need to add name from logged in user
                    "secretDetails": {
                        "secretAnswer": selectBankVm.secretAnswer,
                        "quesId": selectBankVm.secretQuestion
                    },
                    "showMerchant": constantConfig.upiConstant.showMerchant,
                    "accountId": selectBankVm.selectedBankAccount,
                    "virtualAddress": selectBankVm.enteredVpa.split("@")[0].toLowerCase() + "@sbi"
                }
            });
            bhimUpiService.getNativeData(constantConfig.upiConstant.onRegisterSubmit, json).then(function(data) {
				utilityService.hideSpinner();
                if (JSON.parse(data).status === 'S') {
					localStorage.setItem('appGenId', JSON.parse(data).servGenId);
					customerInfoService.registeredUpiId = selectBankVm.enteredVpa.split("@")[0].toLowerCase() + "@sbi";
					$state.go('menu.upiRegistrationSuccess');
                } else {
					utilityService.showBhimUpiAlert("error", JSON.parse(data).statusDesc);
                }
            }, function(msg) {
				utilityService.hideSpinner();
                utilityService.showBhimUpiAlert("error", msg);
            });
		}
		
		selectBankVm.selectSuggestedVpa = function (sugesstedVpa) {
			selectBankVm.enteredVpa = sugesstedVpa.split("@")[0];
			selectBankVm.isEnteredIdAvailable = "donotshowError";
		}

		selectBankVm.checkVpaAvailability = function () {
			if(selectBankVm.enteredVpa.indexOf("@") == -1){
				if(!validationService.isValidVPA(selectBankVm.enteredVpa.split("@")[0].toLowerCase() + "@sbi")){
					utilityService.showBhimUpiAlert("alert", "Kindly check the UPI ID.");
					return false;
				}
			}else{
				if(!validationService.isValidVPA(selectBankVm.enteredVpa)){
					utilityService.showBhimUpiAlert("alert", "Kindly check the UPI ID.");
					return false;
				}
			}
			
			if (selectBankVm.enteredVpa) {
				utilityService.showSpinner();
				var json = JSON.stringify({
					"addInfo": {
						"addInfo10": constantConfig.upiConstant.addInfo10,
						"addInfo9": constantConfig.upiConstant.addInfo9
					},
					"payeeType": {
						"virtualAddress": selectBankVm.enteredVpa.split("@")[0].toLowerCase() + "@sbi"
					},
					"requestInfo": {
						"pspId": constantConfig.upiConstant.pspId,
						"pspRefNo": generateRandomString(27)
					},
					"vAReqType": "R"
				});
				bhimUpiService.getNativeData(constantConfig.upiConstant.checkVirtualAddressAPI, json).then(function (data) {
					utilityService.hideSpinner();
					if (JSON.parse(data).status === 'VN') {
						selectBankVm.isEnteredIdAvailable = true;
					} else if (JSON.parse(data).status === 'VE') {
						selectBankVm.isEnteredIdAvailable = false;
					} else {
						utilityService.showBhimUpiAlert("alert", "Kindly check the UPI ID.");
					}
				}, function (msg) {
					utilityService.hideSpinner();
					utilityService.showBhimUpiAlert("error", msg);
				});
			}
		};

		selectBankVm.selectBank = function (bank) {
			selectBankVm.selectedBank = bank;
			selectBankVm.gotoSelectVpa();
		}

		selectBankVm.getBankAccountList = function(){
			selectBankVm.enteredVpa = '';
			selectBankVm.secretQuestion = '';
			selectBankVm.secretAnswer = '';
			selectBankVm.selectedBankAccount = '';
			selectBankVm.isEnteredIdAvailable = "donotshowError";

			selectBankVm.accountList = [];
			utilityService.showSpinner();
			var json = JSON.stringify({
				"addInfo": {
					"addInfo10": constantConfig.upiConstant.addInfo10,
					"addInfo9": constantConfig.upiConstant.addInfo9
				},
				"bankCode": customerInfoService.selectedBankArray[0].bankCode,
				"recoveryOptionFlag": constantConfig.upiConstant.recoveryOptionFlag,
				"requestInfo": {
					"pspId": constantConfig.upiConstant.pspId,
					"pspRefNo": generateRandomString(27)
				},
				"requestType": constantConfig.upiConstant.requestType_R,
				"updateFlag": constantConfig.upiConstant.updateFlag,
				"userInfo": {
					"defVPAStatus": constantConfig.upiConstant.defVPAStatus,
					"isMerchant": constantConfig.upiConstant.isMerchant,
					"name": localStorage.getItem("customername") ? localStorage.getItem("customername").substring(0, 50) : "", //Here need to add logged in user name
					"showMerchant": constantConfig.upiConstant.showMerchant,
					"accountId": 0,
					"virtualAddress": $rootScope.checkDeviceInfo && $rootScope.checkDeviceInfo.deviceInfo && $rootScope.checkDeviceInfo.deviceInfo.mobileNo ? $rootScope.checkDeviceInfo.deviceInfo.mobileNo + "@sbi" : $rootScope.checkDeviceInfo.deviceInfo.oldMobileNo + "@sbi" //By default send mob no.--- $rootScope.checkDeviceInfo.deviceInfo.mobileNo
				}
			});
			bhimUpiService.getNativeData(constantConfig.upiConstant.getaccountListAPI, json).then(function (data) {
				var accObj = JSON.parse(data);
				utilityService.hideSpinner();
				if (accObj.status == 'S') {
					selectBankVm.accountList = accObj.accountList;
					selectBankVm.vpaSuggestionList = accObj.vpaSuggestionList;
					selectBankVm.pspRespRefNo = accObj.requestInfo.pspRespRefNo;
					selectBankVm.selectBankFlag = false;
				}else{
					if (accObj.errCode && accObj.errCode.toLowerCase() == "upsn") {
						utilityService.showBhimUpiAlert("alert", customerInfoService.selectedBankArray[0].bankName + " : " + accObj.statusDesc, "menu.fundsTransferLanding");
					} else {
						utilityService.showBhimUpiAlert("error", customerInfoService.selectedBankArray[0].bankName + " : " + accObj.statusDesc);
					}
				}
			}, function (msg) {
				utilityService.hideSpinner();
				utilityService.showBhimUpiAlert("error", msg);
			});
		}

		selectBankVm.gotoSelectVpa = function () {
			customerInfoService.selectedBankArray = [];
			if(selectBankVm.selectedBank)
				customerInfoService.selectedBankArray.push(selectBankVm.selectedBank);
			if (customerInfoService.selectedBankArray.length >= 1) {
				selectBankVm.getBankAccountList(customerInfoService.selectedBankArray);
			} else {
				utilityService.showBhimUpiAlert("alert", "Please select a bank to proceed further.");
			}
		}

		selectBankVm.getSecretQuestionList = function () {
			utilityService.showSpinner();
			var json = JSON.stringify({
				"addInfo": {
					"addInfo10": constantConfig.upiConstant.addInfo10,
					"addInfo9": constantConfig.upiConstant.addInfo9
				},
				"recoveryOptionFlag": constantConfig.upiConstant.recoveryOptionFlag,
				"requestInfo": {
					"pspId": constantConfig.upiConstant.pspId,
					"pspRefNo": generateRandomString(27)
				},
				"updateFlag": constantConfig.upiConstant.updateFlag
			});
			bhimUpiService.getNativeData(constantConfig.upiConstant.getSecurityQuestionsList, json).then(function (data) {
				var secQueObj = JSON.parse(data);
				if(secQueObj.status == 'S')
					selectBankVm.secQuestions = secQueObj.secQuesList;
				utilityService.hideSpinner();
			}, function (msg) {
				utilityService.hideSpinner();
				utilityService.showBhimUpiAlert("error", msg);
			});
		};

		selectBankVm.back = function () {
			selectBankVm.selectBankFlag = true;
			selectBankVm.selectedBankCnt = 0;
			customerInfoService.selectedBankArray = [];
			selectBankVm.accountList = [];
		};

		selectBankVm.backToCreateVpa = function(){
			customerInfoService.selectedBankArray = [];
			$state.go('menu.createNewVpa');
		}

		selectBankVm.close = function () {
			$state.go('menu.fundsTransferLanding');
		};

		selectBankVm.clearSearchText = function(){
			selectBankVm.searchText = '';
		}

		selectBankVm.toggleSecretAns = function(){
			selectBankVm.isTextReadable == true ? selectBankVm.isTextReadable = false : selectBankVm.isTextReadable = true;
		};

		$scope.$on('$ionicView.beforeEnter', function () {
			selectBankVm.loggedInUserDetails = loggedInUserService.getUserProfileDetails();
			selectBankVm.selectBankFlag = true;
			selectBankVm.selectedBank = '';
			selectBankVm.getSecretQuestionList();
			selectBankVm.isTextReadable = false;
			selectBankVm.searchText = '';
			selectBankVm.bankList = customerInfoService.bankList;
			selectBankVm.selectedBankCnt = 0;
			customerInfoService.selectedBankArray = [];
			selectBankVm.accountList = [];
			selectBankVm.enteredVpa = "";
			selectBankVm.isEnteredIdAvailable = "donotshowError";
		});

		return this;
	}

]);
