'use strict';

angularApp.controller('fTQRCodeController', [
	"$state",
	"$scope",
	"$ionicHistory",
	"$ionicPopup",
	"$cordovaBarcodeScanner",
	"cameraService",
	"utilityService",
	"fTBeneficiaryService",
	"$rootScope",
	"cryptoService",
	"constantConfig",

	function ($state,
		$scope,
		$ionicHistory,
		$ionicPopup,
		$cordovaBarcodeScanner,
		cameraService,
		utilityService,
		fTBeneficiaryService,
		$rootScope,
		cryptoService,
		constantConfig) {

		var fTQRCodeVm = this;
		fTQRCodeVm.scannedImage = "img/FT/PayQRCode.svg";
		fTBeneficiaryService.customer.remarks = "";
		fTBeneficiaryService.customer.transAmount = "";
		
		//Closing the popup after Scanned QR Code
		fTQRCodeVm.goConfirm = function () {
			fTQRCodeVm.confirm.close();
			fTQRCodeVm.isBarcodeScanned = true;
		}
		
		//Cancellation of QR Code Scanning
		fTQRCodeVm.goCancel = function () {
			fTQRCodeVm.confirm.close();
			$state.go('menu.fTQRCode');
		}
		
		//Page Navigates back to Funds Transfer Home
		fTQRCodeVm.goToBack = function () {
			//$state.go('menu.upiPay');
			$ionicHistory.goBack();
		}
		
		fTQRCodeVm.goToNext = function(){
			utilityService.showSpinner();
			var jsonForPermission = JSON.stringify({});
			getNativeData(constantConfig.upiConstant.getpermission, function(data){
				utilityService.hideSpinner();
				if(data.permission === 'Allowed'){
					utilityService.showSpinner();
					var json = JSON.stringify({
						"addInfo":{
							"addInfo10":constantConfig.upiConstant.addInfo10,
							"addInfo9":constantConfig.upiConstant.addInfo9
						},
						"recoveryOptionFlag":constantConfig.upiConstant.recoveryOptionFlag,
						"requestInfo":{
							"pspId":constantConfig.upiConstant.pspId,
							"pspRefNo":generateRandomString(27)
						},
						"updateFlag":constantConfig.upiConstant.updateFlag
					});
					getNativeData(constantConfig.upiConstant.checkDevice, function(data){
						$rootScope.checkDeviceInfo = JSON.parse(data);
						if(JSON.parse(data).status !== 'F'){
							fTQRCodeVm.goToNext2();
						} else {
							utilityService.hideSpinner();
							utilityService.showErrorMessage($rootScope.checkDeviceInfo.statusDesc);
						}
					}, function(msg){
						utilityService.hideSpinner();
						fTQRCodeVm.showVpaErrorMessage(msg);
					},json);
				} else {
					utilityService.hideSpinner();
					utilityService.showErrorMessage("UPI registration requires permission to use camera, SMS and Phone calls. Please allow these permissions. If problem persists re-initiate UPI registration.");
				}
			}, function(msg){
				utilityService.hideSpinner();
				fTQRCodeVm.showVpaErrorMessage(msg);
			},jsonForPermission);
		} 
		
		//Page Navigates to VPA Payment page
		fTQRCodeVm.goToNext2 = function () {
			var pattern = /^[\w.-]*@[a-zA-Z]*$/;
			if (fTQRCodeVm.isBarcodeScanned) {
				if(pattern.test(fTBeneficiaryService.customer.vpa)){
					fTBeneficiaryService.qrflag = true;
					var json = JSON.stringify({
						"addInfo":{
							"addInfo10":constantConfig.upiConstant.addInfo10,
							"addInfo9":constantConfig.upiConstant.addInfo9
							},
							"payeeType":{
								"virtualAddress": fTBeneficiaryService.customer.vpa.toLowerCase()
								},
							"requestInfo":{
								"pspId":constantConfig.upiConstant.pspId,
								"pspRefNo":generateRandomString(27)
								},
							"vAReqType":constantConfig.upiConstant.vAReqType_T
						});
					getNativeData(constantConfig.upiConstant.checkVirtualAddressAPI, function(data){
						utilityService.hideSpinner();
						if(JSON.parse(data).status === 'VE'){
							fTBeneficiaryService.customer.nameData = JSON.parse(data).payeeType.name;
							$state.go('menu.fTPaymentDetails_VPA');
						} else{
							utilityService.showErrorMessage("This Virtual Payment Address is not available.");
						}
					}, function(msg){
						utilityService.hideSpinner();
						fTQRCodeVm.showVpaErrorMessage(msg);
					},json);
				} else{
					utilityService.hideSpinner();
					utilityService.showErrorMessage("QR image is not valid.");
				}
			} else {
				utilityService.hideSpinner();
				utilityService.showErrorMessage("Kindly scan the QR image.");
			} 
		};
		
		fTQRCodeVm.showVpaErrorMessage = function(errorCode){
			switch(errorCode){
				case -1 : utilityService.showErrorMessage(constantConfig.upiConstant.minusOne);
				break;
				
				case -2 : utilityService.showErrorMessage(constantConfig.upiConstant.minusTwo);
				break;
				
				case -3 : utilityService.showErrorMessage(constantConfig.upiConstant.minusThree);
				break;
				
				case -4 : utilityService.showErrorMessage(constantConfig.upiConstant.minusFour);
				break;
				
				case -5 : utilityService.showErrorMessage(constantConfig.upiConstant.minusFive);
				break;
				
				case -6 : utilityService.showErrorMessage(constantConfig.upiConstant.minusSix);
				break;
				
				case -7 : utilityService.showErrorMessage(constantConfig.upiConstant.minusSeven);
				break;
				
				default : utilityService.showErrorMessage(constantConfig.upiConstant.someWentWrong);
			}
		};
		
		//Get query parameter from URL
		fTQRCodeVm.getParameterByName = function(name, url) {
			if (!url) url = window.location.href;
			name = name.replace(/[\[\]]/g, "\\$&");
			var regex = new RegExp("[?&]" + name + "(=([^&#]*)|&|#|$)"),
				results = regex.exec(url);
			if (!results) return null;
			if (!results[2]) return '';
			return decodeURIComponent(results[2].replace(/\+/g, " "));
		}
		
		//Scan the QR Code
		fTQRCodeVm.goToQRCodeDetails = function () {
			$cordovaBarcodeScanner.scan().then(function (barcodeData) {
				try{
					fTQRCodeVm.isBarcodeScanned = !utilityService.isEmpty(barcodeData.text);
					if(fTQRCodeVm.isBarcodeScanned){
						fTBeneficiaryService.customer.vpa = fTQRCodeVm.getParameterByName('pa', barcodeData.text);
						var customerName = fTQRCodeVm.getParameterByName('pn', barcodeData.text);
						fTBeneficiaryService.customer.nameData = customerName ? customerName : "";
						fTQRCodeVm.scannedImage = "img/FT/PayQRCode.svg"; //Add here scanned image.
						fTQRCodeVm.goToNext();
					}else{
						fTQRCodeVm.scannedImage = "img/FT/PayQRCode.svg";
					}
				}catch(e){}
			}, function (error) {
				utilityService.showErrorMessage(error.responseMessage);
			});
		};
		
		//Select the QR Code from gallery
		fTQRCodeVm.selectImagefromGallery = function () {
			cameraService.getImageFromGallery().then(function (imageData) {
				try {
					fTQRCodeVm.scannedImage = imageData;
					qrcode.decode(imageData);
					qrcode.callback = function (decodedData) {
						fTQRCodeVm.isBarcodeScanned = !utilityService.isEmpty(decodedData);
						if(fTQRCodeVm.isBarcodeScanned){
							fTBeneficiaryService.customer.vpa = fTQRCodeVm.getParameterByName('pa', decodedData);
							var customerName = fTQRCodeVm.getParameterByName('pn', decodedData);
							fTBeneficiaryService.customer.nameData = customerName ? customerName : "";
						}
					}
				}
				catch(e){}
			}, function (error) {
				utilityService.showErrorMessage(error.responseMessage);
			});
		};
		
		//Confirmation of Scanned QR Code 
		fTQRCodeVm.Confirm = function () {
			fTQRCodeVm.confirm = $ionicPopup.show({
				title: '',
				cssClass: 'popupWidth90 popupMargin popupBackgroundWhite removePopup-head textAlignCenter ftpopup-body',
				templateUrl: 'pages/fundTransfer/fTQRCode/fTQRConifrmPopup.html',
				scope: $scope
			});
		};
		
		//Close and Navigate to Funds Transfer Home
		$scope.goToHome = function () {
			$state.go('menu.fundsTransferLanding');
		}

		$scope.$on('$ionicView.beforeEnter', function () {
			fTQRCodeVm.isBarcodeScanned = false;
		});
		
		return this;
	}]);