(function() {
    'use strict';

    angularApp.controller('hospitalDailyCashPremiumCalculationController', hospitalDailyCashPremiumCalculationController);

    hospitalDailyCashPremiumCalculationController.$inject = [
        "$timeout",
        "$state",
        "$scope",
        "generalInsurenceHomeService", "$ionicPopup", "$filter",
        "generalInsurenceHealthService",
        "validateService", "utilityService","GIconstant","clickStreamService",
    ];

    function hospitalDailyCashPremiumCalculationController(
        $timeout,
        $state,
        $scope,
        generalInsurenceHomeService, $ionicPopup, $filter,
        generalInsurenceHealthService,
        validateService, utilityService,GIconstant,clickStreamService) {

        //variables
        var hospitalDailyCashPremiumCalculationVm = this;
        hospitalDailyCashPremiumCalculationVm.disable = false;
        hospitalDailyCashPremiumCalculationVm.showBack = true;
        hospitalDailyCashPremiumCalculationVm.showNext = true;
        hospitalDailyCashPremiumCalculationVm.noOfInsured = 1;
        hospitalDailyCashPremiumCalculationVm.insuredInfo = [];
        var currentDate = generalInsurenceHomeService.getCurrentDate();
        hospitalDailyCashPremiumCalculationVm.minDOB = generalInsurenceHomeService.getFutureYear(currentDate, -110);
        hospitalDailyCashPremiumCalculationVm.maxDOB = generalInsurenceHomeService.getFutureYear(currentDate, -18);
        hospitalDailyCashPremiumCalculationVm.policyMinStartDate = currentDate;
        hospitalDailyCashPremiumCalculationVm.policyMaxStartDate = generalInsurenceHomeService.getFutureDate(currentDate, 7);
        hospitalDailyCashPremiumCalculationVm.validateService = validateService;
        hospitalDailyCashPremiumCalculationVm.goBacktoPrevious = goBacktoPrevious;
        hospitalDailyCashPremiumCalculationVm.goToNextPage = goToNextPage;
        hospitalDailyCashPremiumCalculationVm.decrementInsurers = decrementInsurers;
        hospitalDailyCashPremiumCalculationVm.incrementInsurers = incrementInsurers;
        hospitalDailyCashPremiumCalculationVm.calculatePolicyEndDate = calculatePolicyEndDate;
        hospitalDailyCashPremiumCalculationVm.detail = [];

        //initialize the page
        function initPage() {
            hospitalDailyCashPremiumCalculationVm.insuredInfo = [];
            hospitalDailyCashPremiumCalculationVm.policyStartDate = $filter('chosenDate')(generalInsurenceHomeService.getCurrentDate());
            hospitalDailyCashPremiumCalculationVm.policyEndDate = generalInsurenceHomeService.getFutureYear(hospitalDailyCashPremiumCalculationVm.policyStartDate, 1);

            /* get HDC masters */
			if(!generalInsurenceHealthService.getHDCMasterList()){
				generalInsurenceHealthService.getHDCMaster().then(function(response) {
					generalInsurenceHealthService.setHDCMasterList(response);
					hospitalDailyCashPremiumCalculationVm.ageGroupChoice = response.ageGroup;
					hospitalDailyCashPremiumCalculationVm.cashLimitChoice = response.hospitalCashLimit;
				}, function(error) {
					utilityService.showErrorMessage(error.responseMessage);
				});
			}else{
				hospitalDailyCashPremiumCalculationVm.ageGroupChoice = generalInsurenceHealthService.getHDCMasterList().ageGroup;
				hospitalDailyCashPremiumCalculationVm.cashLimitChoice = generalInsurenceHealthService.getHDCMasterList().hospitalCashLimit;
			}
            
			

            /* pre-fill when back button is pressed  */
            $timeout(function() {
                var previouspageData = generalInsurenceHealthService.getHospitalDailyCashDetails();
                if (previouspageData) {
                    hospitalDailyCashPremiumCalculationVm.noOfInsured = previouspageData.memberCount;
                    hospitalDailyCashPremiumCalculationVm.insuredInfo = previouspageData.membersList;
                    hospitalDailyCashPremiumCalculationVm.policyStartDate = previouspageData.startDate;
                    hospitalDailyCashPremiumCalculationVm.policyEndDate = previouspageData.endDate;
                } else {
                    updateNoOfInsured();
                }
            }, 10);
            hospitalDailyCashPremiumCalculationVm.productType = generalInsurenceHomeService.getProductDetail().uin;
        }

        /*   */
        hospitalDailyCashPremiumCalculationVm.checkforage = function(data, index) {
            var ageLimit = parseInt(data.key);
            hospitalDailyCashPremiumCalculationVm.detail[index] = {};
            if (ageLimit <= 60) {
                hospitalDailyCashPremiumCalculationVm.detail[index].disable = false;
            } else {
                var alertPopup = $ionicPopup.alert({
                    title: '',
                    templateUrl: 'pages/generalInsurance/health/hospitalDailyCashPopup.html'
                });
                hospitalDailyCashPremiumCalculationVm.insuredInfo[index].cashLimit = hospitalDailyCashPremiumCalculationVm.cashLimitChoice[0];
                 hospitalDailyCashPremiumCalculationVm.detail[index].disable = true;
                hospitalDailyCashPremiumCalculationVm.checkForCashLimit(data, index);
            }
        }

        /* cash limit cannot be more than primary insured cash limit   */
        hospitalDailyCashPremiumCalculationVm.checkForCashLimit = function(data, index) {
            hospitalDailyCashPremiumCalculationVm.validate = {};
            for (var i = 0; i < hospitalDailyCashPremiumCalculationVm.insuredInfo.length; i++) {
                if (hospitalDailyCashPremiumCalculationVm.insuredInfo[i].cashLimit.key > hospitalDailyCashPremiumCalculationVm.insuredInfo[0].cashLimit.key) {
                    hospitalDailyCashPremiumCalculationVm.validate.cashLimit = {}
                    hospitalDailyCashPremiumCalculationVm.validate.cashLimit[i] = {};
                    hospitalDailyCashPremiumCalculationVm.validate.cashLimit[i] = 'cash limit cannot be more than primary insured cash limit';
                    hospitalDailyCashPremiumCalculationVm.insuredInfo[i] = "";
                }
            }
          
    }


        //decrement the number of insurers
        function decrementInsurers() {
            if (hospitalDailyCashPremiumCalculationVm.noOfInsured > 1) {
                hospitalDailyCashPremiumCalculationVm.noOfInsured--;
                updateNoOfInsured();
            }
        }

        //increment the number of insurers
        function incrementInsurers() {
            if (hospitalDailyCashPremiumCalculationVm.noOfInsured < 6) {
                hospitalDailyCashPremiumCalculationVm.noOfInsured++;
                updateNoOfInsured();
            }
        }

        /**
         * [getPremiumAmount description]
         * @return {[type]} [description]
         */
        function getDobFromAgeGroup(ageGruop) {
            var CurrentDate = $filter('chosenDate')(generalInsurenceHomeService.getCurrentDate());
            var apprxDob = generalInsurenceHomeService.getFutureYear(CurrentDate, -ageGruop);
            return apprxDob;
        }


        //update the member fields on number insured change
        function updateNoOfInsured() {
            hospitalDailyCashPremiumCalculationVm.insuredInfo = [];
            var count = hospitalDailyCashPremiumCalculationVm.noOfInsured;
            for (var index = 0; index < count; index++) {
                var member = {};
                member.ageGroup = {};
                member.cashLimit = {};
                hospitalDailyCashPremiumCalculationVm.insuredInfo.push(member);
            }
        }

        //calculate the policy end date to 1 year from the start
        function calculatePolicyEndDate() {
            hospitalDailyCashPremiumCalculationVm.policyEndDate = generalInsurenceHomeService
                .getFutureYear(hospitalDailyCashPremiumCalculationVm.policyStartDate, 1);
        }

        //validate the form on next button click
        function validateForm() {
            hospitalDailyCashPremiumCalculationVm.validate = {};
            hospitalDailyCashPremiumCalculationVm.validate.ageGroup = {};
            hospitalDailyCashPremiumCalculationVm.validate.cashLimit = {};
            hospitalDailyCashPremiumCalculationVm.validate.policyStartDate = {};
            var count = hospitalDailyCashPremiumCalculationVm.noOfInsured;
            for (var index = 0; index < count; index++) {
                if (hospitalDailyCashPremiumCalculationVm.validateService.isValidAgeGroup(hospitalDailyCashPremiumCalculationVm.insuredInfo[index].ageGroup)) {
                    hospitalDailyCashPremiumCalculationVm.validate.ageGroup[index] = hospitalDailyCashPremiumCalculationVm.validateService.isValidAgeGroup(hospitalDailyCashPremiumCalculationVm.insuredInfo[index].ageGroup);
                }
                if (hospitalDailyCashPremiumCalculationVm.validateService.isValidCashLimit(hospitalDailyCashPremiumCalculationVm.insuredInfo[index].cashLimit)) {
                    hospitalDailyCashPremiumCalculationVm.validate.cashLimit[index] = hospitalDailyCashPremiumCalculationVm.validateService.isValidCashLimit(hospitalDailyCashPremiumCalculationVm.insuredInfo[index].cashLimit);
                }
            }
            if (hospitalDailyCashPremiumCalculationVm.validateService.isValidPolicyStartDate(hospitalDailyCashPremiumCalculationVm.policyStartDate)) {
                hospitalDailyCashPremiumCalculationVm.validate.policyStartDate = hospitalDailyCashPremiumCalculationVm.validateService
                    .isValidPolicyStartDate(hospitalDailyCashPremiumCalculationVm.policyStartDate);
            }
            return (((angular.equals({}, hospitalDailyCashPremiumCalculationVm.validate.ageGroup)) ? true : false) && ((angular.equals({}, hospitalDailyCashPremiumCalculationVm.validate.cashLimit)) ? true : false) && ((angular.equals({}, hospitalDailyCashPremiumCalculationVm.validate.policyStartDate)) ? true : false));
        }

        //go back to previous page
        function goBacktoPrevious() {
            $state.go("menu.recommendedPolicyDetails");
        }

        /* save application for Arogya Premium  */
        function saveApplicationHDC() {
            generalInsurenceHomeService.setpolicyStartdate(hospitalDailyCashPremiumCalculationVm.policyStartDate);
            var structure = generalInsurenceHomeService.getSaveApplicationSimpleHealth();
            var firstPageDetail = generalInsurenceHealthService.getSaveQuoteRequestForHDC();
            var hdcPremium = generalInsurenceHealthService.getPremiumDetailsForHDC();
            var count = hospitalDailyCashPremiumCalculationVm.noOfInsured;

            for (var i = 0; i < count; i++) {
                firstPageDetail.quoteData.premiumCalculation.request.insuredDetails[i] = {};
                firstPageDetail.quoteData.premiumCalculation.request.insuredDetails[i].hospitalizationCashLimit = hospitalDailyCashPremiumCalculationVm.insuredInfo[i].cashLimit.value;
                firstPageDetail.quoteData.premiumCalculation.request.insuredDetails[i].age = hospitalDailyCashPremiumCalculationVm.insuredInfo[i].ageGroup;
            }
            firstPageDetail.quoteData.premiumCalculation.request.policyStartDate = new Date(hospitalDailyCashPremiumCalculationVm.policyStartDate);
            firstPageDetail.quoteData.premiumCalculation.request.policyEndDate = new Date(hospitalDailyCashPremiumCalculationVm.policyEndDate);
            firstPageDetail.quoteData.premiumCalculation.request.familysize = hospitalDailyCashPremiumCalculationVm.noOfInsured + "";
            firstPageDetail.quoteData.premiumCalculation.request.primarySumInsured = hospitalDailyCashPremiumCalculationVm.insuredInfo[0].cashLimit.value * 30;
            firstPageDetail.quoteData.premiumCalculation.request.quoteDetails.planDuration = "30";
            firstPageDetail.quoteData.premiumCalculation.response = hdcPremium;

            var planDetail = generalInsurenceHomeService.getPlanDetail();
            structure.applicationNumber = generalInsurenceHealthService.getSaveApplicationHDCResponse() ? generalInsurenceHealthService.getSaveApplicationHDCResponse().applicationNumber : "";
            structure.productCode = planDetail.productCode;
            structure.uin = hospitalDailyCashPremiumCalculationVm.productType;
            structure.planName = planDetail.planName;
            structure.mobileNumber = "";
            structure.quoteData = firstPageDetail.quoteData;
            structure.applicationData = "";
            structure.sumInsured =  generalInsurenceHomeService.getpolicySumInsured() ?  generalInsurenceHomeService.getpolicySumInsured() : "";   
            structure.policyStartDate =   generalInsurenceHomeService.getpolicyStartdate() ?   generalInsurenceHomeService.getpolicyStartdate() : "";

            var stringified = structure;
             if(typeof(stringified.quoteData)=='object'){
               stringified.quoteData = JSON.stringify(stringified.quoteData);
            }
            generalInsurenceHomeService.setSaveApplicationHDCStructure(structure);

            generalInsurenceHomeService.saveApplication(stringified,GIconstant.OmniChannel.HDC.HDC_PREMIUM_1).then(function(data) {
                generalInsurenceHealthService.setSaveApplicationHDCResponse(data);
                $state.go("menu.quotesList");
            }, function(error) {
                utilityService.showErrorMessage(error.responseMessage);
            });
        }

        function getJsonForHDC() {
            var hdcPremiumResponse = generalInsurenceHealthService.getPremiumDetailsForHDC();
            var year = generalInsurenceHealthService.getHDCMasterList().policyTenure[0];
            // var hdcDetails = generalInsurenceHealthService.getHospitalDailyCashDetails();
            var productTypes;
            if (hospitalDailyCashPremiumCalculationVm.noOfInsured == '1') {
                productTypes = 'Individual';
            } else {
                productTypes = 'Family Floater';
            }
            var insureedDetails = [];
            for (var i = 0; i < hospitalDailyCashPremiumCalculationVm.noOfInsured; i++) {
                insureedDetails[i] = {}
                insureedDetails[i].age = hospitalDailyCashPremiumCalculationVm.insuredInfo[i].ageGroup.key;
                insureedDetails[i].dateOfBirth = $filter('dateFormat')(getDobFromAgeGroup(insureedDetails[i].age));
                insureedDetails[i].hospitalizationCashLimit = hospitalDailyCashPremiumCalculationVm.insuredInfo[i].cashLimit.value;

                if(hdcPremiumResponse && hospitalDailyCashPremiumCalculationVm.noOfInsured  == hdcPremiumResponse.premiumCalculation.insuredDetails.length){
                    insureedDetails[i].insuredId = hdcPremiumResponse ? hdcPremiumResponse.premiumCalculation.insuredDetails[i].insuredId : "";
                    insureedDetails[i].insuredName = hdcPremiumResponse ? hdcPremiumResponse.premiumCalculation.insuredDetails[i].insuredName : "";
                    insureedDetails[i].policyCtId = hdcPremiumResponse ? hdcPremiumResponse.premiumCalculation.insuredDetails[i].policyCtId : "";
                }else{
                    insureedDetails[i].insuredId = "";
                    insureedDetails[i].insuredName =  "";
                    insureedDetails[i].policyCtId =  "";
                    hdcPremiumResponse = "";
                }
                
            }
            var HDCPremium = {
                "premiumCalculation": {
                    "productType": productTypes,
                    "quoteNo": hdcPremiumResponse ? hdcPremiumResponse.premiumCalculation.quoteNumber : "",
                    "policyID": hdcPremiumResponse ? hdcPremiumResponse.premiumCalculation.policyTerms.policyID : "",
                    "familySize": hospitalDailyCashPremiumCalculationVm.noOfInsured.toString(),
                    "policyStartDate": $filter('startDateWithTimezone')(hospitalDailyCashPremiumCalculationVm.policyStartDate),
                    "policyEndDate":$filter('endDateWithTimezone')(hospitalDailyCashPremiumCalculationVm.policyEndDate),
                    "ppId": hdcPremiumResponse ? hdcPremiumResponse.premiumCalculation.policyTerms.ppId : "",
                    "noOfDays": year.value.toString(),

                    "insuredDetails": insureedDetails
                }
            }
            generalInsurenceHomeService.applyHDCPremium(HDCPremium).then(function(data) {
                generalInsurenceHealthService.setPremiumDetailsForHDC(data);
                generalInsurenceHealthService.setHDCPrimiumForOffer(data);
                generalInsurenceHomeService.setQuoteListDetails(null);
                hospitalDailyCashPremiumCalculationVm.sumInsured = hospitalDailyCashPremiumCalculationVm.insuredInfo[0].cashLimit.value * 30;
                generalInsurenceHealthService.setHDCSumInsured(hospitalDailyCashPremiumCalculationVm.sumInsured);
                saveApplicationHDC();


            }, function(error) {
                utilityService.showErrorMessage(error.responseMessage);
                //alert(error.responseMessage);
            });
        }



        //go to next page
        function goToNextPage() {
            var pagedetail = "HDC";
            if (validateForm()) {
                clickStreamService.clickStreamData = generalInsurenceHomeService.getProductDetail().policyName;
                var data = {};
                data.memberCount = hospitalDailyCashPremiumCalculationVm.noOfInsured;
                data.membersList = hospitalDailyCashPremiumCalculationVm.insuredInfo;
                data.startDate = hospitalDailyCashPremiumCalculationVm.policyStartDate;
                data.endDate = hospitalDailyCashPremiumCalculationVm.policyEndDate;
                generalInsurenceHealthService.setHospitalDailyCashDetails(data);
                getJsonForHDC();

                // getJsonforHDC();
            }
            //$state.go("menu.criticalIlnessPremiumCalulation");
        }

       

        //actions to done everytime the view is shown
        $scope.$on('$ionicView.beforeEnter', function() {
            //To Do
            initPage();
        });

        
        return this;
    }
})();
