(function() {
    'use strict';

    angularApp.service('lifeInsuranceApplicationService', lifeInsuranceApplicationService);

    lifeInsuranceApplicationService.$inject = [
        'lifeInsuranceConfig',
        '$q',
        'AdapterUtils',
        'utilityService',
        '$filter',
        'validateService'
    ];

    function lifeInsuranceApplicationService(
        lifeInsuranceConfig,
        $q,
        AdapterUtils,
        utilityService,
        $filter,
        validateService) {

        var lifeInsuranceApplication = this;
        var performNeedAnalysis = {};
        var masterData = {};
        var selectedAccount;
        var accountDetails;
        var needAnalysisResult;
        var didYouKnowData;
        var helpMeChooseData;
        var premiumAcceptanceMessage;
        var journeyMaster;

        var hasPlans = {
            child: false,
            otherGoals: false,
            homeDetails: false
        };

        var applicationNumber = ''; //initially empty for need analysis first page


        //set the did you know data
        lifeInsuranceApplication.setDidYouKnow = function(data) {
            didYouKnowData = data;
        };

        lifeInsuranceApplication.initializeNeedAnalysis = function() {
            performNeedAnalysis = {};
            hasPlans = {
                child: false,
                otherGoals: false,
                homeDetails: false
            };
        };

        //get the application number
        lifeInsuranceApplication.getApplicationNumber = function() {
            return applicationNumber;
        };

        //set the application number
        lifeInsuranceApplication.setApplicationNumber = function(number) {
            applicationNumber = number;
        };

        //get the did you know data
        lifeInsuranceApplication.getDidYouKnow = function() {
            return didYouKnowData;
        };

        //set the help me choose data
        lifeInsuranceApplication.setHelpMeChoose = function(message) {
            helpMeChooseData = message;
        };

        //get the help me choose data
        lifeInsuranceApplication.getHelpMeChoose = function() {
            return helpMeChooseData;
        };

        //set the need analysis result
        lifeInsuranceApplication.setNeedAnalysisResult = function(data) {
            needAnalysisResult = data;
        };

        //get the need analysis result
        lifeInsuranceApplication.getNeedAnalysisResult = function() {
            return needAnalysisResult;
        };

        //set no child plans to be used while displaying chart
        lifeInsuranceApplication.setNoChildPlans = function(data) {
            hasPlans.child = data;
        };

        //set no other goal plans to be used while displaying chart
        lifeInsuranceApplication.setNoOtherGoals = function(value) {
            hasPlans.otherGoals = value;
        };

        //set no home plan to be used while displaying chart
        lifeInsuranceApplication.setNoHomePlan = function(value) {
            hasPlans.homeDetails = value;
        };

        //get the no plan object whenever displaying the chart
        lifeInsuranceApplication.getNoPlans = function() {
            return hasPlans;
        };

        //set need analysis data
        lifeInsuranceApplication.setNeedAnalysis = function(data) {
            performNeedAnalysis = data;
            hasPlans = {};
            if (performNeedAnalysis.personalDetails && Number(performNeedAnalysis.personalDetails.numberOfChildren) == 0) {
                hasPlans.child = true;
            }
            if (performNeedAnalysis.otherGoals && performNeedAnalysis.otherGoals.achiveByYear.key == 0) {
                hasPlans.otherGoals = true;
            }
            if (performNeedAnalysis.buyingAHome && performNeedAnalysis.buyingAHome.buyHomeYear.key == 0) {
                hasPlans.homeDetails = true;
            }
        };

        //set the personal details of need analysis
        lifeInsuranceApplication.setPersonalDetails = function(data) {
            performNeedAnalysis.personalDetails = data;
        };

        //get the personal details of need analysis
        lifeInsuranceApplication.getPersonalDetails = function() {
            return performNeedAnalysis.personalDetails;
        };

        //set the financial details of need analysis
        lifeInsuranceApplication.setFinancialDetails = function(data) {
            performNeedAnalysis.financialDetails = data;
        };

        //get the financial details of need analysis
        lifeInsuranceApplication.getFinancialDetails = function() {
            return performNeedAnalysis.financialDetails;
        };


        //set the other details of need Analysis
        lifeInsuranceApplication.setOtherDetails = function(data) {
            performNeedAnalysis.otherDetails = data;
        };


        lifeInsuranceApplication.getOtherDetails = function() {
            return performNeedAnalysis.otherDetails;
        };

        //set the retirement planning
        lifeInsuranceApplication.setRetirementPlanning = function(data) {
            performNeedAnalysis.retirementPlanning = data;
        };


        lifeInsuranceApplication.getRetirementPlanning = function() {
            return performNeedAnalysis.retirementPlanning;
        };


        //set the need analysis home details
        lifeInsuranceApplication.setNeedAnalysisHomeDetails = function(data) {
            performNeedAnalysis.buyingAHome = data;
        };


        lifeInsuranceApplication.getHomeDetails = function() {
            return performNeedAnalysis.buyingAHome;
        };


        //set the need analysis other goals details
        lifeInsuranceApplication.setNeedAnalysisOtherGoalDetails = function(data) {
            performNeedAnalysis.otherGoals = data;
        };


        lifeInsuranceApplication.getOtherGoals = function() {
            return performNeedAnalysis.otherGoals;
        };

        lifeInsuranceApplication.setNeedAnalysisChildEducation = function(data) {
            performNeedAnalysis.childEducationNeeds = data;
        };

        lifeInsuranceApplication.getNeedAnalysisChildEducation = function() {
            return performNeedAnalysis.childEducationNeeds;
        };

        lifeInsuranceApplication.setneedAnalysisChildMarriage = function(data) {
            performNeedAnalysis.childMarriageNeeds = data;
        };

        lifeInsuranceApplication.getneedAnalysisChildMarriage = function() {
            return performNeedAnalysis.childMarriageNeeds;
        };

        lifeInsuranceApplication.getNeedAnalysisMastersList = function() {
            return masterData;
        };

        //set the selected bank acount by the user
        lifeInsuranceApplication.setSelectedAccount = function(data) {
            selectedAccount = data;
        };

        lifeInsuranceApplication.setBankAccountDetails = function(data) {
            performNeedAnalysis.bankDetails = data;
        };

        lifeInsuranceApplication.getAccoutDetails = function() {
            return accountDetails;
        };

        lifeInsuranceApplication.getPremiumAcceptanceMessage = function() {
            return premiumAcceptanceMessage;
        };

        lifeInsuranceApplication.setPremiumAcceptanceMessage = function(message) {
            premiumAcceptanceMessage = message;
        };

        lifeInsuranceApplication.getDate = function() {
            return new Date();
            //This has to be replaced once we get time services
        };


        lifeInsuranceApplication.getConsentText = function() {
            var q = $q.defer();
            AdapterUtils.getData(lifeInsuranceConfig.adapterURL.consentText[0], true).then(
                function(response) {
                    masterData = response.data;
                    q.resolve(response.data);
                },
                function(error) {
                    utilityService.showErrorMessage(error.responseMessage);
                    q.reject(error);
                }
            );
            return q.promise;
        };


        lifeInsuranceApplication.saveNA = function(commonId) {
            var saveNA = {};
            saveNA.applicationNumber = applicationNumber;
            saveNA.pageNo = commonId;
            saveNA.na = {};
            saveNA.na.req = performNeedAnalysis;

            var q = $q.defer();
            AdapterUtils.postData(lifeInsuranceConfig.adapterURL.saveNA[0], saveNA, true).then(
                function(response) {
                    if (response.data.applicationNumber) {
                        applicationNumber = response.data.applicationNumber;
                    }
                    if (commonId) {
                        lifeInsuranceApplication.saveJourney(commonId);
                    }
                    q.resolve(response.data);
                },
                function(error) {
                    utilityService.showErrorMessage(error.responseMessage);
                    q.reject(error);
                }
            );
            return q.promise;
        };

        lifeInsuranceApplication.saveJourney = function(commonId) {
            var object = $filter('getObjectByValue')(journeyMaster, 'commonId', commonId);
            var request = {
                "id": applicationNumber,
                "journey": [{
                    "journeyType": object.journeyType,
                    "portalURL": object.portalURL,
                    "commonId": object.commonId,
                    "mobileURL": object.mobileURL,
                    "lastModifiedTime": validateService.getCurrentDate().getTime() + '',
                    "lastModifiedBy": "mobile"
                }]
            };
            var q = $q.defer();
            AdapterUtils.postData(lifeInsuranceConfig.adapterURL.saveLiJourney[0], request, false).then(
                function(response) {
                    q.resolve(response.data);
                },
                function(error) {
                    //utilityService.showErrorMessage(error.responseMessage);
                    q.reject(error);
                }
            );
            return q.promise;
        };

        lifeInsuranceApplication.getJourneyMasterFromCloud = function() {
            var q = $q.defer();
            var request = {
                "journeyType":"LI"
            }
            AdapterUtils.postData(lifeInsuranceConfig.adapterURL.getLiJourneyMaster[0], request, true).then(
                function(response) {
                    journeyMaster = response.data;
                    q.resolve(response.data);
                },
                function(error) {
                    utilityService.showErrorMessage(error.responseMessage);
                    q.reject(error);
                }
            );
            return q.promise;
        };

        lifeInsuranceApplication.getJourneyMaster = function() {
            return journeyMaster;
        };

        //posting the need analysis data
        lifeInsuranceApplication.submitNeedAnalysisData = function() {
            performNeedAnalysis.applicationNumber = applicationNumber;
            var q = $q.defer();
            AdapterUtils.postData(lifeInsuranceConfig.adapterURL.performNeedAnalysis[0], performNeedAnalysis, true).then(
                function(response) {
                    q.resolve(response.data);
                },
                function(error) {
                    utilityService.showErrorMessage(error.responseMessage);
                    q.reject(error);
                }
            );
            return q.promise;
        };


        //get the master data for dropdown values
        lifeInsuranceApplication.getMasterData = function() {
            var q = $q.defer();
            AdapterUtils.getData(lifeInsuranceConfig.adapterURL.getNeedAnalysisMasters[0], true).then(
                function(response) {
                    masterData = response.data;
                    q.resolve(response.data);
                },
                function(error) {
                    utilityService.showErrorMessage(error.responseMessage);
                    q.reject(error);
                }
            );
            return q.promise;
        };

        //get the SBI bank account details
        lifeInsuranceApplication.getSBIBankAccounts = function(req) {
            var q = $q.defer();
            AdapterUtils.postData(lifeInsuranceConfig.adapterURL.getLISBIBankAccounts[0], req, true).then(
                function(response) {
                    q.resolve(response.data);
                },
                function(error) {
                    utilityService.showErrorMessage(error.responseMessage);
                    q.reject(error);
                }
            );
            return q.promise;
        };

        lifeInsuranceApplication.getLetsMakeFasterText = function() {
            var q = $q.defer();
            AdapterUtils.getData(lifeInsuranceConfig.adapterURL.getLetsMakeFasterText[0], true).then(
                function(response) {
                    q.resolve(response.data);
                },
                function(error) {
                    utilityService.showErrorMessage(error.responseMessage);
                    q.reject(error);
                }
            );
            return q.promise;
        };


        lifeInsuranceApplication.getConsentProceedAddressText = function() {
            var q = $q.defer();
            AdapterUtils.getData(lifeInsuranceConfig.adapterURL.getConsentProceedAddressText[0], true).then(
                function(response) {
                    q.resolve(response.data);
                },
                function(error) {
                    utilityService.showErrorMessage(error.responseMessage);
                    q.reject(error);
                }
            );
            return q.promise;
        };


        lifeInsuranceApplication.getWelcomeText = function() {
            var q = $q.defer();
            AdapterUtils.getData(lifeInsuranceConfig.adapterURL.getWelcomeText[0], true).then(
                function(response) {
                    q.resolve(response.data);
                },
                function(error) {
                    utilityService.showErrorMessage(error.responseMessage);
                    q.reject(error);
                }
            );
            return q.promise;
        };


        lifeInsuranceApplication.getDidYouKnowList = function() {
            var q = $q.defer();
            AdapterUtils.getData(lifeInsuranceConfig.adapterURL.didYouKnowList[0], true).then(
                function(response) {
                    q.resolve(response.data);
                },
                function(error) {
                    utilityService.showErrorMessage(error.responseMessage);
                    q.reject(error);
                }
            );
            return q.promise;
        };

        //get the account details of selected bank account by the user 
        lifeInsuranceApplication.getSBIBankAccoutDetails = function(data) {
            var q = $q.defer();
            AdapterUtils.postData(lifeInsuranceConfig.adapterURL.getLISBIBankAccountDetails[0], data, true).then(
                function(response) {
                    accountDetails = response.data;
                    q.resolve(response.data);
                },
                function(error) {
                    utilityService.showErrorMessage(error.responseMessage);
                    q.reject(error);
                }
            );
            return q.promise;
        };

        lifeInsuranceApplication.getAcceptanceMessage = function() {
            var q = $q.defer();
            AdapterUtils.getData(lifeInsuranceConfig.adapterURL.getAcceptanceMessage[0], true).then(
                function(response) {
                    q.resolve(response.data);
                },
                function(error) {
                    utilityService.showErrorMessage(error.responseMessage);
                    q.reject(error);
                }
            );
            return q.promise;
        };
        // Function to get E-siganture content
        lifeInsuranceApplication.getESignatureContent = function() {
            var q = $q.defer();
            AdapterUtils.getData(lifeInsuranceConfig.adapterURL.getESignatureContent[0], true).then(
                function(response) {
                    q.resolve(response.data);
                },
                function(error) {
                    utilityService.showErrorMessage(error.responseMessage);
                    q.reject(error);
                }
            );
            return q.promise;
        };
    }

})();
