'use strict';
angularApp.controller('carLoancalculateEMIController', [
    "$state",
    "$scope",
    "$ionicPopup",
    "$translate",
    "$ionicHistory",
    "utilityService",
    "ionicDatePicker",
    "$ionicSideMenuDelegate",
    "validateService",
    "$filter",
    "homeLoanService", "carLoanService",
    function($state, $scope, $ionicPopup, $translate, $ionicHistory, utilityService, ionicDatePicker, $ionicSideMenuDelegate, validateService, $filter, homeLoanService, carLoanService) {

        var carLoancalculateEMIVm = this;

        function initPage() {




            var rupeeSymbol = String.fromCharCode(8377);
            carLoancalculateEMIVm.detail = {};
            carLoancalculateEMIVm.detail.interestRate = carLoanService.emiData.effectiveRate;

            if (carLoanService.amountSlider) {

                carLoancalculateEMIVm.amountSlider = carLoanService.amountSlider;
                carLoancalculateEMIVm.tenureSlider = carLoanService.tenureSlider;
                carLoancalculateEMIVm.finalAmount  = carLoanService.initialAmount;
                carLoancalculateEMIVm.finalTenure = carLoanService.initialTenure;

            } else {
                carLoancalculateEMIVm.finalAmount  = carLoanService.emiData.amount.initial;
                carLoancalculateEMIVm.finalTenure = carLoanService.emiData.tenure.initial;

            }
                carLoancalculateEMIVm.amountSlider = {
                    value: carLoancalculateEMIVm.finalAmount,
                    options: {
                        showSelectionBar: true,
                        floor: carLoanService.emiData.amount.min,
                        ceil: carLoanService.emiData.amount.max,
                        step: carLoanService.emiData.amount.step,
                        onChange: function(id, model) {
                            carLoancalculateEMIVm.emiCalculation();
                        },
                        translate: function(value) {
                            return rupeeSymbol + $filter('INR')(value);
                        }
                    }
                };


                carLoancalculateEMIVm.tenureSlider = {
                    value: carLoancalculateEMIVm.finalTenure,
                    options: {
                        showSelectionBar: true,
                        floor: carLoanService.emiData.tenure.min,
                        ceil: carLoanService.emiData.tenure.max,
                        step: carLoanService.emiData.tenure.step,
                        onChange: function(id, model) {
                            carLoancalculateEMIVm.emiCalculation();
                        },
                        translate: function(value) {
                            return value + " Months";
                        }
                    }
                };

            carLoancalculateEMIVm.emiCalculation();

             var p = carLoanService.emiData.amount.max;
            var i = (carLoancalculateEMIVm.detail.interestRate / 1200);
            var t = carLoanService.emiData.tenure.max;
            var numerator = p * i * Math.pow((1 + i), t);
            var denominator = Math.pow((1 + i), t) - 1;
            carLoancalculateEMIVm.emiAmountMax = Math.ceil((numerator / denominator));


        };

        $scope.$on('$ionicView.loaded', function() {

        });

        $scope.$on('$ionicView.beforeEnter', function() {
            initPage();
        });

        carLoancalculateEMIVm.goToNextPage = function() {

            if(parseInt(carLoanService.emiData.amount.max) < carLoancalculateEMIVm.amountSlider.value){
                utilityService.showErrorMessage("Invalid loan amount");
                return;
            }

            if(parseInt(carLoanService.emiData.amount.min) > carLoancalculateEMIVm.amountSlider.value){
                utilityService.showErrorMessage("Invalid loan amount");
                return;
            }

            if(parseInt(carLoanService.emiData.tenure.max) < carLoancalculateEMIVm.tenureSlider.value){
                utilityService.showErrorMessage("Invalid loan tenure");
                return;
            }

            if(parseInt(carLoanService.emiData.tenure.min) > carLoancalculateEMIVm.tenureSlider.value){
                utilityService.showErrorMessage("Invalid loan tenure");
                return;
            }

            var request = carLoanService.saveObj;

            request.loanAmount = carLoancalculateEMIVm.amountSlider.value.toString();

            request.loanTenure = carLoancalculateEMIVm.tenureSlider.value.toString();

            carLoanService.triggerCIR(request).then(function(data) {

                carLoanService.saveObj = request;
                carLoanService.amountSlider = carLoancalculateEMIVm.amountSlider;
                carLoanService.tenureSlider = carLoancalculateEMIVm.tenureSlider;
                carLoanService.initialAmount = carLoancalculateEMIVm.amountSlider.value;
                carLoanService.initialTenure = carLoancalculateEMIVm.tenureSlider.value;
                $state.go("menu.cardetails");
            }, function(error) {

                utilityService.showErrorMessage(error.responseMessage);
            });


        }

        carLoancalculateEMIVm.showMInfoPopup = function() {
            
               var templateInfo = '<p translate="EMI_INFO"></p>';
          

            var hlInfoIcon = $ionicPopup.show({
                template: templateInfo,
                title: '',
                cssClass: 'dialog',
                scope: $scope,
                buttons: [{
                    text: 'OK',
                    type: 'button-positive'
                }]
            });


        }



        carLoancalculateEMIVm.goBack = function() {
            carLoanService.amountSlider="";

            $ionicHistory.goBack(-1);
            
        }

        carLoancalculateEMIVm.emiCalculation = function() {
            var p = carLoancalculateEMIVm.amountSlider.value;
            var i = (carLoancalculateEMIVm.detail.interestRate / 1200);
            var t = carLoancalculateEMIVm.tenureSlider.value;
            var numerator = p * i * Math.pow((1 + i), t);
            var denominator = Math.pow((1 + i), t) - 1;
            carLoancalculateEMIVm.emiAmount = Math.ceil((numerator / denominator));
        }

        return this;
    }


]);