'use strict';

angularApp.controller('rxtcUploadPhotographController', [
    "$state",
    "$scope",
    "$translate",
    "$ionicHistory",
    "$ionicPopup",
    "utilityService", 
    "$filter",
    "rxtcService",
    "$ionicScrollDelegate",
    "homeLoanService","ionicDatePicker","cameraService",

    function($state,
        $scope,
        $translate,
        $ionicHistory,
        $ionicPopup,
        utilityService,
        $filter,
        rxtcService,
        $ionicScrollDelegate,
        homeLoanService,ionicDatePicker,cameraService) {

        var rxtcUploadPhotographVm = this;
        var phnReg = /^[123456789]\d{9}$/;
        var pinRegex = /^[123456789]\d{5}$/;

        rxtcUploadPhotographVm.initPage = function () {
            rxtcUploadPhotographVm.errWorkObj = {};            
            rxtcUploadPhotographVm.photoNotAdded = false;
            rxtcUploadPhotographVm.retireDateNotAdded = false;
            rxtcUploadPhotographVm.editIcon = true;
            rxtcUploadPhotographVm.expandPhoto = true;
            rxtcUploadPhotographVm.expandRDate = false;
            rxtcUploadPhotographVm.expandWorkDetails = false;
            rxtcUploadPhotographVm.dxcFlag = rxtcService.dxcFlag;
            rxtcUploadPhotographVm.isPSSExempted = true;
            if (rxtcUploadPhotographVm.dxcFlag) {
                rxtcUploadPhotographVm.retireDate = new Date();
            }            

            if(rxtcService.getRetrieveData()) {
                rxtcUploadPhotographVm.retrieveData = rxtcService.getRetrieveData();                
                if(rxtcService.getRetrieveData().photographDocId){
                    rxtcUploadPhotographVm.retrievePhotograph();
                }                
                if (rxtcUploadPhotographVm.dxcFlag && rxtcUploadPhotographVm.retrieveData.retirementDate) {
                    rxtcUploadPhotographVm.retireDate = rxtcUploadPhotographVm.retrieveData.retirementDate;
                    if(rxtcUploadPhotographVm.isPSSExempted) {
                        rxtcUploadPhotographVm.address1 = rxtcUploadPhotographVm.retrieveData.workDetails.address1;
                        rxtcUploadPhotographVm.address2 = rxtcUploadPhotographVm.retrieveData.workDetails.address2;
                        rxtcUploadPhotographVm.pincode = rxtcUploadPhotographVm.retrieveData.workDetails.pinCode;
                        rxtcUploadPhotographVm.village = JSON.parse(rxtcUploadPhotographVm.retrieveData.workDetails.city);
                        rxtcUploadPhotographVm.district = JSON.parse(rxtcUploadPhotographVm.retrieveData.workDetails.district);
                        rxtcUploadPhotographVm.state = JSON.parse(rxtcUploadPhotographVm.retrieveData.workDetails.state);
                    }
                }
            }
        }

        rxtcUploadPhotographVm.retrievePhotograph = function() {
            rxtcService.retrievePhotograph().then(function(data) {
                rxtcUploadPhotographVm.profileImageUrl = "data:image/jpeg;base64," + data.docList.base64;
                rxtcUploadPhotographVm.filename = data.docList.docName;                    
                rxtcUploadPhotographVm.contentType = data.docList.mimeType;
                rxtcUploadPhotographVm.category = data.docList.category;
                rxtcUploadPhotographVm.photoValidated = true;
                rxtcUploadPhotographVm.editIcon = false;               
            }, function(error) {
                utilityService.showErrorMessage(error.responseMessage);
            });
        }

        rxtcUploadPhotographVm.isAddress1Input = function() {
            rxtcUploadPhotographVm.errWorkObj.add1Error = rxtcService.isValidField(rxtcUploadPhotographVm.address1,"Address Line 1");
        }

        rxtcUploadPhotographVm.isPincodeInput = function() {
            if(rxtcService.isValidField(rxtcUploadPhotographVm.pincode,"Pincode")) {
                rxtcUploadPhotographVm.errWorkObj.pincodeError = rxtcService.isValidField(rxtcUploadPhotographVm.pincode,"Pincode");
            }else if ((rxtcUploadPhotographVm.pincode.length != 6) || (!pinRegex.test(rxtcUploadPhotographVm.pincode))) {
                rxtcUploadPhotographVm.errWorkObj.pincodeError = 'Pin code should be of six digits (0-9) and should not start with zero.';
            }else{
                rxtcUploadPhotographVm.errWorkObj.pincodeError = '';
            }
        }

        rxtcUploadPhotographVm.isVillageInput = function() {
            rxtcUploadPhotographVm.errWorkObj.villageError = rxtcService.isValidField(rxtcUploadPhotographVm.village,"Village");        
        }

        rxtcUploadPhotographVm.isTownInput = function() {
            rxtcUploadPhotographVm.errWorkObj.townError = rxtcService.isValidField(rxtcUploadPhotographVm.town,"Town");
        }

        rxtcUploadPhotographVm.isDistrictInput = function() {
            rxtcUploadPhotographVm.errWorkObj.districtError = rxtcService.isValidField(rxtcUploadPhotographVm.district,"District");
        }

        rxtcUploadPhotographVm.isStateInput = function() {
            rxtcUploadPhotographVm.errWorkObj.stateError = rxtcService.isValidField(rxtcUploadPhotographVm.state,"State");
        }

        rxtcUploadPhotographVm.isCountryInput = function() {
            rxtcUploadPhotographVm.errWorkObj.countryError = rxtcService.isValidField(rxtcUploadPhotographVm.country,"Country");
        }

        rxtcUploadPhotographVm.isMobileNumberInput = function() {
            if(rxtcService.isValidField(rxtcUploadPhotographVm.mobileNo,"Mobile Number")) {
                rxtcUploadPhotographVm.errWorkObj.mobileNoError = rxtcService.isValidField(rxtcUploadPhotographVm.mobileNo,"Mobile Number");
            }else if (!phnReg.test(rxtcUploadPhotographVm.mobileNo)) {
                rxtcUploadPhotographVm.errWorkObj.mobileNoError = 'Contact number should be of ten digits (0-9) and should not start with zero.';
            } else {
                rxtcUploadPhotographVm.errWorkObj.mobileNoError = '';
            }
        }
        

        rxtcUploadPhotographVm.selectRetireDate = function(flag){
            if (flag == 'Y') {
                rxtcUploadPhotographVm.retirementDate = $filter('date')(rxtcUploadPhotographVm.retireDate, "MMM dd yyyy");
                rxtcUploadPhotographVm.rDateValidated = true;
                rxtcUploadPhotographVm.retireDateNotAdded = false;
            }else{
                rxtcUploadPhotographVm.retirementDate = "";               
                rxtcUploadPhotographVm.rDateValidated = false;
            }
            rxtcUploadPhotographVm.expandRDate = false;
            rxtcUploadPhotographVm.expandWorkDetails = true;
        }

        rxtcUploadPhotographVm.validateBlocks = function() {
            if(rxtcUploadPhotographVm.profileImageUrl) {
                rxtcUploadPhotographVm.photoValidated = true;
            }else{
                rxtcUploadPhotographVm.photoValidated = false;
            }
            if(rxtcUploadPhotographVm.validateWorkDetailsForm()){
                rxtcUploadPhotographVm.workDetailsValidated = true;
            }else{
                rxtcUploadPhotographVm.errWorkObj = {};
                rxtcUploadPhotographVm.workDetailsValidated = false;
            }
        }

        rxtcUploadPhotographVm.expandBlock = function(block) {
            rxtcUploadPhotographVm.expandPhoto = false;
            rxtcUploadPhotographVm.expandRDate = false;
            rxtcUploadPhotographVm.expandWorkDetails = false;
            if(block == "photo") {
                rxtcUploadPhotographVm.expandPhoto = true;
                rxtcUploadPhotographVm.validateBlocks();                               
            }else if (block == "retirementDate") {
                rxtcUploadPhotographVm.expandRDate = true;
                rxtcUploadPhotographVm.validateBlocks(); 
            }else if (block == "work") {
                rxtcUploadPhotographVm.expandWorkDetails = true;
                rxtcUploadPhotographVm.validateBlocks(); 
            }            
        }

        rxtcUploadPhotographVm.uploadPhotograph = function(imgProfile, filename, category, contentType) {            
            var request = {
                "docList": {
                    "docName": filename ? filename : '',
                    "mimeType": contentType ? contentType : '',
                    "category": category ? category : '',
                    "base64": imgProfile ? imgProfile.split(',')[1] : ''
                    }
                };
            rxtcService.uploadPhotograph(request).then(function(data) {
                rxtcService.setPhotographData(data);
                rxtcUploadPhotographVm.editIcon = false;
                rxtcUploadPhotographVm.expandPhoto = false;
                rxtcUploadPhotographVm.photoValidated = true;
                rxtcUploadPhotographVm.photoNotAdded = false;
                rxtcUploadPhotographVm.expandRDate = true;
            }, function(error) {
                rxtcUploadPhotographVm.profileImageUrl = "";
                rxtcUploadPhotographVm.editIcon = true;
                rxtcUploadPhotographVm.photoValidated = false;
                utilityService.showErrorMessage(error.responseMessage);
            }); 
        }

        rxtcUploadPhotographVm.commanAddFile = function(blob, data, typecheck,sizeOfImage){
                var imageName = "Photo";
                var sizeInMB = sizeOfImage;
                var size = 0;
                var block = data.split(";");
                var contentType = block[0].split(":")[1];                

                if (sizeInMB < 3145728) {
                    // utilityService.hideSpinner();
                    rxtcUploadPhotographVm.profileImageUrl = data;
                    rxtcUploadPhotographVm.filename = imageName;                    
                    rxtcUploadPhotographVm.size = size;
                    rxtcUploadPhotographVm.contentType = contentType;
                    rxtcUploadPhotographVm.category = imageName + typecheck;                                                  
              
                    rxtcUploadPhotographVm.uploadPhotograph(rxtcUploadPhotographVm.profileImageUrl,rxtcUploadPhotographVm.filename,rxtcUploadPhotographVm.category,rxtcUploadPhotographVm.contentType); 
                }else{
                    // utilityService.hideSpinner();
                    var template = "Uploaded photograph Exceeds the size limit. Maximum size limit-3 MB, please retry."
                    $ionicPopup.show({
                        title: '',
                        template: template,
                        scope: $scope,
                        cssClass: 'my-custom-popup',
                        buttons: [{
                            text: 'OK',
                            type: 'button-assertive',
                            onTap: function () {
                                
                            }
                        }],
                    });
                }
            }

        rxtcUploadPhotographVm.deletePicture = function(){
            rxtcUploadPhotographVm.profileImageUrl = "";
            rxtcUploadPhotographVm.editIcon = true;
            rxtcUploadPhotographVm.photoValidated = false;
        }

        rxtcUploadPhotographVm.uploadPicture = function(){
            rxtcUploadPhotographVm.picturePopup = $ionicPopup.show({
                cssClass: 'uploadPhoto-alert-popup',
                template: '<div class="row homeLoan textCenter"><div class="col-50">'+
                        '<img class="rxtc-photoPopUp" alt="" src="img/rxtc/UploadPhoto.svg" ng-click="rxtcUploadPhotographVm.uploadGalleryPicture()"/>'+
                        '<p class="roboto-medium font-size-12" translate="RTXC_GALLERY_LBL"></p></div>'+
                        '<div class="col-50"><img class="rxtc-photoPopUp" alt="" src="img/rxtc/Selfie.svg" ng-click="rxtcUploadPhotographVm.clickselfie()"/>'+
                        '<p class="roboto-medium font-size-12" translate="RTXC_SELFIE_LBL"></p></div></div>',
                scope: $scope, 
                buttons: []
            });
        }

        rxtcUploadPhotographVm.clickselfie = function() {
            rxtcUploadPhotographVm.picturePopup.close();
            rxtcService.getnewImage().then(function(data) {
                var blob = new Blob([data], {type: 'image/jpeg'});
                    var typecheck = data.substring(data.indexOf('/') + 1, data.indexOf(';base64'));
                    var size = data.length;
                    if (typecheck == "png" || typecheck == "jpg" || typecheck == "jpeg") {
                         rxtcUploadPhotographVm.commanAddFile(blob, data, typecheck,size); 
                    }else{
                        // utilityService.hideSpinner();
                        var template = "File should be .jpg or .png only and should not exceed 3MB in size."
                        $ionicPopup.show({
                            title: '',
                            template: template,
                            scope: $scope,
                            cssClass: 'my-custom-popup',
                            buttons: [{
                                text: 'OK',
                                type: 'button-assertive',
                                onTap: function () {
                                }
                            }],
                        });
                    }
            }, function(error) {
                var title = '';
                var template = '{{"SERVICE_ERR_MSG" | translate}}';
                var onTap = '';
                var buttontext = '<b>OK</b>';
                utilityService.showAlertModal(title, template, onTap, $scope, $state, buttontext);
            });
        }

        rxtcUploadPhotographVm.uploadGalleryPicture = function() {
            rxtcUploadPhotographVm.picturePopup.close();
            rxtcService.getImageFromGallery().then(function(data) {
                var blob = new Blob([data], {type: 'image/jpeg'});
                    var typecheck = data.substring(data.indexOf('/') + 1, data.indexOf(';base64'));
                    var size = data.length;
                    if (typecheck == "png" || typecheck == "jpg" || typecheck == "jpeg") {
                         rxtcUploadPhotographVm.commanAddFile(blob, data, typecheck,size); 
                    }else{
                        // utilityService.hideSpinner();
                        var template = "File should be .jpg or .png only and should not exceed 3MB in size."
                        $ionicPopup.show({
                            title: '',
                            template: template,
                            scope: $scope,
                            cssClass: 'my-custom-popup',
                            buttons: [{
                                text: 'OK',
                                type: 'button-assertive',
                                onTap: function () {
                                }
                            }],
                        });
                    }
            }, function(error) {
                var title = '';
                var template = '{{"SERVICE_ERR_MSG" | translate}}';
                var onTap = '';
                var buttontext = '<b>OK</b>';
                utilityService.showAlertModal(title, template, onTap, $scope, $state, buttontext);
            });
        }

        rxtcUploadPhotographVm.validateWorkDetailsForm = function() {
            rxtcUploadPhotographVm.errWorkObj = {};
            if(rxtcService.isValidField(rxtcUploadPhotographVm.address1,"Address Line 1")) {
                rxtcUploadPhotographVm.errWorkObj.add1Error = rxtcService.isValidField(rxtcUploadPhotographVm.address1,"Address Line 1");
            }
            if(rxtcService.isValidField(rxtcUploadPhotographVm.pincode,"Pincode")) {
                rxtcUploadPhotographVm.errWorkObj.pincodeError = rxtcService.isValidField(rxtcUploadPhotographVm.pincode,"Pincode");
            }else if ((rxtcUploadPhotographVm.pincode.length != 6) || (!pinRegex.test(rxtcUploadPhotographVm.pincode))) {
                rxtcUploadPhotographVm.errWorkObj.pincodeError = 'Pin code should be of six digits (0-9) and should not start with zero.';
            }
            if(rxtcService.isValidField(rxtcUploadPhotographVm.village,"Village")) {
                rxtcUploadPhotographVm.errWorkObj.villageError = rxtcService.isValidField(rxtcUploadPhotographVm.village,"Village");
            }
            if(rxtcService.isValidField(rxtcUploadPhotographVm.district,"District")) {
                rxtcUploadPhotographVm.errWorkObj.districtError = rxtcService.isValidField(rxtcUploadPhotographVm.district,"District");
            }
            if(rxtcService.isValidField(rxtcUploadPhotographVm.state,"State")) {
                rxtcUploadPhotographVm.errWorkObj.stateError = rxtcService.isValidField(rxtcUploadPhotographVm.state,"State");
            }
            if(rxtcService.isValidField(rxtcUploadPhotographVm.mobileNo,"Mobile Number")) {
                rxtcUploadPhotographVm.errWorkObj.mobileNoError = rxtcService.isValidField(rxtcUploadPhotographVm.mobileNo,"Mobile Number");
            }else if ((rxtcUploadPhotographVm.mobileNo.length != 10) || (!phnReg.test(rxtcUploadPhotographVm.mobileNo))) {
                rxtcUploadPhotographVm.errWorkObj.mobileNoError = 'Contact number should be of ten digits (0-9) and should not start with zero.';
            }
         
            return (angular.equals({}, rxtcUploadPhotographVm.errWorkObj)) ? true : false;           
        }      

        rxtcUploadPhotographVm.goback = function() {
            rxtcService.backToDetails = true;
            $state.go('menu.rxtcDetails');
        };

        rxtcUploadPhotographVm.goToNextPage = function() {
            if(!rxtcUploadPhotographVm.photoValidated) {
                rxtcUploadPhotographVm.photoNotAdded = true;
            }else{
                rxtcUploadPhotographVm.photoNotAdded = false;
            }

            if (!rxtcUploadPhotographVm.rDateValidated) { 
                rxtcUploadPhotographVm.retireDateNotAdded = true;
            }else{
                rxtcUploadPhotographVm.retireDateNotAdded = false;
            }

            
            var saveRequest = {
                "retirementDate": rxtcUploadPhotographVm.retireDate ? rxtcUploadPhotographVm.retireDate : "",
                "workDetails": {
                    "addressLine1": rxtcUploadPhotographVm.address1 ? rxtcUploadPhotographVm.address1 : "",
                    "addressLine2": rxtcUploadPhotographVm.address2 ? rxtcUploadPhotographVm.address2 : "",
                    "pincode": rxtcUploadPhotographVm.pincode ? rxtcUploadPhotographVm.pincode : "",
                    "cityCode": rxtcUploadPhotographVm.village ? rxtcUploadPhotographVm.village.key : "",
                    "cityText": rxtcUploadPhotographVm.village ? rxtcUploadPhotographVm.village.value : "",
                    "districtCode": rxtcUploadPhotographVm.district ? rxtcUploadPhotographVm.district.key : "",
                    "districtText": rxtcUploadPhotographVm.district ? rxtcUploadPhotographVm.district.value : "",
                    "stateCode": rxtcUploadPhotographVm.state ? rxtcUploadPhotographVm.state.key : "",
                    "stateText": rxtcUploadPhotographVm.state ? rxtcUploadPhotographVm.state.value : "",
                    "officeContactNo": rxtcUploadPhotographVm.mobileNo ? rxtcUploadPhotographVm.mobileNo : ""
                    }
                }
            rxtcService.savePageDetails(saveRequest);                 
            if(rxtcUploadPhotographVm.dxcFlag && !rxtcUploadPhotographVm.isPSSExempted) {
                if (rxtcUploadPhotographVm.validateWorkDetailsForm()) {
                    rxtcUploadPhotographVm.workDetailsValidated = true;
                    if (rxtcUploadPhotographVm.photoValidated && rxtcUploadPhotographVm.rDateValidated && rxtcUploadPhotographVm.workDetailsValidated) {
                        $state.go('menu.rxtcXpressCredit');

                        // rxtcService.checkFinalEligibility(saveRequest).then(function(data) {
                        //     rxtcService.getRetrieveData().retirementDate = saveRequest.retirementDate;
                        //     rxtcService.getRetrieveData().workDetails = saveRequest.workDetails;
                        //     $state.go('menu.rxtcXpressCredit');
                        // },function(error){
                        //     utilityService.showErrorMessage(error.responseMessage);
                        // });                    
                    }    
                }
            }else if(rxtcUploadPhotographVm.dxcFlag) {
                if (rxtcUploadPhotographVm.photoValidated && rxtcUploadPhotographVm.rDateValidated) {
                    $state.go('menu.rxtcXpressCredit');

                    // rxtcService.checkFinalEligibility(saveRequest).then(function(data) {
                    //     rxtcService.getRetrieveData().retirementDate = saveRequest.retirementDate;
                    //     $state.go('menu.rxtcXpressCredit');
                    // },function(error){
                    //     utilityService.showErrorMessage(error.responseMessage);
                    // });                    
                } 
            }else{
                if (rxtcUploadPhotographVm.photoValidated) {
                    var request = {
                        "retirementDate": rxtcUploadPhotographVm.retireDate ? rxtcUploadPhotographVm.retireDate : "",
                        "workDetails": {}
                    } 
                    rxtcService.checkFinalEligibility(request).then(function(data) {
                        // rxtcService.setFinalEligibilityData(data);
                        if(rxtcService.getRetrieveData().selectedProductDetail){
                            rxtcService.getRetrieveData().selectedProductDetail = "";                  
                        }
                        rxtcService.savePageDetails(data);
                        $state.go('menu.rxtcXpressCredit');
                    },function(error){
                        if(error.responseCode == "FE01"){
                            rxtcService.showAlertPopup("error",error.responseMessage,"","menu.homeScreen","OK","","",""); 
                        }else{
                            utilityService.showErrorMessage(error.responseMessage);
                        }
                    });   
                } 
            }                                   
        }       

        $scope.$on('$ionicView.beforeEnter', function() {            
            rxtcUploadPhotographVm.initPage();          
        });

        return this;
    }
]);