'use strict';

angularApp.controller('selectSimController',
    [
        "$state",
        "$scope",
        "loggedInUserService",
        "$filter",
        "utilityService",
        "$ionicPopup",
        "registerWithSimService",
        "$cordovaSms",
        "$q",
        "cryptoService",
        "currentLocationService",
        "clickStreamService",
        "ompMerchantsService",
        "AdapterUtils",
        "velocityCheckService",
        function (
            $state,
            $scope,
            loggedInUserService,
            $filter,
            utilityService,
            $ionicPopup,
            registerWithSimService,
            $cordovaSms,
            $q,
            cryptoService,
            currentLocationService,
            clickStreamService,
            ompMerchantsService,
            AdapterUtils,
            velocityCheckService) {

            var selectSimVm = this;
            var custom_timeout;
            var options = {
                replaceLineBreaks: false, // true to replace \n by a new line, false by default
                android: {
                    intent: '' // send SMS with the native android SMS messaging
                    //intent: '' // send SMS without open any other app
                    //intent: 'INTENT' // send SMS inside a default SMS app
                }
            };

            document.addEventListener("deviceready", function () {

                var permissions = cordova.plugins.permissions;
                selectSimVm.checkSMSPermission = function (mobileNumber, message, option, subscriptionId) {

                    var q = $q.defer();
                    permissions.checkPermission(permissions.SEND_SMS, function (status) {
                        if (!status.hasPermission) {
                            permissions.requestPermissions([permissions.SEND_SMS], function (stat) {
                                if (!stat.hasPermission) {
                                    utilityService.showExitAlertPopup("Kindly provide permission for SMS in your device settings");
                                    q.reject('Contact permission denied by user');

                                } else {
                                    selectSimVm.sendSMS(mobileNumber, message, option, subscriptionId);
                                }
                            }, function (error) {
                                q.reject('Something went wrong while requesting Contact permission');
                            });
                        } else {
                            selectSimVm.sendSMS(mobileNumber, message, option, subscriptionId);
                            q.resolve('Success');
                        }
                    }, function (error) {
                        q.reject('Something went wrong while checking Contact permission');
                    });
                    return q.promise;
                };
                function successCall(success) {
                    clearTimeout(custom_timeout);
                    utilityService.hideSpinner();
                    registerWithSimService.msgSentTimeUi = new Date();
                    var params = {
                        "msgKey": registerWithSimService.textMsg,
                        "deviceId" : device.uuid
                    };
                    registerWithSimService.logSBMsgSentTime(params).then(function (data) {
                        $state.go('menu.loadSimData');
                    }, function (error) {
                        $state.go('menu.loadSimData');
                    });
                    
                }
                function errorCall(error) {
                    clearTimeout(custom_timeout);
                    utilityService.hideSpinner();
                    utilityService.showExitAlertPopup("Cannot send message now. Please try again later.");
                }
                selectSimVm.sendSMS = function (mobileNumber, message, option, subscriptionId) {
                    utilityService.showSpinner();
                    setTimeout(function () {
                        try{
                            sms.send(subscriptionId, mobileNumber, message, options, successCall, errorCall);
                            custom_timeout = setTimeout(function () {
                                errorCall('Delivery status failed !!');
                            }, 30000);
                        }
                        catch(err){
                            utilityService.hideSpinner();
                        }
                    }, 300);
                };
                selectSimVm.sendSMSiOS = function (mobileNumber, message, option) {
                    setTimeout(function () {
                        sms.send('', mobileNumber, message, option, successCall, errorCall);
                    }, 300);
                };
            });


            
            selectSimVm.next = function () {
                if(!(selectSimVm.selectedSimSlot == undefined || selectSimVm.selectedSimSlot == null) || selectSimVm.isIos){
                if(utilityService.isAndroidPlatform())utilityService.showSpinner();
                velocityCheckService.getVelocityData().then(function(res){
                    if(utilityService.isAndroidPlatform())utilityService.hideSpinner();
                    selectSimVm.afterVelocitySuccess();
                },function(error){
                    if(utilityService.isAndroidPlatform())utilityService.hideSpinner();
                    utilityService.showExitAlertPopup(error);
                });
                }
            };

            selectSimVm.afterVelocitySuccess = function(){
                var mobile_number = registerWithSimService.simBindingVirtualMobile;
                var random_str = "";
                var text_msg = "";
                
                if (utilityService.isAndroidPlatform()) {
                    var isAccountExists = -1;
                    selectSimVm.simList.some(function (obj, i) {
                        return obj.simSlotIndex == selectSimVm.selectedSimSlot ? isAccountExists = i : false;
                    });
                    if (isAccountExists !== -1) {
                        registerWithSimService.simSubscriptionId = selectSimVm.simList[isAccountExists].subscriptionId;
                        if (selectSimVm.simList[isAccountExists].carrierName.indexOf('No service') == -1) {
                            utilityService.showSpinner();
                            //send sms if sim network available
                            random_str = generateRandomString(20);
                            text_msg = 'YONOREG ' + cryptoService.getSHA512EncryptedData(random_str);
                            registerWithSimService.textMsg = text_msg;
                            selectSimVm.checkSMSPermission(mobile_number, text_msg, options, registerWithSimService.simSubscriptionId);
                        }
                        else {
                            utilityService.showExitAlertPopup("Kindly check your network settings for the selected sim card.");
                        }
                    }
                }
                else {
                    random_str = generateRandomString(20);
                    text_msg = 'YONOREG ' + cryptoService.getSHA512EncryptedData(random_str);
                    registerWithSimService.textMsg = text_msg;
                    selectSimVm.sendSMSiOS(mobile_number, text_msg, options);
                }
            }
            
            
            $scope.$on('$ionicView.beforeEnter', function () {
                selectSimVm.isAndroid = utilityService.isAndroidPlatform();
                selectSimVm.isIos = utilityService.isIOSPlatform();
                selectSimVm.simList = [];
                utilityService.showSpinner();
                //currentLocation();
                readSimcardInfo();
                registerWithSimService.isSimRegistration = true;
                registerWithSimService.isSimLogin = true;
            });

            function readSimcardInfo() {
                /*Sim card Info fetching - Start*/
                function simInfosuccessCallback(result) {
                    utilityService.hideSpinner();
		            if(utilityService.isIOSPlatform()){
                        if(result.countryCode === '' || result.mnc === '' || result.mcc === '' || result.carrierName === '' || result.carrierName === 'No service')
                            utilityService.showExitAlertPopup("Please insert a SIM or check your network settings before proceeding further");
                    }
                    else {
                        if(result.cards && result.cards.length > 0)
                        {
                            selectSimVm.simList = result.cards;
                        }
                        if (selectSimVm.simList == undefined || selectSimVm.simList.length == 0) {
                                utilityService.showExitAlertPopup("There is no SIM card in your device. Please insert the SIM before proceeding further");
                        }
                        else {
                            if (selectSimVm.simList.length == 1) {
                                    selectSimVm.selectedSimSlot = selectSimVm.simList[0].simSlotIndex;
                            }
                        }
		            }
                    $scope.$apply();
                }

                function HasPerminionSuccessCallback(result) {
                    if (result) {
                        window.plugins.sim.getSimInfo(simInfosuccessCallback, errorCallback);
                    } else {
                        requestReadPermission();
                    }
                }

                function errorCallback(error) {
                    utilityService.hideSpinner();
                    utilityService.showExitAlertPopup("Permission denied.");
                }

                function requestSuccessCallback(result) {
                    if (result) {
                        hasReadPermission();
                    }
                }
                // Android only: check permission
                function hasReadPermission() {
                    window.plugins.sim.hasReadPermission(HasPerminionSuccessCallback, errorCallback);
                }
                // Android only: request permission
                function requestReadPermission() {
                    window.plugins.sim.requestReadPermission(requestSuccessCallback, errorCallback);
                }
                if(utilityService.isIOSPlatform()) {
                    window.plugins.sim.getSimInfo(simInfosuccessCallback, errorCallback);
                }
                else hasReadPermission();

                /*Sim card Info fetching - End*/
            }
            $scope.$on('$ionicView.afterEnter', function () {
                
            });
            return this;
        }
    ]);
